import * as playwright_core from 'playwright-core';
import * as _playwright_test from '@playwright/test';
import { Page, APIRequestContext, Response, Locator, APIResponse, Fixtures, PlaywrightWorkerArgs, PlaywrightWorkerOptions, PlaywrightTestArgs, PlaywrightTestOptions, Browser, BrowserContext, FrameLocator, CDPSession } from '@playwright/test';
import { TFunction } from 'i18next';
import { FastmailApi } from 'apis/fastmail';
import { I18nPlaywrightFixture } from 'playwright-i18next-fixture';
import { TOTP, Secret } from 'otpauth';
import { MemberApis as MemberApis$1 } from 'apis/members';
import { RoleApis } from 'apis/roles';
import { TagsApi } from 'apis/tags';
import { Protocol } from 'playwright-core/types/protocol';
import * as ts_toolbelt_out_Function_Curry from 'ts-toolbelt/out/Function/Curry';
interface InterceptMultipleResponsesParams {
  responseUrl: string;
  times: number;
  baseUrl: string;
  customPageContext: Page | undefined;
  timeout: number;
  responseStatus: number;
}
type GenericCallback = (...params: any[]) => Promise<unknown> | unknown;
interface ExecuteRecursivelyParams {
  callback: GenericCallback;
  condition: GenericCallback;
  timeout: number;
}
interface VerifyToastParams {
  message: string;
  timeout?: number;
  closeAfterVerification: boolean;
  toastType: "success" | "error";
  customPageContext?: Page;
}
interface VerifyHelpPopoverProps {
  triggerElement?: Locator;
  title?: string;
  content?: string;
  helpURL?: string;
  customPageContext?: Page;
}
interface SaveChangesProps {
  closeAfterVerification?: boolean;
  isPane?: boolean;
  customPageContext?: Page;
}
type ConditionProps = Record<string, string>[];
type FilterProps = Record<string, ConditionProps>;
type ParamFilters = FilterProps[];
type BasicTypesInterface = Record<string, number | string | boolean>;
type ParamProps = Record<string, number | string | boolean | ParamFilters>;
type HttpMethods = "get" | "patch" | "post" | "put" | "delete";
type FileType = "csv" | "avi" | "doc" | "docx" | "flv" | "html" | "mp3" | "mp4" | "mpg" | "pdf" | "rtf" | "txt" | "webm" | "xls" | "xlsx" | "wma" | "zip" | "jpg" | "jpeg" | "png" | "gif";
interface BreadcrumbTitleAndRoute$1 {
  title: string;
  route: string;
}
interface ApiRequestProps {
  url: string;
  failOnStatusCode?: boolean;
  headers?: BasicTypesInterface;
  data?: Record<string, unknown>;
  method?: HttpMethods;
  params?: ParamProps;
}
interface WaitForPageLoadParams {
  visibilityTimeout: number;
  customPageContext: Page | undefined;
}
type ApiRequest = (props: ApiRequestProps & Record<string, unknown>) => Promise<APIResponse | undefined>;
interface FieldValue {
  field: string;
  value: string;
}
type VerifyFieldValue = (values: FieldValue | FieldValue[]) => Promise<void> | Promise<void[]>;
interface SelectOptionFromDropdownParams {
  label?: string;
  value: string;
  page?: Page;
  options?: Partial<{
    visibilityTimeout: number;
    textAssertionTimeout: number;
    retryTimeout: number;
  }>;
}
interface SearchAndVerifyProps {
  searchTerm: string;
  countSelector: string;
  searchInputSelector?: string;
  countText: string;
}
interface UploadFileViaDispatchProps {
  fileNameWithType: string;
  assetsPath?: string;
  dispatchEvent?: string;
  droppableZone?: Locator;
}
interface VerifyTooltipProps {
  triggerElement: Locator;
  content: string | RegExp;
  customPageContext?: Page;
}
declare class CustomCommands {
  page: Page;
  t: TFunction;
  responses: string[];
  request: APIRequestContext;
  baseURL: string | undefined;
  csrfToken: string | null | undefined;
  constructor(page: Page, request: APIRequestContext, baseURL?: string | undefined);
  private waitUntilTimeout;
  /**
   *
   * Command to initialize the Csrf token. The Csrf token is initialized by default if its not defined yet, whenever the method apiRequest is executed. Its helpful in cases when we want to hit the api request for two different applications.
   *
   * @example 
   *
   * 
   *   neetoPlaywrightUtilities.initializeCsrfToken();
   * @endexample
  */
  initializeCsrfToken: () => Promise<string | null>;
  /**
   * @deprecated Use UI assertions instead.
   */
  /**
   *
   * Command to wait until a response with URL responseUrl is found. Optionally,
   *
   * provide a base URL if it differs from the home URL of the project's host.
   *
   * @example 
   *
   *   // wait for 3 responses
   * 
   *   neetoPlaywrightUtilities.interceptMultipleResponses({
   *    responseUrl: "/login",
   *    times: 3,
   *    baseURL: "https://app.neetoauth.net",
   *   });
   * @endexample
  */
  interceptMultipleResponses: ({
    responseUrl,
    responseStatus,
    times,
    baseUrl,
    customPageContext,
    timeout
  }?: Partial<InterceptMultipleResponsesParams>) => Promise<Response[]>;
  private recursiveMethod;
  /**
   *
   * Command to check for a condition recursively until it's true, then execute a
   *
   * callback. This process will be repeated until the specified timeout.
   *
   * @example 
   *
   *  //checks if the URL contains /login for 5000 ms. If /login is found within this timeframe, the callback is executed.
   * 
   *  await neetoPlaywrightUtilities.executeRecursively({
   *    timeout: 5000,
   *    condition: () => this.page.url().match(/.*login/),
   *    callback: async () => {
   *     await expect("#locator").to.equal("Login");
   *    },
   *  });
   * @endexample
  */
  executeRecursively: ({
    callback,
    condition,
    timeout
  }: ExecuteRecursivelyParams) => Promise<unknown>;
  /**
   *
   * Command to assert the toastr message. It takes the following parameters:
   *
   * closeAfterVerification(optional): Boolean to close the toast after verification. Default is true.
   *
   * message(optional): Text that should be on toast.
   *
   * toastType(optional): Type of toast. It takes either success or error as it's value. Default is success.
   *
   * timeout(optional): Timeout in milliseconds to wait for the toast to appear. Default is 10_000.
   *
   * customPageContext(optional): Custom page context on which to verify the toast.
   *
   * @example 
   *
   *   await neetoPlaywrightUtilities.verifyToast({
   *     message: "Toastr message",
   *     closeAfterVerification: false,
   *     toastType: "error",
   *     timeout: 20_000,
   *     customPageContext: this.page,
   *   });
   * @endexample
  */
  verifyToast: ({
    message,
    toastType,
    closeAfterVerification,
    timeout,
    customPageContext
  }?: Partial<VerifyToastParams>) => Promise<void>;
  /**
   * @deprecated Use reload & waitForPageLoad instead.
   */
  /**
   *
   * Command to reload and wait for the API responses.
   *
   * @example 
   *
   *   // wait for 3 responses after reloading
   *   await neetoPlaywrightUtilities.reloadAndWait(3);
   * @endexample
  */
  reloadAndWait: (requestCount?: number, customPageContext?: Page, interceptMultipleResponsesProps?: Partial<Omit<InterceptMultipleResponsesParams, "times">>) => Promise<void>;
  /**
   *
   * Command to wait until the page has no loaders or spinners.
   *
   * @example 
   *
   *   await neetoPlaywrightUtilities.waitForPageLoad({
   *     visiblityTimeout = 35_000,
   *     customPageContext,
   *   });
   * @endexample
  */
  waitForPageLoad: ({
    visibilityTimeout,
    customPageContext
  }?: Partial<WaitForPageLoadParams>) => Promise<void>;
  /**
   *
   * Command to send an API request.
   *
   * @example 
   *
   *   await neetoPlaywrightUtilities.apiRequest({
   *     url: "/api/v1/tags",
   *     failOnStatusCode, // throws error for status codes other than 2xx and 3xx
   *     body, // request body
   *     method, // request method  "get" | "patch" | "post" | "put" | "delete"
   *     params, // request params
   *     headers, // aditional request headers
   *   });
   * @endexample
  */
  apiRequest: ApiRequest;
  /**
   *
   * Command to select an option from a select input. It retries until the select
   *
   * operation is completed. It takes the following parameters:
   *
   * label (optional): is the label for the menu and the select input container. Default is nui.
   *
   * value: is the value to be selected.
   *
   * page (optional): is the custom page context. Default is POM's page.
   *
   * options: is an object with the following optional parameters:
   *
   * visiblityTimeout: is the time to wait for the select input to be visible. Default is 2000ms.
   *
   * textAssertionTimeout: is the time to wait for the selected value to be visible in the select input. Default is 1000ms.
   *
   * retryTimeout: is the time to wait until the select operation is completed. Default is 20000ms.
   *
   * @example 
   *
   *   await neetoPlaywrightUtilities.selectOptionFromDropdown({
   *     label,
   *     value,
   *     options = {},
   *   });
   *   // or
   * 
   *   await neetoPlaywrightUtilities.selectOptionFromDropdown({
   *     label,
   *     value,
   *     options:{
   *       visiblityTimeout:200,
   *       textAssertionTimeout:1000,
   *       retryTimeout:20000
   *     },
   *   });
   * @endexample
  */
  selectOptionFromDropdown: ({
    label,
    value,
    page,
    options
  }: SelectOptionFromDropdownParams) => Promise<void>;
  /**
   *
   * Command to verify the value of a field. It can take either a single object or an array of objects, each representing a field and its expected value.
   *
   * @example 
   *
   * // verifyFieldValue with an array of field-value pairs as it's parameter
   *   await neetoPlaywrightUtilities.verifyFieldValue([
   *     { field: COMMON_SELECTORS.submitButton, value: "Submit" },
   *     {
   *       field: COMMON_SELECTORS.cancelButton,
   *       value: "cancel",
   *     },
   *   ]);
   * 
   *   // verifyFieldValue with a field-value object as it's parameter
   *   await neetoPlaywrightUtilities.verifyFieldValue({
   *     field: COMMON_SELECTORS.submitButton,
   *     value: "Submit",
   *   });
   * @endexample
  */
  verifyFieldValue: VerifyFieldValue;
  /**
   *
   * Command to search for a term and verify the results and its count.
   *
   * @example 
   *
   *   await neetoPlaywrightUtilities.searchAndVerify({
   *     searchTerm: "searchTerm",
   *     searchInputSelector: COMMON_SELECTORS.inputField,
   *     countSelector: COMMON_SELECTORS.count,
   *     countText: "43 items",
   *   });
   * @endexample
  */
  searchAndVerify: ({
    searchTerm,
    searchInputSelector,
    countSelector,
    countText
  }: SearchAndVerifyProps) => Promise<void>;
  /**
   *
   * Command to upload an image to image uploader and verify it. It takes the following parameters:
   *
   * localImagePath: Path to image.
   *
   * @example 
   *
   *   await neetoPlaywrightUtilities.uploadImage("../assets/image.png");
   * @endexample
  */
  uploadImage: (localImagePath: string) => Promise<void>;
  /**
   *
   * Function to upload a file by simulating a drop event onto a specified droppable zone on the page.
   *
   * React-dropzone, by default, uses File System API to upload files. Due to this we cannot use directly use waitForEvent("filechooser"). Ref: https://github.com/microsoft/playwright/issues/8850
   *
   * fileNameWithType: The name of the file to upload including its type extension (e.g., "images/example.png").
   *
   * assetsPath: The relative path to the assets directory where the file is located. Defaults to ../../../e2e/assets/.
   *
   * dispatchEvent: The type of event to dispatch to the droppable zone. Defaults to drop.
   *
   * droppableZone: The droppable zone element where the file will be dropped. Defaults to this.page.getByTestId("file-upload-body").
   *
   * @example 
   *
   * await uploadFileViaDispatch({
   *   fileNameWithType: "files/sample.pdf",
   * });
   * @endexample
  */
  uploadFileViaDispatch: ({
    fileNameWithType,
    assetsPath,
    dispatchEvent,
    droppableZone
  }: UploadFileViaDispatchProps) => Promise<void>;
  /**
   *
   * Method to hover on an element to show tooltip.
   *
   * triggerElement: Locator hovering on which tooltip should be shown.
   *
   * customPageContext(optional): Custom page context on which tooltip is shown. Default to this.page.
   *
   * @example 
   *
   * await hoverOnElement(triggerElement);
   * @endexample
  */
  hoverOnElement: (triggerElement: Locator, customPageContext?: Page) => Promise<void>;
  /**
   *
   * Method to verify content of the tooltip by hovering the trigger element.
   *
   * customPageContext (optional): The custom page on which tooltip needs to be verified. Defaults to this.page.
   *
   * triggerElement: The element hovering which the tooltip will be shown.
   *
   * content: The content of the tooltip container.
   *
   * @example 
   *
   * await verifyTooltip({
   *   triggerElement: page.getByTestId("tooltip"),
   *   content: "content of tooltip container",
   * });
   * @endexample
  */
  verifyTooltip: ({
    triggerElement,
    content,
    customPageContext
  }: VerifyTooltipProps) => Promise<void>;
  /**
   *
   * Method to verify title, content and the help link of help popover by hovering the trigger element.
   *
   * customPageContext (optional): The custom page on which tooltip needs to be verified. Defaults to this.page.
   *
   * triggerElement: The element hovering which the tooltip will be shown.
   *
   * title (optional): The title of the tooltip container.
   *
   * content (optional): The content of the tooltip container.
   *
   * helpURL (optional): The help URL in tooltip container navigating to the help docs.
   *
   * @example 
   *
   * await verifyHelpPopover({
   *   customPageContext: page,
   *   triggerElement: page.getByTestId("tooltip"),
   *   content: "content of tooltip container",
   * });
   * @endexample
  */
  verifyHelpPopover: ({
    triggerElement,
    title,
    content,
    helpURL,
    customPageContext
  }: VerifyHelpPopoverProps) => Promise<void>;
  /**
   *
   * Method to verify the help link on the page.
   *
   * helpURL: URL to match against the help link's href attribute. Matching is case-insensitive.
   *
   * @example 
   *
   * await neetoPlaywrightUtilities.verifyHelpText("https://help.neetoform.com/a-sj53mrx");
   * @endexample
  */
  verifyHelpText: (helpURL: string) => Promise<void>;
  /**
   *
   * Method to verify the term in the search term block.
   *
   * searchTerm (optional): The term need to be asserted in search term block. If not passed then it will assert the search term block to be hidden.
   *
   * @example 
   *
   * await verifySearchTermBlock("search term");
   * @endexample
  */
  verifySearchTermBlock: (searchTerm?: string) => Promise<void>;
  /**
   *
   * Used to save the changes made on the thank you page.
   *
   * @example 
   *
   * await thankYouPage.saveChanges();
   * @endexample
  */
  saveChanges: ({
    isPane,
    customPageContext,
    closeAfterVerification
  }?: SaveChangesProps) => Promise<[void, false | void, void]>;
  /**
   *
   * Method to hide the tooltip.
   *
   * triggerElement: Locator hovering on which tooltip was shown.
   *
   * customPageContext(optional): Custom page context on which tooltip is shown. Default to this.page.
   *
   * @example 
   *
   * await hideTooltip(triggerElement);
   * @endexample
  */
  hideTooltip: (triggerElement: Locator, customPageContext?: Page) => Promise<void>;
  /**
   *
   * Verifies the breadcrumbs in the header of a web page. It takes the following parameters:
   *
   * page: An instance of the Playwright Page class representing the web page where the breadcrumbs are located.
   *
   * titlesAndRoutes: An array of objects containing the titles and routes of the breadcrumbs to verify.
   *
   * @example 
   *
   *   import { Page } from "@playwright/test";
   *   import { headerUtils } from "@bigbinary/neeto-playwright-commons";
   * 
   *   const breadcrumbs = [
   *     { title: "Home", route: "/" },
   *     { title: "Category", route: "/category" },
   *     { title: "Subcategory", route: "/category/subcategory" }
   *   ];
   * 
   *   await headerUtils.verifyBreadcrumbs({
   *    page,
   *    titlesAndRoutes: breadcrumbs
   *   });
   * @endexample
  */
  verifyBreadcrumbs: (titlesAndRoutes: BreadcrumbTitleAndRoute$1[]) => Promise<void>;
  /**
   *
   * Function to upload a file by simulating a drop event on a droppable zone using the DataTransfer API.
   *
   * Note: React-dropzone, by default, uses File System API to upload files. Due to this we cannot use directly use waitForEvent("filechooser"). Ref: https://github.com/microsoft/playwright/issues/8850
   *
   * file: The File object to be uploaded. (e.g., using generateRandomFile()).
   *
   * dispatchEvent (optional): The DOM event to dispatch. Defaults to "drop".
   *
   * droppableZone (optional): A Playwright Locator representing the area to drop the file. Defaults to this.page.getByTestId("file-upload-body")
   *
   * @example 
   *
   * import { generateRandomFile } from "@utils/fileUtils";
   * 
   * const { file } = generateRandomFile({
   *   sizeInKB: 1024,
   *   fileType: "pdf",
   * });
   * 
   * await neetoPlaywrightUtilities.uploadFileViaDispatchV2({ file });
   * @endexample
  */
  uploadFileViaDispatchV2: ({
    droppableZone,
    dispatchEvent,
    file
  }: {
    file: File;
    dispatchEvent?: string;
    droppableZone?: Locator;
  }) => Promise<void>;
  /**
   *
   * Method to verify the presence and content of the unsaved changes modal.
   *
   * shouldLeavePage (optional): A boolean indicating whether to simulate leaving the page (true) or staying on the page (false).Defaults to false.
   *
   * @example 
   *
   * await neetoPlaywrightUtilities.verifyUnsavedChangesModal(true);
   * @endexample
  */
  verifyUnsavedChangesModal: (shouldLeavePage?: boolean) => Promise<void>;
}
declare class MemberApis {
  private neetoPlaywrightUtilities;
  private readonly teamsBaseUrl;
  constructor(neetoPlaywrightUtilities: CustomCommands);
  create: (body: Record<string, unknown>) => Promise<playwright_core.APIResponse | undefined>;
  jobStatus: (jobId: string) => Promise<playwright_core.APIResponse | undefined>;
  fetch: (params: ParamProps) => Promise<playwright_core.APIResponse | undefined>;
  update: (memberId: string, body: Record<string, unknown>) => Promise<playwright_core.APIResponse | undefined>;
  bulkUpdate: (body: Record<string, unknown>) => Promise<playwright_core.APIResponse | undefined>;
}
type Range<N extends number, Acc extends number[] = []> = Acc["length"] extends N ? Exclude<Acc[number], 0 | Acc["length"]> | N : Range<N, [...Acc, Acc["length"]]>;
interface MessageSearchCriteria {
  from: string;
  to: string;
  subject: string;
  body: string;
}
interface FindMessageFilterOptions {
  receivedAfter: Date;
  timeout: number;
  expectedEmailCount?: number;
}
interface Identifier {
  name: string;
  email: string;
}
interface Attachment {
  name: string;
  type: string;
}
interface FindOtpFromEmailParams {
  email: string;
  subjectSubstring?: string;
  timeout?: number;
  receivedAfter?: Date;
  expectedEmailCount?: number;
}
interface ListMessagesFilterCriteria {
  receivedAfter: Date;
  page: number;
  itemsPerPage: Range<100>;
}
interface MessageInferredData {
  links: string[] | null;
  codes: string[] | null;
  body: string;
}
interface AttachmentDetails {
  filename: string;
  type: string;
  content: Buffer;
  contentType: string;
}
interface FormattedList {
  html: MessageInferredData;
  text: MessageInferredData;
  id: string;
  from: Identifier[];
  to: Identifier[];
  cc: Identifier[];
  bcc: Identifier[];
  replyTo: Identifier[];
  received: string;
  subject: string;
  attachments: Attachment[];
  blobId: string;
}
declare class MailerUtils {
  private neetoPlaywrightUtilities;
  accountId: string | undefined;
  fastmailApi: FastmailApi;
  constructor(neetoPlaywrightUtilities: CustomCommands);
  private queryEmail;
  private getEmails;
  /**
   *
   * This method is used to list a set of messages matching a specific search criteria. It immediately returns the available list of messages matching the search criteria and doesn't wait until a matching message is found. Due to this reason delays in email deliveries should be accounted while using this method. This method is useful in asserting negative test cases and asserting a list of emails matching a certain pattern.
   *
   * Note: If the intention is to find a matching message within a certain time frame, prefer using the findMessage method.
   *
   * messageSearchCriteria: An object containing the search criteria for matching the messages. The object can contain the keys, from, to, subject and body. All the keys of the object are optional. The values of the object are of string type and are case-insensitive. The following key-value pairs can be used:
   *
   * from: The complete email address from which the email was sent.
   *
   * to: The complete email address to which the email was sent to.
   *
   * subject: A complete string or a substring used to match the subject of the email.
   *
   * body: A complete string or a substring used to match the body of the email.
   *
   * messageFilterCriteria (optional): An object containing the criteria which are used to filter the messages that match the search criteria. The object can contain the keys receivedAfter, page and itemsPerPage. The following key-value pairs can be used:
   *
   * receivedAfter: A JavaScript Date object used to filter the matching messages on the date-time of email delivery. Defaults to one hour before the method call.
   *
   * page: A number specifying the page number for paginating the results. Starts from 1 (default value). If a page number greater than the total number of matching emails is specified, an empty array will be returned.
   *
   * itemsPerPage: A number specifying the number of results per page. Default value is 50. The value can range from 1 to 100.
   *
   * Returns an array of objects with details about the emails matching the search and filter criteria. The object will have the following shape.
   *
   * html: Contains an object with the codes (Array of number strings having length greater than or equal to 4 in the email), links (Array of links in the email) and the body of the email with the HTML tags intact.
   *
   * text: Contains an object with the codes (Array of number strings having length greater than or equal to 4 in the email), links (Array of links in the email) and the body of the email with the HTML tags stripped off.
   *
   * id: A unique identifier string used to identify the email.
   *
   * from: An array of objects containing the name and email of the sender of the email.
   *
   * to: An array of objects containing the name and email of the receiver of the email.
   *
   * cc: An array of objects containing the name and email of the sender of the email as part of the cc list.
   *
   * replyTo: An array of objects containing the name and email of the individuals to whom replies should be directed.
   *
   * bcc: An array of objects containing the name and email of the recipients of the email as part of the bcc list.
   *
   * received: A JavaScript Date object containing the date-time of the email delivery.
   *
   * subject: A string containing the subject of the email.
   *
   * attachments: An array of objects containing the name and type of the attachment of the email.
   *
   * @example 
   *
   * test("sample test", async ({ mailerUtils }) => {
   *   const message = await mailerUtils.listMessages({
   *     to: fastmailEmailId,
   *     from: senderEmailId,
   *     subject: "login code",
   *     body: "neeto",
   *   }, {
   *     receivedAfter: new Date(),
   *     page: 1,
   *     itemsPerPage: 50,
   *   });
   * });
   * @endexample
  */
  listMessages: (messageSearchCriteria?: Partial<MessageSearchCriteria> | undefined, listMessagesFilterCriteria?: Partial<ListMessagesFilterCriteria> | undefined) => Promise<FormattedList[]>;
  getEmailIds: (messageSearchCriteria?: Partial<MessageSearchCriteria>, {
    timeout,
    receivedAfter,
    expectedEmailCount
  }?: Partial<FindMessageFilterOptions> | undefined, shouldThrowErrorOnTimeout?: boolean) => Promise<string[]>;
  /**
   *
   * This method is used to find a first email matching the search criteria. On top of the listMessage method, this method waits until a specific mail is received or the timeout is exceeded. This method is useful for fetching an email once an action is triggered since it waits for the message delivery and can be customized according to delays in email deliveries.
   *
   * messageSearchCriteria: An object containing the search criteria for matching the messages. The object can contain the keys, from, to, subject and body. All the keys of the object are optional. The values of the object are of string type and are case-insensitive. The following key-value pairs can be used:
   *
   * from: The complete email address from which the email was sent.
   *
   * to: The complete email address to which the email was sent to.
   *
   * subject: A complete string or a substring used to match the subject of the email.
   *
   * body: A complete string or a substring used to match the body of the email.
   *
   * messageFilterCriteria (optional): An object containing the criteria which are used to filter the messages that match the search criteria. The object can contain the keys receivedAfter, page and itemsPerPage. The following key-value pairs can be used:
   *
   * receivedAfter: A JavaScript Date object used to filter the matching messages on the date-time of email delivery. Defaults to one hour before the method call.
   *
   * timeout: A number indicating the number of milliseconds to retry fetching the message before timing out. Defaults to 10 seconds.
   *
   * shouldThrowErrorOnTimeout (optional): A boolean value indicating whether the method show throw an error if a matching message is not found within the timeout time. If set to false, no error is thrown if the timeout is exceeded and just returns an empty object. Defaults to true.
   *
   * Returns an object with details about the first email matching the search and filter criteria. The object will have the following shape.
   *
   * html: Contains an object with the codes (Array of number strings having length greater than or equal to 4 in the email), links (Array of links in the email) and the body of the email with the HTML tags intact.
   *
   * text: Contains an object with the codes (Array of number strings having length greater than or equal to 4 in the email), links (Array of links in the email) and the body of the email with the HTML tags stripped off.
   *
   * id: A unique identifier string used to identify the email.
   *
   * from: An array of objects containing the name and email of the sender of the email.
   *
   * to: An array of objects containing the name and email of the receiver of the email.
   *
   * cc: An array of objects containing the name and email of the sender of the email as part of the cc list.
   *
   * replyTo: An array of objects containing the name and email of the individuals to whom replies should be directed.
   *
   * bcc: An array of objects containing the name and email of the recipients of the email as part of the bcc list.
   *
   * received: A JavaScript Date object containing the date-time of the email delivery.
   *
   * subject: A string containing the subject of the email.
   *
   * @example 
   *
   * test("sample test", async ({ mailerUtils }) => {
   *   const message = await mailerUtils.listMessages({
   *     to: fastmailEmailId,
   *     from: senderEmailId,
   *     subject: "login code",
   *     body: "neeto",
   *   }, {
   *     receivedAfter: new Date(),
   *     timeout: 60 * 1000,
   *   }, false);
   * });
   * @endexample
  */
  findMessage: (messageSearchCriteria?: Partial<MessageSearchCriteria>, {
    timeout,
    receivedAfter,
    expectedEmailCount
  }?: Partial<FindMessageFilterOptions> | undefined, shouldThrowErrorOnTimeout?: boolean) => Promise<FormattedList | Record<string, never>>;
  /**
   *
   * A helper method that is used to find the first code value from the matching email body. This method has been built to match the Neeto OTP emails.
   *
   * The method accepts the following named arguments:
   *
   * email: The recipient email address used to find the email
   *
   * subjectSubstring: The subject of the email used to match it. Defaults to the string is your login code to match Neeto OTP emails
   *
   * timeout: The timeout duration number in milliseconds, which when exceeded without finding matching emails, the method throws an error. Default to 2 minutes.
   *
   * receivedAfter: = A JavaScript Date object used to filter the matching messages on the date-time of email delivery. Defaults to the time of method call.
   *
   * The method returns the OTP as a string from the matching email.
   *
  */
  findOtpFromEmail: ({
    email,
    subjectSubstring,
    timeout,
    receivedAfter,
    expectedEmailCount
  }: FindOtpFromEmailParams) => Promise<string | undefined>;
  /**
   *
   * Generates a random Fastmail email based on the value of the FASTMAIL_DOMAIN_NAME environment variable.
   *
   * Returns a random mixed-cased email ending with the FASTMAIL_DOMAIN_NAME.
   *
  */
  generateRandomEmail: () => string;
  /**
   *
   * This method is used to return the attachment based on the attachmentName of first email matching the search criteria. On top of the findMessage method, this method matches the attachment name with the attachments associated to the email. If any attachment matches then it will fetch the attachment details and return. If any attachment file name doesn't contain the substring attachmentName then it will throw an error saying No such attachment exists.
   *
   * attachmentName: A substring matching the attachment file name. It can be both with or without extension.
   *
   * messageSearchCriteria: An object containing the search criteria for matching the messages. The object can contain the keys, from, to, subject and body. All the keys of the object are optional. The values of the object are of string type and are case-insensitive. The following key-value pairs can be used:
   *
   * from: The complete email address from which the email was sent.
   *
   * to: The complete email address to which the email was sent to.
   *
   * subject: A complete string or a substring used to match the subject of the email.
   *
   * body: A complete string or a substring used to match the body of the email.
   *
   * messageFilterCriteria (optional): An object containing the criteria which are used to filter the messages that match the search criteria. The object can contain the keys receivedAfter, page and itemsPerPage. The following key-value pairs can be used:
   *
   * receivedAfter: A JavaScript Date object used to filter the matching messages on the date-time of email delivery. Defaults to one hour before the method call.
   *
   * timeout: A number indicating the number of milliseconds to retry fetching the message before timing out. Defaults to 10 seconds.
   *
   * shouldThrowErrorOnTimeout (optional): A boolean value indicating whether the method show throw an error if a matching message is not found within the timeout time. If set to false, no error is thrown if the timeout is exceeded and just returns an empty object. Defaults to true.
   *
   * Returns a promise object with details of attachment. The object will have the following shape.
   *
   * filename: A string representing the file name of attachment.
   *
   * type: A string representing the type of attachment file.
   *
   * content: A buffer with the content of attachment file.
   *
   * contentType: A string representing the content type of attachment file.
   *
   * @example 
   *
   * test("sample test", async ({ mailerUtils }) => {
   *   const message = await mailerUtils.getEmailAttachment(
   *     "invite",
   *     {
   *     to: fastmailEmailId,
   *     from: senderEmailId,
   *     subject: "Event details",
   *   }, {
   *     receivedAfter: new Date(),
   *     timeout: 60 * 1000,
   *   }, false);
   * });
   * @endexample
  */
  getEmailAttachment: (attachmentName: string, messageSearchCriteria?: Partial<MessageSearchCriteria>, {
    timeout,
    receivedAfter,
    expectedEmailCount
  }?: Partial<FindMessageFilterOptions> | undefined, shouldThrowErrorOnTimeout?: boolean) => Promise<AttachmentDetails | undefined>;
}
/**
 *
 * Decodes a QR code from an image file and returns the decoded string.
 *
 * filePath: A string representing the path to the image file containing the QR code.
 *
 * Returns: A string representing the decoded content of the QR code, or undefined if decoding fails.
 *
 * @example 
 *
 *   import { decodeQRCodeFromFile } from "@bigbinary/neeto-playwright-commons";
 * 
 *   const filePath = "path/to/qrCodeImage.png";
 * 
 *   const decodedString = await decodeQRCodeFromFile(filePath);
 * @endexample
*/
declare const decodeQRCodeFromFile: (filePath: string) => Promise<string | undefined>;
declare class QRCodeUtils {
  private page;
  constructor(page: Page);
  verifyQRCodeInFile: (qrCodeDownloadButton: Locator, qrCodeContent: string) => Promise<void>;
  verifyQRCodeOnScreen: (qrCodeCanvas: Locator, qrCodeContent: string) => Promise<void>;
  /**
   *
   * Decodes a QR code from an image file and returns the decoded string.
   *
   * filePath: A string representing the path to the image file containing the QR code.
   *
   * Returns: A string representing the decoded content of the QR code, or undefined if decoding fails.
   *
   * @example 
   *
   *   import { decodeQRCodeFromFile } from "@bigbinary/neeto-playwright-commons";
   * 
   *   const filePath = "path/to/qrCodeImage.png";
   * 
   *   const decodedString = await decodeQRCodeFromFile(filePath);
   * @endexample
  */
  decodeQRCodeFromFile: (filePath: string) => Promise<string | undefined>;
}
type Hex = Lowercase<`#${string}`>;
interface BaseThemeStyle {
  primaryColor: Hex;
  secondaryColor: Hex;
  primaryTextColor: Hex;
  secondaryTextColor: Hex;
  backgroundColor: Hex;
  cardBackgroundColor: Hex;
  cardTextColor: Hex;
  linkColor: Hex;
}
type BaseThemeStyleType = keyof BaseThemeStyle;
interface IntroPageThemeStyle {
  titleColor: Hex;
  descriptionColor: Hex;
  cardBackgroundColor: Hex;
  pageBackgroundColor: Hex;
  meetingCardBackgroundColor: Hex;
  meetingCardTextColor: Hex;
}
type IntroPageThemeStyleType = keyof IntroPageThemeStyle;
type ThemeCategory = "base" | "intro";
/**
 *
 * This function converts a hexadecimal color code to its RGBA equivalent.
 *
 * @example 
 *
 * import { hexToRGBA } from "@bigbinary/neeto-playwright-commons";
 * 
 *    // Convert hexadecimal color code to RGB
 *    const rgbaColor = hexToRGBA("#ffffff29");
 * 
 *    console.log(rgbaColor); // Output: 'rgba(255, 255, 255, 0.16)'
 * 
 *    // Convert another hexadecimal color code to RGB
 *    const anotherRGBAColor = hexToRGBA("#00ff00ff");
 * 
 *    console.log(anotherRGBAColor); // Output: 'rgba(0, 255, 0, 1)'
 * @endexample
*/
declare const hexToRGBA: (hex: string) => string;
declare class ColorPickerUtils {
  private page;
  constructor(page: Page);
  pickColor: (themeLocator: Locator, color: Hex) => Promise<void>;
  /**
   *
   * This function converts a hexadecimal color code to its RGBA equivalent.
   *
   * @example 
   *
   * import { hexToRGBA } from "@bigbinary/neeto-playwright-commons";
   * 
   *    // Convert hexadecimal color code to RGB
   *    const rgbaColor = hexToRGBA("#ffffff29");
   * 
   *    console.log(rgbaColor); // Output: 'rgba(255, 255, 255, 0.16)'
   * 
   *    // Convert another hexadecimal color code to RGB
   *    const anotherRGBAColor = hexToRGBA("#00ff00ff");
   * 
   *    console.log(anotherRGBAColor); // Output: 'rgba(0, 255, 0, 1)'
   * @endexample
  */
  hexToRGBA: (hex: string) => string;
}
interface CustomFixture {
  neetoPlaywrightUtilities: CustomCommands;
  page: Page;
  mailerUtils: MailerUtils;
  colorPicker: ColorPickerUtils;
  qrCodeUtils: QRCodeUtils;
}
type Commands = Fixtures<CustomFixture, PlaywrightWorkerArgs & PlaywrightWorkerOptions, PlaywrightTestArgs & PlaywrightTestOptions, PlaywrightWorkerArgs & PlaywrightWorkerOptions>;
declare const commands: Commands;
/**
 *
 * Function generates staging data for a specified product. It takes the following parameters:
 *
 * product (optional): A string representing the product for which staging data is being generated. Defaults to "invoice" if not provided.
 *
 * @example 
 *
 *   import { generateStagingData } from "@bigbinary/neeto-playwright-commons";
 * 
 *   // Generate staging data for the default product ("invoice")
 *   const stagingData = generateStagingData();
 * 
 *   console.log(stagingData);
 *   
 *   Output:
 *   {
 *     firstName: 'André',
 *     lastName: "O'Reilly",
 *     otp: 111111,
 *     domain: 'neetoinvoice.net',
 *     currentUserName: 'André O'Reilly', // Depends on IS_STAGING_ENV and CREDENTIALS
 *     businessName: 'cpt-invoice-0322153521234', // Timestamp will be different
 *     subdomainName: 'cpt-invoice-0322153521234', // Timestamp will be different if IS_STAGING_ENV is true, else 'spinkart'
 *     email: 'cpt12345+invoice+0322153521234@bigbinary.com' // OTP bypass key will be included if IS_STAGING_ENV is true, else CREDENTIALS.email
 *   }
 * 
 * @endexample
*/
declare const generateStagingData: (product?: string) => {
  firstName: string;
  lastName: string;
  otp: number;
  domain: string;
  currentUserName: string;
  businessName: string;
  subdomainName: string;
  email: string;
};
declare const _default: _playwright_test.TestType<_playwright_test.PlaywrightTestArgs & _playwright_test.PlaywrightTestOptions & Browser, _playwright_test.PlaywrightWorkerArgs & _playwright_test.PlaywrightWorkerOptions>;
declare const i18nFixture: Fixtures<PlaywrightTestArgs & PlaywrightTestOptions, I18nPlaywrightFixture, PlaywrightTestArgs & PlaywrightTestOptions, PlaywrightWorkerArgs & PlaywrightWorkerOptions>;
interface VerifyAdminPanelCardProps$1 {
  cardLocator: Locator;
  title: string;
  description: string;
}
declare class AdminPanelPage {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  t: TFunction;
  constructor(page: Page, neetoPlaywrightUtilities: CustomCommands);
  /**
   *
   * Used to verify the admin panel card details.
   *
   * cardLocator (required): The locator of the card to verify.
   *
   * title (required): The title of the card.
   *
   * description (required): The description of the card.
   *
   * @example 
   *
   * await rolesPage.verifyAdminPanelCard({
   *   description: "Roles card description",
   *   title: "Roles card title",
   *   cardLocator: page.getByTestId("roles-tab"),
   * });
   * @endexample
  */
  verifyAdminPanelCard: ({
    cardLocator,
    title,
    description
  }: VerifyAdminPanelCardProps$1) => Promise<[void, void, void]>;
}
declare class ThankYouPage {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  t: TFunction;
  constructor(page: Page, neetoPlaywrightUtilities: CustomCommands);
  /**
   *
   * Used to navigate to the thank you page.
   *
   * @example 
   *
   * await thankYouPage.navigateToThankYouPage();
   * @endexample
  */
  navigateToThankYouPage: () => Promise<void>;
  /**
   *
   * Used to save the changes made on the thank you page.
   *
   * @example 
   *
   * await thankYouPage.saveChanges();
   * @endexample
  */
  saveChanges: () => Promise<void>;
  /**
   *
   * Used to verify the preview of the uploaded image.
   *
   * imagePath (required): The relative path to the image file.
   *
   * imageName (required): The name of the image file.
   *
   * @example 
   *
   * await thankYouPage.verifyThankYouImage( imagePath, imageName );
   * @endexample
  */
  verifyThankYouImage: (imagePath: string, imageName: string) => Promise<void>;
  /**
   *
   * Used to verify the Neeto editor menu.
   *
   * @example 
   *
   * await thankYouPage.verifyEditorMenu();
   * @endexample
  */
  verifyEditorMenu: () => Promise<void>;
  /**
   *
   * Used to verify the preview of the message.
   *
   * thankYouMessage (required): The message to be displayed on the thank you page.
   *
   * @example 
   *
   * await thankYouPage.verifyThankYouMessage( thankYouMessage );
   * @endexample
  */
  verifyThankYouMessage: (thankYouMessage: string) => Promise<void>;
  /**
   *
   * Used to add an external redirect link.
   *
   * customRedirectUrl (required): The URL to which users will be redirected after submission or booking.
   *
   * @example 
   *
   * await thankYouPage.addRedirectUrl( customRedirectUrl );
   * @endexample
  */
  addRedirectUrl: (customRedirectUrl: string) => Promise<void>;
}
type EmbedType = "inline" | "floatingPopup" | "elementClick";
type EmbedTypeV2 = "inline" | "floatingPopup" | "elementPopup";
type GetByRoleOptions = {
  checked?: boolean;
  disabled?: boolean;
  exact?: boolean;
  expanded?: boolean;
  includeHidden?: boolean;
  level?: number;
  name?: string | RegExp;
  pressed?: boolean;
  selected?: boolean;
};
type InlineCustomizationOptions = {
  embedHeight: string;
  embedWidth: string;
  embedDivContainerId: string;
};
type VerifyInlineCustomizationParams = {
  headingTestId: string;
  /**
   * @deprecated This parameter is deprecated.
   */
  inlineEmbedInterceptParams?: Partial<InterceptMultipleResponsesParams>;
  customizationOptions: InlineCustomizationOptions;
};
type FloatingPopupCustomizationOptions = {
  buttonText: string;
  buttonColorHex: string;
  buttonTextColorHex: string;
  buttonPosition: "Bottom left" | "Bottom right";
  showIcon?: boolean;
};
type ElementClickCustomizationOptions = {
  customId: string;
};
type initializeEmbedPageParams = {
  embedType: EmbedType;
  embedCode: string;
  customElementText?: string;
};
type InitializeEmbedPageParamsV2 = {
  embedType: EmbedTypeV2;
  embedCode: string;
  customElementText?: string;
};
type EmbedBasePageConstructorParams = {
  context: BrowserContext;
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  appName: string;
};
declare class EmbedBase {
  context: BrowserContext;
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  appName: string;
  t: TFunction;
  embedTestPage: Page;
  embedTestPageType: EmbedType | EmbedTypeV2;
  embeddedFrame: FrameLocator;
  filePath: string;
  codeBlock: Locator;
  previewTab: Locator;
  constructor({
    context,
    page,
    neetoPlaywrightUtilities,
    appName
  }: EmbedBasePageConstructorParams);
  /**
   * @deprecated This method is deprecated. Use initializeEmbedPageV2 instead.
   */
  /**
   *
   * Initializes the embed test page. It takes the following parameters:
   *
   * embedType: Type of embedded content (inline, floatingPopup, elementClick).
   *
   * embedCode: Embed code.
   *
   * customElementText: Custom text for element click type (default: "Click here").
   *
   * @example 
   *
   *   await embedBase.initializeEmbedPage({
   *     embedType: "inline",
   *     embedCode: "<iframe src='example.com'></iframe>"
   *   });
   *   // OR
   * 
   *    await embedBase.initializeEmbedPage({
   *     embedType: "inline",
   *     embedCode: "<iframe src='example.com'></iframe>",
   *     customElementText:"Click here"
   *   });
   * @endexample
  */
  initializeEmbedPage: ({
    embedType,
    embedCode,
    customElementText
  }: initializeEmbedPageParams) => Promise<Page>;
  /**
   *
   * Initializes the embed test page. It takes the following parameters:
   *
   * embedType: Type of embedded content (inline, floatingPopup, elementPopup).
   *
   * embedCode: Embed code.
   *
   * customElementText: Custom text for element click type (default: "Click here").
   *
   * @example 
   *
   *   await embedBase.initializeEmbedPageV2({
   *     embedType: "inline",
   *     embedCode: "<iframe src='example.com'></iframe>"
   *   });
   *   // OR
   * 
   *    await embedBase.initializeEmbedPageV2({
   *     embedType: "inline",
   *     embedCode: "<iframe src='example.com'></iframe>",
   *     customElementText:"Click here"
   *   });
   * @endexample
  */
  initializeEmbedPageV2: ({
    embedType,
    embedCode,
    customElementText
  }: InitializeEmbedPageParamsV2) => Promise<Page>;
  /**
   *
   * Closes the embed modal and page.
   *
   * @example 
   *
   *   await embedBase.closeEmbedModalAndPage();
   * @endexample
  */
  closeEmbedModalAndPage: () => Promise<void>;
  /**
   *
   * Clicks on the popup button.
   *
   * It takes the following parameters as an object:
   *
   * checked: Indicates whether an element is checked.
   *
   * disabled: Indicates whether an element is disabled.
   *
   * exact: Indicates whether an exact match is required.
   *
   * expanded: Indicates whether an element is expanded.
   *
   * includeHidden: Indicates whether hidden elements should be included.
   *
   * level: Specifies the level of the element.
   *
   * name: Specifies the name of the element, which can be a string or a regular expression.
   *
   * pressed: Indicates whether an element is pressed.
   *
   * selected: Indicates whether an element is selected.
   *
   * @example 
   *
   *   await embedBase.clickOnPopupButton({ name: "Popup Button" });
   *   //OR
   *   await embedBase.clickOnPopupButton({
   *     checked: true,
   *     disabled: false,
   *     exact: true,
   *     expanded: false,
   *     includeHidden: false,
   *     level: 2,
   *     name: "Popup Button",
   *     pressed: false,
   *     selected: true
   *   });
   * @endexample
   * /**
   *
  */
  clickOnPopupButton: (popUpButtonSelectorOptions: GetByRoleOptions) => Promise<void>;
  /**
   * @deprecated This method is deprecated. Use copyEmbedScriptV2 instead.
   */
  /**
   *
   * Copies the embed script. It takes the following parameters:
   *
   * embedLabel: Label for the embed script.
   *
   * @example 
   *
   *   const embedScript = await embedBase.copyEmbedScript({ embedLabel: "Embed Script" });
   * @endexample
  */
  copyEmbedScript: ({
    embedLabel
  }: {
    embedLabel: string;
  }) => Promise<string>;
  /**
   *
   * Copies the embed script. It takes the following parameters:
   *
   * embedType: Type of embedded content (inline, floatingPopup, elementPopup).
   *
   * @example 
   *
   *   const embedScript = await embedBase.copyEmbedScript("inline");
   * @endexample
   * /**
   *
  */
  copyEmbedScriptV2: (embedType: EmbedTypeV2) => Promise<string>;
  /**
   * @deprecated This method is deprecated. Use selectEmbedTypeV2 instead.
   */
  /**
   *
   * Selects the embed type. It takes the following parameters:
   *
   * embedLabel: Label for the embed type.
   *
   * @example 
   *
   *   await embedBase.selectEmbedType("Inline Embed");
   * @endexample
  */
  selectEmbedType: (embedLabel: string) => Promise<void>;
  /**
   *
   * Selects the embed type. It takes the following parameters:
   *
   * embedType: Type of embedded content (inline, floatingPopup, elementPopup).
   *
   * @example 
   *
   *   await embedBase.selectEmbedType("inline");
   * @endexample
  */
  selectEmbedTypeV2: (embedType: EmbedTypeV2) => Promise<void>;
  /**
   *
   * Verifies inline customization of embedded content. It takes the following parameters:
   *
   * headingTestId: Test ID of the heading element.
   *
   * inlineEmbedInterceptParams: (Deprecated) Parameters for intercepting multiple responses.
   *
   * customizationOptions: Options for customization.
   *
   * @example 
   *
   *   await embedBase.verifyInlineCustomization({
   *     headingTestId: "heading",
   *     inlineEmbedInterceptParams: { urlRegex: /example\.com/, status: 200 },
   *     customizationOptions: { embedHeight: "100", embedWidth: "100", embedDivContainerId: "container" }
   *   });
   * @endexample
  */
  verifyInlineCustomization: ({
    headingTestId,
    inlineEmbedInterceptParams,
    customizationOptions
  }: VerifyInlineCustomizationParams) => Promise<void>;
  backToEmbedSelection: () => Promise<void>;
  /**
   *
   * Verifies floating popup customization of embedded content. It takes the following parameters:
   *
   * customizationOptions: Options for customization.
   *
   * @example 
   *
   *   await embedBase.verifyFloatingPopupCustomization({
   *     buttonText: "Popup Button",
   *     buttonColorHex: "#FFFFFF",
   *     buttonTextColorHex: "#000000",
   *     buttonPosition: "Bottom left"
   *   });
   * @endexample
  */
  verifyFloatingPopupCustomization: (customizationOptions: FloatingPopupCustomizationOptions) => Promise<void>;
  /**
   *
   * Verifies element click customization of embedded content. It takes the following parameters:
   *
   * customizationOptions: Options for customization.
   *
   * @example 
   *
   *   await embedBase.verifyElementClickCustomization({ customId: "custom-element" });
   * @endexample
  */
  verifyElementClickCustomization: (customizationOptions: ElementClickCustomizationOptions) => Promise<void>;
  /**
   *
   * Expects multiple texts to be present in the code block. It takes the following parameters:
   *
   * containTextOptions: Array of strings or regex patterns to be checked in the code block.
   *
   * @example 
   *
   *   await embedBase.expectMultipleTextsInCodeblock([
   *     "Text1", "Text2", /Pattern/
   *   ]);
   * @endexample
  */
  expectMultipleTextsInCodeblock: (containTextOptions: [string | RegExp, string | RegExp, ...(string | RegExp)[]]) => Promise<void>;
}
interface HelpAndProfilePageInitializerProps {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  chatApiBaseURL: string;
  kbDocsBaseURL: string;
  changelogBaseURL: string;
}
type NeetoProducts = "Form" | "Cal" | "Auth" | "KB" | "Desk" | "Chat" | "Invoice" | "Playdash" | "Pay" | "Testify" | "Record" | "Site" | "Runner" | "Wireframe" | "Engage" | "Quiz" | "Replay" | "Planner" | "CRM" | "Publish" | "Course" | "Code" | "Git";
declare class HelpAndProfilePage {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  chatApiBaseURL: string;
  kbDocsBaseURL: string;
  changelogBaseURL: string;
  neetoChatWidget: Locator;
  neetoChatFrame: FrameLocator;
  neetoChatSpinner: Locator;
  t: TFunction;
  profileSectionButton: Locator;
  constructor({
    page,
    neetoPlaywrightUtilities,
    chatApiBaseURL,
    kbDocsBaseURL,
    changelogBaseURL
  }: HelpAndProfilePageInitializerProps);
  private hoverOnBody;
  openHelpCenterV2: () => Promise<void>;
  private openLiveChatAndVerify;
  /**
   *
   * The function reloads the page, opens the chat interface, closes and reopens the chat frame, initiates a new conversation, and verifies the conversation window content.
   *
   * @example 
   *
   *   await helpAndProfilePage.openAndVerifyChatWidgetV2();
   * @endexample
  */
  openAndVerifyChatWidgetV2: () => Promise<void>;
  /**
   *
   * Opens and verifies the help articles in Help Center.
   *
   * @example 
   *
   *   await helpAndProfilePage.openAndVerifyHelpArticlesV2();
   * @endexample
  */
  openAndVerifyHelpArticlesV2: () => Promise<void>;
  private openChangelogPaneV2;
  /**
   *
   * Opens and verifies the changelog in Help Center.
   *
   * @example 
   *
   *   await helpAndProfilePage.openAndVerifyChangelogV2();
   * @endexample
  */
  openAndVerifyChangelogV2: () => Promise<void>;
  private formatKeyboardShortcut;
  /**
   *
   * Opens and verifies the keyboard shortcuts pane in Help Center. It takes the following parameters:
   *
   * productShortcuts: Array of objects containing description and sequence of product shortcuts.
   *
   * osPlatform: Platform for keyboard shortcuts ("mac" or "windows").
   *
   * @example 
   *
   *   await helpAndProfilePage.openAndVerifyKeyboardShortcutsPaneV2(productShortcuts, "windows");
   * @endexample
  */
  openAndVerifyKeyboardShortcutsPaneV2: (productShortcuts: {
    description: string;
    sequence: string;
  }[], osPlatform?: "mac" | "windows") => Promise<void>;
  /**
   *
   * Opens and verifies the app switcher in Help Center.
   *
   * @example 
   *
   *   await helpAndProfilePage.openAppSwitcherAndVerifyV2();
   * @endexample
  */
  openAppSwitcherAndVerifyV2: () => Promise<void>;
  private openAuthLinkAndVerify;
  /**
   *
   * Verifies the profile and organization links in Help Center.
   *
   * @example 
   *
   *   await helpAndProfilePage.verifyProfileAndOrganizationLinksV2();
   * @endexample
  */
  verifyProfileAndOrganizationLinksV2: () => Promise<void>;
  /**
   *
   * Verifies logout functionality in Help Center.
   *
   * @example 
   *
   *   await helpAndProfilePage.verifyLogout();
   * @endexample
  */
  verifyLogoutV2: () => Promise<void>;
  private openAuthLinkAndVerifyV1;
  verifyProfileAndOrganizationLinksV3: () => Promise<void>;
  /**
   *
   * Opens and verifies the Neeto status in Help Center.
   *
   * appName: Name of the application.
   *
   * @example 
   *
   *   await helpAndProfilePage.openAndVerifyStatus("Auth");
   * @endexample
  */
  openAndVerifyStatus: (appName: NeetoProducts) => Promise<void>;
  /**
   *
   * Opens and verifies the Neeto community in Help Center.
   *
   * @example 
   *
   *   await helpAndProfilePage.openAndVerifyCommunity();
   * @endexample
  */
  openAndVerifyCommunity: () => Promise<void>;
}
type IntegrationStatus = "connected" | "disconnected";
type PartialInterceptMultipleResponsesParams$1 = Partial<InterceptMultipleResponsesParams>;
interface IntegrationBaseParams {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  integration: string;
  connectedHeader?: string;
  connectHeader?: string;
  pageloaderTimeout?: number;
  integrationRouteIndex?: string;
  integrationRouteResponsesParams?: PartialInterceptMultipleResponsesParams$1;
}
declare class IntegrationBase {
  readonly page: Page;
  readonly neetoPlaywrightUtilities: CustomCommands;
  readonly t: TFunction;
  readonly integration: string;
  readonly integrationCard: Locator;
  readonly connectHeader: string;
  readonly connectedHeader: string;
  pageloaderTimeout: number;
  integrationRouteIndex: string;
  integrationRouteResponsesParams: PartialInterceptMultipleResponsesParams$1;
  constructor({
    page,
    neetoPlaywrightUtilities,
    integration,
    connectHeader,
    connectedHeader,
    pageloaderTimeout,
    integrationRouteIndex,
    integrationRouteResponsesParams
  }: IntegrationBaseParams);
  /**
   *
   * Disconnects an active integration. It takes the following parameters:
   *
   * interceptMultipleResponsesParams: Optional parameter for intercepting multiple responses.
   *
   * @example 
   *
   *   await integrationBase.disconnect();
   *   // OR
   *   await integrationBase.disconnect({
   *     responseUrl: "/auth";
   *     times:1;
   *     baseUrl: "https://www.zoom.com";
   *     responseStatus: 200;
   *   });
   * @endexample
  */
  disconnect: (interceptMultipleResponsesParams?: PartialInterceptMultipleResponsesParams$1) => Promise<void>;
  /**
   *
   * Connects an integration. It takes the following parameters:
   *
   * skipGoTo: Boolean indicating whether to skip navigating to integration index (default: false).
   *
   * @example 
   *
   *   await integrationBase.connect();
   *   // OR
   *   await integrationBase.connect(true);
   * @endexample
  */
  connect: (skipGoTo?: boolean) => Promise<void>;
  /**
   *
   * Verifies the integration status. It takes the following parameters:
   *
   * status: Integration status ("connected" or "disconnected") (default: "connected").
   *
   * visibilityTimeout: Timeout in milliseconds to wait for integration status tag to become visible.
   *
   * @example 
   *
   *   await integrationBase.verifyIntegrationStatus();
   *   // OR
   *   await integrationBase.verifyIntegrationStatus("disconnected");
   * @endexample
  */
  verifyIntegrationStatus: (status?: IntegrationStatus, visibilityTimeout?: number) => Promise<void>;
  /**
   *
   * Clicks on the integration card.
   *
   * @example 
   *
   *   await integrationBase.clickOnIntegrationCard();
   * @endexample
  */
  clickOnIntegrationCard: () => Promise<void>;
  /**
   *
   * Navigates to the integration index route.
   *
   * @example 
   *
   *   await integrationBase.gotoIntegrationIndex();
   * @endexample
  */
  gotoIntegrationIndex: () => Promise<void>;
}
type StagingConsentFlowParams = {
  abortFlow?: boolean;
  allowPermissions: boolean;
};
type GooglePageParams = {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  integration: string;
  integrationRouteIndex?: string;
};
declare class GooglePage extends IntegrationBase {
  totp: TOTP;
  t: TFunction;
  constructor({
    page,
    neetoPlaywrightUtilities,
    integration,
    integrationRouteIndex
  }: GooglePageParams);
  /**
   *
   * Connects to the Google account for integration.
   *
   * appName: Name of the application.
   *
   * @example 
   *
   * await googlePage.connectGoogleAccount("neetoForm");
   * @endexample
  */
  connectGoogleAccount: (appName: string) => Promise<void>;
  /**
   *
   * Selects the Google account to be used during the integration. If a verification code is required (e.g., for 2FA), it enters the TOTP code.
   *
   * appName: Name of the application.
   *
   * @example 
   *
   * await googlePage.selectGoogleAccount("neetoForm");
   * @endexample
  */
  selectGoogleAccount: (appName: string) => Promise<void>;
  /**
   *
   * Automates the login process to a Google account, filling in the email, password, and handling 2FA (Two-Factor Authentication) via TOTP.
   *
   * @example 
   *
   * await googlePage.loginToGoogle();
   * @endexample
  */
  loginToGoogle: () => Promise<void>;
  enterTotpCode: (locator: Locator) => Promise<void>;
  /**
   *
   * Logs out of the Google account by navigating to the account settings and clicking the "Sign Out" button.
   *
   * @example 
   *
   * await googlePage.logoutFromGoogle()
   * @endexample
  */
  logoutFromGoogle: () => Promise<void>;
  /**
   *
   * Disconnects from Slack integration and verifies disconnection.
   *
   * @example 
   *
   * await slackPage.disconnectAndVerifyIntegration();
   * @endexample
  */
  disconnectAndVerifyIntegration: () => Promise<void>;
  /**
   *
   * Handles the user consent process for Google account. It handles navigating screens, granting permissions, and aborting the flow if needed.
   *
   * abortFlow (optional): Cancel the integration. Defaults to false.
   *
   * allowPermissions: Give permissions to the application to access the google account. Defaults to true.
   *
   * @example 
   *
   * await googlePage.stagingConsentFlow({
   *   abortFlow: true,
   *   allowPermissions: false,
   * })
   * @endexample
  */
  stagingConsentFlow: ({
    abortFlow,
    allowPermissions
  }?: Partial<StagingConsentFlowParams>) => Promise<void>;
  private handleNotVerifiedPage;
}
type AsyncNoArgsFunction = () => Promise<void>;
type RedirectUrl = string | RegExp | ((url: URL) => boolean);
type PartialInterceptMultipleResponsesParams = Partial<InterceptMultipleResponsesParams>;
type UpdateConfigureSlackChannelParams = {
  newSlackChannel: string;
  interceptMultipleResponsesParams?: PartialInterceptMultipleResponsesParams;
  refreshInterceptMultipleResponsesParams?: PartialInterceptMultipleResponsesParams;
  refreshChannelList?: boolean;
};
type SlackPageParams = {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  integrationRouteIndex?: string;
};
interface CreateNewSlackChannelParams {
  channelName: string;
  kind?: "public" | "private";
}
declare class SlackPage extends IntegrationBase {
  slackWebappPage: Page;
  slackWebappPageDataQa: (dataQa: string | [string, string]) => Locator;
  constructor({
    page,
    neetoPlaywrightUtilities,
    integrationRouteIndex
  }: SlackPageParams);
  /**
   *
   * Closes the coach mark modal, upgrades banner, and permissions banner that appears when a user logs in to Slack for the first time, if present. It can be useful in scenarios where the banners are blocking the view of the elements that needs to be interacted with. It takes the following parameters:
   *
   * slackWebappPage (optional): Playwright Page object for Slack web app.
   *
   * @example 
   *
   * await slackPage.setupCloseHandlers(slackWebappPageInstance);
   * @endexample
  */
  setupCloseHandlers: (slackWebappPage?: Page) => Promise<void>;
  /**
   *
   * Connects to slack integration and verifies the connection. It takes the following parameters:
   *
   * redirectUrl: URL to redirect after connecting.
   *
   * customSteps (optional): Custom steps to perform after connection.
   *
   * channelToConfigure (optional): Channel to configure.
   *
   * @example 
   *
   * await slackPage.connectAndVerifyIntegration(
   *   /example\.com/,
   *   customSteps,
   *   "general"
   * );
   * @endexample
  */
  connectAndVerifyIntegration: (redirectUrl: RedirectUrl, customSteps?: AsyncNoArgsFunction, channelToConfigure?: string) => Promise<void>;
  /**
   *
   * Disconnects from Slack integration and verifies disconnection.
   *
   * @example 
   *
   * await slackPage.disconnectAndVerifyIntegration();
   * @endexample
  */
  disconnectAndVerifyIntegration: () => Promise<void>;
  /**
   *
   * Updates and configures slack channel. It takes the following parameters:
   *
   * newSlackChannel: The name of the slack channel to which the update will be applied.
   *
   * interceptMultipleResponsesParams (optional): Parameters for intercepting multiple responses.
   *
   * refreshInterceptMultipleResponsesParams (optional): Parameters for refreshing intercepting multiple responses.
   *
   * refreshChannelList (optional): Whether to refresh the channel list.
   *
   * @example 
   *
   *   await slackPage.updateConfigureSlackChannel({
   *     newSlackChannel: "example-channel",
   *     refreshChannelList: true
   *   });
   *   //or
   *   await slackPage.updateConfigureSlackChannel({
   *     newSlackChannel: "example-channel",
   *     refreshChannelList: true,
   *     refreshInterceptMultipleResponsesParams:{
   *       responseUrl: "/auth";
   *       times:1;
   *       baseUrl: "https://www.zoom.com";
   *       responseStatus: 200;
   *     },
   *     interceptMultipleResponsesParams:{
   *       responseUrl: "/auth";
   *       times:1;
   *       baseUrl: "https://www.zoom.com";
   *       responseStatus: 200;
   *     }
   *   });
   * @endexample
  */
  updateConfigureSlackChannel: ({
    newSlackChannel,
    interceptMultipleResponsesParams,
    refreshInterceptMultipleResponsesParams,
    refreshChannelList
  }: UpdateConfigureSlackChannelParams) => Promise<void>;
  /**
   *
   * Clicks on the refresh button to update the channel list.
   *
   * @example 
   *
   *   await slackPage.clickOnChannelListRefreshButton();
   * @endexample
  */
  clickOnChannelListRefreshButton: () => Promise<void>;
  /**
   *
   * Note: Either ENV variables SLACK_WORKSPACE, SLACK_LOGIN_PASSWORD and
   *
   * SLACK_LOGIN_EMAIL is required for this method to work or custom credentials
   *
   * workspace, loginPassword and loginEmail must be passed.
   *
   * Logs into slack web app. It takes the following parameters:
   *
   * slackWebappPage: Playwright Page object for Slack web app.
   *
   * customCredentials (optional): Custom credentials for logging in.
   *
   * @example 
   *
   * await slackPage.loginToSlackWebapp(slackWebappPageInstance);
   * // OR
   * await slackPage.loginToSlackWebapp(slackWebappPageInstance, {
   *   loginEmail: "johndoe@gmail.com",
   *   loginPassword: "123456789",
   *   workspace: "your-workspace-name",
   * });
   * @endexample
  */
  loginToSlackWebapp: (slackWebappPage: Page, customCredentials?: Record<"workspace" | "loginPassword" | "loginEmail", string | undefined>) => Promise<void>;
  /**
   *
   * Logs out from slack web app.
   *
   * @example 
   *
   * await slackPage.logoutFromSlackWebApp();
   * @endexample
  */
  logoutFromSlackWebApp: () => Promise<void>;
  /**
   *
   * Navigates to a Slack channel. It takes the following parameters:
   *
   * slackChannel: Name of the Slack channel.
   *
   * @example 
   *
   * await slackPage.goToSlackChannel("general");
   * @endexample
  */
  goToSlackChannel: (slackChannel: string) => Promise<void>;
  /**
   *
   * Creates a new slack channel. It takes the following parameters:
   *
   * channelName: Name of the new Slack channel.
   *
   * kind: Type of the new Slack channel (public or private, optional).
   *
   * @example 
   *
   * await slackPage.createNewSlackChannel({
   *   channelName: "new-channel",
   *   kind: "public",
   * });
   * @endexample
  */
  createNewSlackChannel: ({
    channelName,
    kind
  }: CreateNewSlackChannelParams) => Promise<void>;
  /**
   *
   * Deletes a slack channel. It takes the following parameters:
   *
   * channel: Name of the Slack channel to delete.
   *
   * @example 
   *
   * await slackPage.deleteSlackChannel("old-channel");
   * @endexample
  */
  deleteSlackChannel: (channel: string) => Promise<void>;
}
interface WebhooksPageParams {
  page: Page;
  request: APIRequestContext;
  neetoPlaywrightUtilities: CustomCommands;
  context: BrowserContext;
}
type CallbackFunction = (args: Record<string, unknown>) => void;
interface VerifyWebhookResponseParams extends Record<string, unknown> {
  callback?: CallbackFunction;
  parseFullResponseContent?: boolean;
  webhookToken: string;
  timeout?: number;
}
interface VerifyWebhookDeliveriesParams extends Record<string, unknown> {
  callback: CallbackFunction;
}
interface VerifyWebhookDeliveryByEventParams extends Record<string, unknown> {
  event: string;
  callbackToVerifyDeliveries: (args: Record<string, unknown>) => void;
}
declare class WebhooksPage {
  page: Page;
  request: APIRequestContext;
  context: BrowserContext;
  neetoPlaywrightUtilities: CustomCommands;
  t: TFunction;
  constructor({
    page,
    request,
    neetoPlaywrightUtilities,
    context
  }: WebhooksPageParams);
  /**
   *
   * Retrieves the webhook URL and token from a third-party site.
   *
   * Returns: Object containing webhook site URL and token.
   *
   * @example 
   *
   *   const { webhookSiteURL, webhookToken } = await webhooksPage.getWebhookURL();
   * @endexample
  */
  getWebhookURL: () => Promise<{
    webhookSiteURL: string;
    webhookToken: string | undefined;
  }>;
  /**
   *
   * Adds a webhook using the provided webhook site URL. It takes the following parameters:
   *
   * webhookSiteURL: URL of the webhook site.
   *
   * @example 
   *
   *   await webhooksPage.addWebhook({ webhookSiteURL: "https://example.com/webhook" });
   * @endexample
  */
  addWebhook: ({
    webhookSiteURL
  }: {
    webhookSiteURL: string;
  }) => Promise<void>;
  /**
   *
   * Verifies the latest webhook response. It takes the following parameters:
   *
   * callback: Callback function to execute on parsed response.
   *
   * webhookToken: Token of the webhook.
   *
   * parseFullResponseContent: Option to pass the full response content to the callback function. Defaults to false.
   *
   * Other parameters to be passed to the callback function.
   *
   * timeout(optional): Timeout in milliseconds to fetch the latest response. Default is 20_000.
   *
   * @example 
   *
   *   await webhooksPage.verifyLatestWebhookResponse({
   *     callback: ({ parsedResponse }) => console.log(parsedResponse),
   *     webhookToken: "exampleToken",
   *     timeout: 35_000
   *   });
   * @endexample
  */
  verifyLatestWebhookResponse: ({
    callback,
    webhookToken,
    parseFullResponseContent,
    timeout,
    ...otherParams
  }: VerifyWebhookResponseParams) => Promise<void>;
  /**
   *
   * Verifies webhook deliveries. It takes the following parameters:
   *
   * callback: Callback function to execute on parsed response.
   *
   * Other parameters to be passed to the callback function.
   *
   * @example 
   *
   *   await webhooksPage.verifyWebhookDeliveries({
   *     callback: ({ parsedResponse }) => console.log(parsedResponse)
   *   });
   * @endexample
  */
  verifyWebhookDeliveries: ({
    callback,
    ...otherParams
  }: VerifyWebhookDeliveriesParams) => Promise<void>;
  /**
   *
   * Verifies webhook delivery by event. It takes the following parameters:
   *
   * event: Event name.
   *
   * callbackToVerifyDeliveries: Callback function to execute on parsed response.
   *
   * Other parameters to be passed to the callback function.
   *
   * @example 
   *
   *   await webhooksPage.verifyWebhookDeliveryByEvent({
   *     event: "eventName",
   *     callbackToVerifyDeliveries: ({ parsedResponse }) => console.log(parsedResponse)
   *   });
   * @endexample
  */
  verifyWebhookDeliveryByEvent: ({
    event,
    callbackToVerifyDeliveries,
    ...fieldsToBeVerified
  }: VerifyWebhookDeliveryByEventParams) => Promise<void>;
}
interface ZapierPageInitializer {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  integrationRouteIndex?: string;
  mailerUtils: MailerUtils;
}
interface VerifyZapIsTriggeredProps {
  submittedEmail: string;
  zapTriggeredAfter: Date;
  productName: string;
  timeout?: number;
}
declare class ZapierPage extends IntegrationBase {
  zapierWebPage: Page;
  continueButton: Locator;
  mailerUtils: MailerUtils;
  constructor({
    page,
    neetoPlaywrightUtilities,
    integrationRouteIndex,
    mailerUtils
  }: ZapierPageInitializer);
  /**
   *
   * Logs into zapier web app. It takes the following parameters:
   *
   * zapierWebPage: Playwright Page object for Zapier web app.
   *
   * @example 
   *
   * await zapierPage.loginToZapier(zapierWebPageInstance);
   * @endexample
  */
  loginToZapier: (zapierWebPage: Page) => Promise<void>;
  /**
   *
   * Logs out from zapier web app.
   *
   * @example 
   *
   * await zapierPage.logoutFromZapier();
   * @endexample
  */
  logoutFromZapier: () => Promise<void>;
  /**
   *
   * Reconnects zapier account and publishes changes. It takes the following parameters:
   *
   * zapierApiKey: Zapier API key.
   *
   * appName: Name of the application.
   *
   * @example 
   *
   * await zapierPage.reconnectAccountAndPublish("your-zapier-api-key", "neetoForm");
   * @endexample
  */
  reconnectAccountAndPublish: (zapierApiKey: string, appName: string) => Promise<void>;
  /**
   *
   * Deletes all connections in zapier. It takes the following parameters:
   *
   * zapierAppLink: Link to Zapier app.
   *
   * @example 
   *
   * await zapierPage.deleteAllConnections("https://zapier.com/app/dashboard");
   * @endexample
  */
  deleteAllConnections: (zapierAppLink: string) => Promise<void>;
  /**
   *
   * Verifies that a Zap is triggered. It takes the following parameters:
   *
   * submittedEmail: Submitted email address.
   *
   * zapTriggeredAfter: Date after which the Zap should be triggered.
   *
   * productName: Name of the product.
   *
   * timeout(optional): Timeout in milliseconds to fetch the latest response. Default is 2 * 60_000.
   *
   * @example 
   *
   * await zapierPage.verifyZapIsTriggered({
   *   submittedEmail: "example@example.com",
   *   zapTriggeredAfter: new Date(),
   *   productName: "neetoChat",
   * });
   * @endexample
  */
  verifyZapIsTriggered: ({
    productName,
    submittedEmail,
    zapTriggeredAfter,
    timeout
  }: VerifyZapIsTriggeredProps) => Promise<FormattedList | Record<string, never>>;
  /**
   *
   * Skips test if Zapier task limit is exhausted.
   *
   * @example 
   *
   * await zapierPage.skipIfTaskLimitIsExhausted();
   * @endexample
  */
  skipIfTaskLimitIsExhausted: () => Promise<void>;
  /**
   *
   * Connects to zapier integration and verifies the connection. It takes the following parameters:
   *
   * apiKeyLabel: Label for Zapier API key.
   *
   * Returns: Zapier API key.
   *
   * @example 
   *
   * const apiKey = await zapierPage.connectAndVerify({
   *   apiKeyLabel: "Your API Key",
   * });
   * @endexample
  */
  connectAndVerify: ({
    apiKeyLabel
  }: {
    apiKeyLabel: string;
  }) => Promise<string>;
  /**
   *
   * Disconnects from Zapier integration and verifies disconnection.
   *
   * toastMessage(Optional): Text that should be on toast.
   *
   * @example 
   *
   * await zapierPage.disconnectAndVerify();
   * @endexample
  */
  disconnectAndVerify: (toastMessage?: string) => Promise<void>;
  /**
   *
   * Creates a new Zapier API key with the given label and copies it to the clipboard.
   *
   * apiKeyLabel : The label/name to assign to the newly created API key.
   *
   * The value of the generated API key copied from the clipboard.
   *
   * @example 
   *
   * const apiKey = await zapierPage.generateAPIKey("Your API Key");
   * @endexample
  */
  generateAPIKey: (apiKeyLabel: string) => Promise<string>;
}
type SubscriptionPlan = "free" | "pro";
interface AddMemberProps {
  email: string;
  role?: string;
  appName: string;
  subscriptionPlan?: SubscriptionPlan;
}
interface EditMemberProps$1 {
  email: string;
  firstName?: string;
  lastName?: string;
  newRole?: string;
  subscriptionPlan?: SubscriptionPlan;
}
declare class Member {
  private neetoPlaywrightUtilities;
  memberApis: MemberApis$1;
  constructor(neetoPlaywrightUtilities: CustomCommands);
  addMemberViaRequest: ({
    email,
    role,
    appName,
    subscriptionPlan
  }: AddMemberProps) => Promise<void>;
  editMemberViaRequest: ({
    email,
    firstName,
    lastName,
    newRole,
    subscriptionPlan
  }: EditMemberProps$1) => Promise<void>;
  deactivateMemberViaRequest: (email: string) => Promise<APIResponse | undefined>;
  generateRandomTeamMembers: ({
    count,
    role
  }: {
    count?: number | undefined;
    role?: string | undefined;
  }) => {
    firstName: string;
    lastName: string;
    email: string;
    role: string;
  }[];
}
interface KeyValuePair {
  key: string;
  value: string;
}
interface VerifyDescriptionEditorParams {
  dynamicVariables?: KeyValuePair[];
  linkUrl?: string;
  filePath?: string;
  imageUrl?: string;
  videoUrl?: string;
  videoPath?: string;
  cannedResponseSuccessMessage?: string;
}
declare class EditorPage {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  t: TFunction;
  editorWrapper: Locator | Page;
  wordsUsedInEditor: string[];
  fixedMenuArrowSelector: Locator;
  editorLinkButton: Locator;
  attachmentPreview: Locator;
  editorAttachmentsButton: Locator;
  uploadDeleteButton: Locator;
  imageWrapper: Locator;
  imageUploadOption: Locator;
  cannedResponseOption: Locator;
  videoEmbedOption: Locator;
  videoEmbedInput: Locator;
  videoWrapperSelector: Locator;
  emojiSelector: Locator;
  moreMenuSelector: Locator;
  contentField: Locator;
  dynamicVariablesButton: Locator;
  redoSelector: Locator;
  undoSelector: Locator;
  tableOption: Locator;
  videoUploadOption: Locator;
  filePath: string;
  videoPath: string;
  linkUrl: string;
  imageUrl: string;
  videoUrl: string;
  cannedResponseSuccessMessage?: string | undefined;
  constructor(page: Page, neetoPlaywrightUtilities: CustomCommands, editorWrapper?: Locator | Page);
  private cleanString;
  private fixedMenuOptions;
  private moreMenuOptions;
  private verifyFontSize;
  private verifyTextModifiers;
  private verifyTextDeskModifier;
  private verifyListModifiers;
  private verifyEditorLinkButton;
  private verifyEditorAttachmentsButton;
  private verifyImageUploadOption;
  private verifyCannedResponseOption;
  private verifyVideoEmbedOption;
  private verifyEmojiSelector;
  private verifyUndoSelector;
  private verifyRedoSelector;
  private verifyTableSelector;
  private verifyVideoUploadOption;
  verifyDynamicVariables: (dynamicVariables: KeyValuePair[]) => Promise<void>;
  private buttonsAndVerifications;
  /**
   *
   * Used to verify description editor functionality.
   *
   * Returns the array of key value pairs, where key is the type of button in the editor and value is the reflected text due to the button in the editor.
   *
   * dynamicVariables (optional): An array of key value pairs of dynamic variables used by the product in editor content field.
   *
   * linkUrl (optional): The url to be added when we select the button on the editor menu to link a url to a text. Default is faker.internet.url().
   *
   * videoPath (optional): The video path to be added when we select the button on the editor menu to attach a video in the editor. Default is "../../e2e/assets/files/sample.mp4".
   *
   * filePath (optional): The file path to be added when we select the button on the editor menu to attach a file in the editor. Default is "../../../e2e/assets/images/BigBinary.png".
   *
   * imageUrl (optional): The url to be added when we select the button on the editor menu to upload an image in the editor. Default is https://picsum.photos/200/300.
   *
   * videoUrl (optional): The url to be added when we select the button on the editor menu to upload a video in the editor. Default is https://youtu.be/jNQXAC9IVRw.
   *
   * cannedResponseSuccessMessage (optional): The success toastr message after applying canned response.
   *
   * @example 
   *
   * await editorPage.verifyDescriptionEditor(); //=> [
   *     // { key: 'h1', value: 'coaegresco' },
   *     // { key: 'h2', value: 'beneficium' }, ... ]
   * @endexample
  */
  verifyDescriptionEditor: ({
    dynamicVariables,
    linkUrl,
    videoPath,
    filePath,
    imageUrl,
    videoUrl,
    cannedResponseSuccessMessage
  }?: VerifyDescriptionEditorParams) => Promise<KeyValuePair[]>;
  private moveCursorAtBottom;
  private fillRandomText;
}
interface CropImageProps {
  toggleAspectRatioLock: boolean;
  aspectRatioHeight: string;
  aspectRatioWidth: string;
  width: string;
  height: string;
}
interface ImageLibraryProps extends Partial<CropImageProps> {
  toggleOrginalImage?: boolean;
  localImagePath: string;
}
interface SelectImage extends CropImageProps {
  toggleOrginalImage: boolean;
  searchTerm: string;
  nthImage: number;
}
declare class ImageUploader {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  constructor(page: Page, neetoPlaywrightUtilities: CustomCommands);
  private submitCroppedImage;
  /**
   *
   * Used to remove an image already uploaded from the image uploader amd verify it.
   *
   * @example 
   *
   * await imageUploader.removeImage()
   * @endexample
  */
  removeImage: () => Promise<void>;
  /**
   *
   * Used to open the image library modal.
   *
   * @example 
   *
   * await imageUploader.openImageLibrary()
   * @endexample
  */
  openImageLibrary: () => Promise<void>;
  /**
   *
   * Used to crop the image. It takes the following parameters:
   *
   * toggleAspectRatioLock (optional): A boolean value to toggle the aspect ratio lock switch which is checked by default. Default is false.
   *
   * aspectRatioHeight (optional): The height of the aspect ratio. Default is 9.
   *
   * aspectRatioWidth (optional): The width of the aspect ratio. Default is 16.
   *
   * width (optional): The width of the cropped image. Default is 100.
   *
   * height (optional): The height of the cropped image. Default is 100.
   *
   * @example 
   *
   *     await imageUploader.cropImage({
   *         toggleAspectRatioLock: false
   *         aspectRatioHeight: "9",
   *         aspectRatioWidth: "16",
   *         width: "100",
   *         height: "100",
   *     })
   * @endexample
  */
  cropImage: ({
    toggleAspectRatioLock,
    width,
    height,
    aspectRatioHeight,
    aspectRatioWidth
  }?: Partial<CropImageProps>) => Promise<void>;
  /**
   *
   * Used to upload a new image from the library and crop it if required. It takes the following parameters:
   *
   * localImagePath: The path of the image to be uploaded.
   *
   * toggleOrginalImage (optional): A boolean value to toggle the original image switch which is not checked by default. Default is false.
   *
   * toggleAspectRatioLock (optional): A boolean value to toggle the aspect ratio lock switch which is checked by default. Default is false.
   *
   * aspectRatioHeight (optional): The height of the aspect ratio. Default is 9.
   *
   * aspectRatioWidth (optional): The width of the aspect ratio. Default is 16.
   *
   * width (optional): The width of the cropped image. Default is 100.
   *
   * height (optional): The height of the cropped image. Default is 100.
   *
   * @example 
   *
   *     await imageUploader.uploadNewImageFromLibrary({
   *         localImagePath,
   *         toggleOrginalImage: false,
   *         toggleAspectRatioLock: false,
   *         aspectRatioHeight: "9",
   *         aspectRatioWidth: "16",
   *         width: "100",
   *         height: "100",
   *     })
   * @endexample
  */
  uploadNewImageFromLibrary: ({
    localImagePath,
    toggleOrginalImage,
    toggleAspectRatioLock,
    aspectRatioHeight,
    aspectRatioWidth,
    width,
    height
  }: ImageLibraryProps) => Promise<void>;
  /**
   *
   * Used to select an image from the unsplash and crop it if required. It takes the following parameters:
   *
   * nthImage (optional): The index of the image to be selected. Default is 0.
   *
   * searchTerm (optional): The input for the search field.
   *
   * toggleOrginalImage (optional): A boolean value to toggle the original image switch which is not checked by default. Default is false.
   *
   * toggleAspectRatioLock (optional): A boolean value to toggle the aspect ratio lock switch which is checked by default. Default is false.
   *
   * aspectRatioHeight (optional): The height of the aspect ratio. Default is 9.
   *
   * aspectRatioWidth (optional): The width of the aspect ratio. Default is 16.
   *
   * width (optional): The width of the cropped image. Default is 100.
   *
   * height (optional): The height of the cropped image. Default is 100.
   *
   * @example 
   *
   * await imageUploader.selectImageFromWeb({
   *     nthImage: 0,
   *     searchTerm: "",
   *     toggleOrginalImage: false,
   *     toggleAspectRatioLock: false,
   *     aspectRatioHeight: "9",
   *     aspectRatioWidth: "16",
   *     width: "100",
   *     height: "100",
   * })
   * @endexample
  */
  selectImageFromWeb: ({
    nthImage,
    searchTerm,
    toggleOrginalImage,
    toggleAspectRatioLock,
    aspectRatioHeight,
    aspectRatioWidth,
    width,
    height
  }?: Partial<SelectImage>) => Promise<void>;
  /**
   *
   * Used to select an image from the library and crop it if required. It takes the following parameters:
   *
   * nthImage (optional): The index of the image to be selected. Default is 0.
   *
   * searchTerm (optional): The input for the search field.
   *
   * toggleOrginalImage (optional): A boolean value to toggle the original image switch which is not checked by default. Default is false.
   *
   * toggleAspectRatioLock (optional): A boolean value to toggle the aspect ratio lock switch which is checked by default. Default is false.
   *
   * aspectRatioHeight (optional): The height of the aspect ratio. Default is 9.
   *
   * aspectRatioWidth (optional): The width of the aspect ratio. Default is 16.
   *
   * width (optional): The width of the cropped image. Default is 100.
   *
   * height (optional): The height of the cropped image. Default is 100.
   *
   * @example 
   *
   *     await imageUploader.selectImageFromLibrary({
   *         nthImage: 0,
   *         searchTerm: "",
   *         toggleOrginalImage: false,
   *         toggleAspectRatioLock: false,
   *         aspectRatioHeight: "9",
   *         aspectRatioWidth: "16",
   *         width: "100",
   *         height: "100",
   *     })
   * @endexample
  */
  selectImageFromLibrary: ({
    nthImage,
    searchTerm,
    toggleOrginalImage,
    toggleAspectRatioLock,
    aspectRatioHeight,
    aspectRatioWidth,
    width,
    height
  }?: Partial<SelectImage>) => Promise<void>;
}
type emailCondition = "Contains" | "Does not contain" | "Is" | "Is not" | "Starts with" | "Does not start with" | "Ends with" | "Does not end with";
interface EditMemberProps {
  email: string;
  firstName: string;
  lastName: string;
  role: string;
}
declare class TeamMembers {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  t: TFunction;
  constructor({
    page,
    neetoPlaywrightUtilities
  }: {
    page: Page;
    neetoPlaywrightUtilities: CustomCommands;
  });
  /**
   *
   * Used to navigate to the team members page.
   *
   * @example 
   *
   * await teamMembers.navigateToTeamMembers();
   * @endexample
  */
  navigateToTeamMembers: () => Promise<void>;
  /**
   *
   * Used to add a member using the add button in the header. It takes the following parameters:
   *
   * emails (optional): The emails of the members to be added. Default is an example email.
   *
   * role (optional): The role of the new members. Default is standard.
   *
   * @example 
   *
   * await teamMembers.addMemberViaUI({
   *     emails: ["sam@example.com", "tom@example.com"],
   *     role: "admin",
   * });
   * @endexample
  */
  addMemberViaUI: ({
    emails,
    role
  }?: {
    emails?: string[];
    role?: string;
  }) => Promise<void>;
  /**
   *
   * Used to search and verify the member by providing email as the search term. It takes the following parameters:
   *
   * email (required): The email of the member to be searched.
   *
   * interceptOptions (optional): The options to be passed to the waitForMultipleResponse command.
   *
   * @example 
   *
   * await teamMembers.searchAndVerifyMemberByEmail({
   *     email: "sam@example.com",
   *     interceptOptions: { timeout: 10000, requestCount: 1 },
   * });
   * @endexample
  */
  searchAndVerifyMemberByEmail: ({
    email,
    interceptOptions
  }: {
    email: string;
    interceptOptions?: Partial<Omit<InterceptMultipleResponsesParams, "responseUrl">>;
  }) => Promise<void>;
  /**
   *
   * Used to edit a member using the edit button in row dropdown. A member has to be searched before editing. It takes the following parameters:
   *
   * email (optional): The new email of the member.
   *
   * role (optional): The new role of the member. Default is standard.
   *
   * firstName (optional): The new first name of the member.
   *
   * lastName (optional): The new last name of the member.
   *
   * @example 
   *
   * await teamMembers.searchAndVerifyMemberByEmail({
   *     email: "sam@example.com",
   * });
   * await teamMembers.editMemberViaUI({
   *     email: "tom@example.com",
   *     role: "admin",
   *     firstName: "Tom",
   *     lastName: "Hanks",
   * });
   * @endexample
   * @example 
   *
   * await teamMembers.searchAndVerifyMemberByEmail({
   *     email: "sam@example.com",
   * });
   * await teamMembers.editMemberViaUI();
   * 
   * // This will change the role of the member with email "sam@example.com" to the `standard` role.
   * @endexample
  */
  editMemberViaUI: ({
    email,
    firstName,
    lastName,
    role
  }?: Partial<EditMemberProps>) => Promise<void>;
  /**
   *
   * Used to remove member, using the remove button in row dropdown. A member has to be searched before removing.
   *
   * @example 
   *
   * await teamMembers.searchAndVerifyMemberByEmail({
   *     email: "sam@example.com",
   * });
   * await teamMembers.removeMemberViaUI();
   * @endexample
  */
  removeMemberViaUI: () => Promise<void>;
  /**
   *
   * Used to filter members by multi select fields such as role, group, teams, etc. The filter pane should be opened and closed before and after filtering. It takes the following parameters:
   *
   * selectedOptions (required): The options to be selected in the multi select field.
   *
   * selectContainerLocator (optional): The locator of the container of the multi select field. Default is the container of the role field.
   *
   * @example 
   *
   * await filterUtils.openFilterPane(page);
   * await teamMembers.filterMembersByMultiSelect({
   *     selectedOptions: ["Admin", "Standard"],
   *     selectContainerLocator: NEETO_FILTERS_SELECTORS.roleSelectContainer
   * });
   * @endexample
  */
  filterMembersByMultiSelect: ({
    selectedOptions,
    selectContainerLocator
  }: {
    selectedOptions: string[];
    selectContainerLocator?: string;
  }) => Promise<void>;
  /**
   *
   * Used to filter members by at least one these field: email with conditions, role, or name. It takes the following parameters:
   *
   * email (optional): An object with the id and condition as keys to filter by email.
   *
   * roles (optional): The roles to filter by.
   *
   * name (optional): The name to filter by.
   *
   * @example 
   *
   * await teamMembers.filterMembers({
   *     email: { id: "sam", condition: "Contains" },
   *     roles: ["Admin", "Standard"],
   * });
   * @endexample
   * @example 
   *
   * await teamMembers.filterMembers({
   *     name: "Sam",
   *     roles: ["Admin"],
   * });
   * @endexample
  */
  filterMembers: ({
    email,
    roles,
    name
  }: {
    email?: {
      id: string;
      condition: emailCondition;
    };
    roles?: string[];
    name?: string;
  }) => Promise<void>;
  /**
   *
   * Used to get the row of the team members table by providing the name of the member.
   *
   * @example 
   *
   * await teamMembers.getMemberRowByName("Sam");
   * @endexample
  */
  getMemberRowByName: (name: string) => playwright_core.Locator;
  /**
   *
   * Used to take action on members by selecting the members and clicking on the take action button in the subheader. It takes the following parameters:
   *
   * names (optional): The names of the members to take action on. If not provided, all members will be selected.
   *
   * state (optional): The state to change the members to.
   *
   * action (optional): An object with actionButtonText and valueButtonText as keys to take action on the members. actionButtonText and valueButtonText are the text of the action button to be clicked and the value of the action to be changed to, respectively.
   *
   * @example 
   *
   * await teamMembers.takeActionOnMembers({
   *     names: ["Sam", "Tom"],
   *     state: "Deactivate",
   * });
   * @endexample
   * @example 
   *
   * await teamMembers.takeActionOnMembers({
   *     action: { actionButtonText: "Change role", valueButtonText: "Admin" },
   * });
   * @endexample
  */
  takeActionOnMembers: ({
    names,
    state,
    action
  }: {
    names?: string[];
    state?: "activate" | "deactivate" | undefined;
    action?: {
      actionButtonText: string;
      valueButtonText: string;
    } | undefined;
  }) => Promise<void>;
  /**
   *
   * Used to perform an action on a column header in the team members table. It takes the following parameters:
   *
   * columnName (optional): The name of the column to perform the action on. Default is Name.
   *
   * actionButtonText (optional): The text of the action button to be clicked. Default is Ascending.
   *
   * @example 
   *
   * await teamMembers.performColumnAction({
   *     columnName: "Role",
   *     actionButtonText: "Hide column",
   * });
   * @endexample
   * @example 
   *
   * await teamMembers.performColumnAction();
   * 
   * // This will sort the `name` column in ascending order.
   * @endexample
  */
  performColumnAction: ({
    columnName,
    actionButtonText
  }?: {
    columnName?: string;
    actionButtonText?: "Ascending" | "Descending" | "Hide column";
  }) => Promise<void>;
  /**
   *
   * Used to toggle the visibility of columns in the team members table. It takes the following parameters:
   *
   * columns (optional): The columns whose visibility is to be toggled.
   *
   * bulkAction (optional): The option to show or hide all columns. If not provided, the columns will be toggled individually based on the columns parameter.
   *
   * @example 
   *
   * await teamMembers.toggleMemberColumns({
   *     bulkAction: "show",
   * });
   * @endexample
   * @example 
   *
   * await teamMembers.toggleMemberColumns({
   *     columns: ["role", "email"],
   * });
   * @endexample
  */
  toggleMemberColumns: ({
    columns,
    bulkAction
  }: {
    columns?: string[];
    bulkAction?: "hide" | "show";
  }) => Promise<void>;
  /**
   *
   * Used to verify the presence of a member in the team members table. It takes the following parameters:
   *
   * email (required): The email of the member to be verified.
   *
   * name (optional): The name of the member to be verified.
   *
   * @example 
   *
   * await teamMembers.verifyMemberInTable({
   *     email: "sam@example.com",
   *     name: "Sam",
   * });
   * @endexample
  */
  verifyMemberInTable: ({
    name,
    email
  }: {
    name: string;
    email: string;
  }) => Promise<void>;
  private applyFilter;
}
interface BasicUserInfo {
  firstName: string;
  lastName: string;
  email: string;
  country?: string;
}
interface CreateOrganizationProps extends BasicUserInfo {
  businessName: string;
  subdomainName: string;
  appName: string;
}
interface LoginAndOnboardParams extends BasicUserInfo {
  handleOnboarding: () => Promise<void>;
  baseURL?: string;
  fetchOtpFromEmail?: FetchOtpFromEmail;
}
interface Credentials extends BasicUserInfo {
  otp?: number;
  domain: string;
  currentUserName: string;
  businessName: string;
  subdomainName: string;
}
type FetchOtpFromEmail = (params: {
  email: string;
  timeout: number;
}) => Promise<string>;
interface LoginWithFastmailEmail {
  email: string;
  loginTimeout?: number;
  fetchOtpFromEmail: FetchOtpFromEmail;
}
declare class OrganizationPage {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  constructor(page: Page, neetoPlaywrightUtilities: CustomCommands);
  /**
   *
   * Used to generate  the subdomain URL. It takes the following parameters:
   *
   * appName(required): Name of the app.
   *
   * @example 
   *
   *   const domain = organizationPage.baseUrlGenerator(appName)
   *   console.log(domain) // https://${subdomainName}.${appName}.net
   *   // "subdomainName" is the loggedIn user name
   * @endexample
  */
  baseUrlGenerator: (appName: string) => string;
  /**
   *
   * Used to create a new organization. It takes the following parameters:
   *
   * email: Owner emails.
   *
   * businessName: Your business name.
   *
   * subdomainName: Your subdomain.
   *
   * firstName: User first name.
   *
   * lastName: User last name.
   *
   * appName: App name
   *
   * @example 
   *
   *   await organizationPage.createOrganization({
   *     email:"jhondoe@gmail.com",
   *     businessName:"BigBinary",
   *     subdomainName:"bigbinary",
   *     firstName:"jhon",
   *     lastName:"doe",
   *     appName:"neetoChat"
   *   })
   * @endexample
  */
  createOrganization: ({
    email,
    businessName,
    subdomainName,
    firstName,
    lastName,
    appName
  }: CreateOrganizationProps) => Promise<void>;
  /**
   *
   * Used to set up an Organization. It takes the following parameters:
   *
   * product: Name of the product.
   *
   * @example 
   *
   *   await organizationPage.setupOrganization("Chat")
   * @endexample
  */
  setupOrganization: (product: string) => Promise<void>;
  /**
   *
   * Used to update already existing subdomain name. It takes the following parameters:
   *
   * appName: Name of the app.
   *
   * @example 
   *
   *   await organizationPage.updateSubdomainIfExists("latest subdomain")
   * @endexample
  */
  updateSubdomainIfExists: (appName: string) => Promise<void>;
  fillEmailAndSubmit: (email: string, loginTimeout: number) => Promise<void>;
  /**
   *
   * Used to login via SSO. It takes the following parameters:
   *
   * email (optional): A bypass email. If not provided, a random bypass email will be generated.
   *
   * loginTimeout (optional): Specifies the maximum amount of time the method will wait for the login process to complete before timing out. Default is 15s.
   *
   * @example 
   *
   *  await organizationPage.loginViaSSO()
   * @endexample
  */
  loginViaSSO: (email?: string, loginTimeout?: number) => Promise<void>;
  /**
   *
   * This method is used to login NeetoAuth using Fastmail email id. It takes the following parameters:
   *
   * email: A Fastmail email id. You can generate a Fastmail email id using the method generateRandomEmail in MailerUtils.
   *
   * loginTimeout (optional): Specifies the maximum amount of time the method will wait for the login process to complete before timing out. Default is 15s.
   *
   * fetchOtpFromEmail: Method to fetch OTP from Fastmail email.
   *
   * @example 
   *
   *  await organizationPage.loginWithFastmailEmail({
   *   email,
   *   fetchOtpFromEmail: () =>
   *     mailerUtils.findOtpFromEmail({
   *       ...newHost,
   *       timeout: 5 * 60 * 1000,
   *     }),
   *  })
   * @endexample
  */
  loginWithFastmailEmail: ({
    email,
    loginTimeout,
    fetchOtpFromEmail
  }: LoginWithFastmailEmail) => Promise<void>;
  /**
   *
   * Used to fill and submit all the profile info. It takes the following parameters:
   *
   * firstName (optional): The first name of the user.
   *
   * lastName (optional): The last name of the user.
   *
   * @example 
   *
   *   await organizationPage.setupProfile({
   *     firstName:"John",
   *     lastName:"Doe"
   *   })
   * @endexample
  */
  setupProfile: ({
    firstName,
    lastName,
    country
  }?: {
    firstName?: string;
    lastName?: string;
    country?: string;
  }) => Promise<void>;
  /**
   *
   * Used to login and onboard the user to app. It takes the following parameters:
   *
   * email: User email.
   *
   * firstName: User first name.
   *
   * lastName: User last name.
   *
   * handleOnBoard: Method to call after onboarding.
   *
   * @example 
   *
   *   await organizationPage.loginAndOnboard({
   *     email:"jhondoe@gmail.com",
   *     firstName:"jhon",
   *     lastName:"doe",
   *     handleOnboarding:() => methodToOnBoard
   *   })
   * @endexample
  */
  loginAndOnboard: ({
    email,
    firstName,
    lastName,
    country,
    handleOnboarding,
    baseURL,
    fetchOtpFromEmail
  }: LoginAndOnboardParams) => Promise<void>;
  /**
   *
   * Used to signUp the user. It takes the following parameters:
   *
   * otp: (optional) OTP to verify the email.
   *
   * fetchOtpFromEmail: (optional) Method to fetch OTP from email.
   *
   * @example 
   *
   *   const fetchOtpFromEmail = (email,timeOut)=>Promise<void>
   * 
   *   const credentials = {
   *     otp:1234,
   *     domain:"chat.com",
   *     currentUserName:"jhon",
   *     businessName:"bigbinary",
   *     subdomainName: "bigbinary"
   *   }
   * 
   *   await organizationPage.signUp({
   *     credentials,
   *     fetchOtpFromEmail,
   *     appName:"neetoChat"
   *   })
   * @endexample
  */
  signUp: ({
    credentials,
    fetchOtpFromEmail,
    appName
  }: {
    credentials: Credentials;
    fetchOtpFromEmail?: FetchOtpFromEmail;
    appName: string;
  }) => Promise<{
    STORAGE_STATE: {
      cookies: Array<{
        name: string;
        value: string;
        domain: string;
        path: string;
        expires: number;
        httpOnly: boolean;
        secure: boolean;
        sameSite: "Strict" | "Lax" | "None";
      }>;
      origins: Array<{
        origin: string;
        localStorage: Array<{
          name: string;
          value: string;
        }>;
      }>;
    };
    baseURL: string | undefined;
  }>;
  /**
   *
   * Used to fill and complete all the details of an Organization.
   *
   * @example 
   *
   *   const credentials = {
   *     otp:1234,
   *     domain:"chat.com",
   *     currentUserName:"jhon",
   *     businessName:"bigbinary",
   *     subdomainName: "bigbinary"
   *   }
   * 
   *   await organizationPage.fillOrganizationDetails({
   *     credentials,
   *     appName:"neetoChat"
   *   })
   * @endexample
  */
  fillOrganizationDetails: ({
    credentials,
    appName
  }: {
    credentials: Credentials;
    appName: string;
  }) => Promise<void>;
  changeCountry: (country: string) => Promise<void>;
}
interface ApiKeyDetails {
  label: string;
  expiryDate?: string;
}
declare class ApiKeysPage {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  t: TFunction;
  constructor(page: Page, neetoPlaywrightUtilities: CustomCommands);
  /**
   *
   * Used to fill in the details for creating or editing an API key.
   *
   * label (required): The name for the API key.
   *
   * expiryDate (optional): The day of the month for the expiry date, formatted as "dd".
   *
   * @example 
   *
   * await apiKeysPage.fillApiKeyDetails({
   *   label: "API Key",
   *   expiryDate: "15"
   * });
   * @endexample
  */
  fillApiKeyDetails: ({
    label,
    expiryDate
  }: ApiKeyDetails) => Promise<void>;
  /**
   *
   * Used to verify the values in the API keys table.
   *
   * targetRow (required): The locator of the row where the API key should be verified.
   *
   * label (required): The name of the API key.
   *
   * date (required): The creation date of the API key, formatted as "MMM dd, yyyy".
   *
   * @example 
   *
   * await apiKeysPage.verifyApiKey({
   *   targetRow: page.getByRole("row"),
   *   label: "API Key",
   *   date: "Mar 11, 2025"
   * });
   * @endexample
  */
  verifyApiKey: ({
    targetRow,
    label,
    date
  }: {
    targetRow: Locator;
    label: string;
    date: string;
  }) => Promise<[void, void, void, void]>;
  /**
   *
   * Used to edit an existing API key.
   *
   * label (required): The new name for the API key.
   *
   * expiryDate (optional): The day of the month for the expiry date, formatted as "dd".
   *
   * @example 
   *
   * await apiKeysPage.editApiKey({
   *   label: "new API Key",
   *   expiryDate: "20"
   * });
   * @endexample
  */
  editApiKey: ({
    label,
    expiryDate
  }: ApiKeyDetails) => Promise<void>;
  /**
   *
   * Used to delete an existing API key.
   *
   * targetRow (required): The locator of the row containing the API key to delete.
   *
   * @example 
   *
   * await apiKeysPage.deleteApiKey(targetRow);
   * @endexample
  */
  deleteApiKey: (targetRow: Locator) => Promise<void>;
}
interface VerifyAuditLogProps {
  targetRow: Locator;
  action: string;
  date: string;
  adminName: string;
}
interface VerifyDataInPaneProps {
  action: string;
  values: string[];
  page?: Page;
  firstName?: string;
  lastName?: string;
  roleName?: string;
}
declare class AuditLogsPage {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  t: TFunction;
  targetRow: Locator;
  constructor(page: Page, neetoPlaywrightUtilities: CustomCommands);
  /**
   *
   * Used to verify the values in the audit logs table.
   *
   * targetRow (required): The locator of the row where the value should be verified.
   *
   * action (required): The action that was performed.
   *
   * date (required): The date when the action was performed.
   *
   * adminName (required): The name of the admin who performed the action.
   *
   * @example 
   *
   * await auditLogsPage.verifyAuditLog({
   *   targetRow: page.getByRole("row"),
   *   action: "Updated user",
   *   date: "Nov 27, 2024",
   *   adminName: "Oliver Smith"
   * });
   * @endexample
  */
  verifyAuditLog: ({
    targetRow,
    action,
    date,
    adminName
  }: VerifyAuditLogProps) => Promise<void>;
  /**
   *
   * Used to verify the additional details of the action.
   *
   * action (required): The action that was performed.
   *
   * values (required): An array that contains the values to be verified in the pane.
   *
   * page (optional): The custom page context. Default is POM's page.
   *
   * firstName (optional): The first name of the team member whose details were edited.
   *
   * lastName (optional): The last name of the team member whose details were edited.
   *
   * roleName (optional): The role of the team member after the action.
   *
   * @example 
   *
   * await auditLogsPage.verifyDataInPane({
   *   action: "Updated user",
   *   values: ["johnluther@example.com"],
   *   firstName: "John",
   *   lastName: "Luther",
   *   roleName: "Agent",
   *   page,
   * });
   * @endexample
  */
  verifyDataInPane: ({
    page,
    action,
    values,
    firstName,
    lastName,
    roleName
  }: VerifyDataInPaneProps) => Promise<void>;
}
declare class CustomDomainPage {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  t: TFunction;
  constructor(page: Page, neetoPlaywrightUtilities: CustomCommands);
  /**
   *
   * Used to add a custom domain via the UI.
   *
   * domainName (required): The custom domain name to be added.
   *
   * @example 
   *
   * await customDomainPage.addCustomDomainViaUI("example.com");
   * @endexample
  */
  addCustomDomainViaUI: (domainName: string) => Promise<void>;
  /**
   *
   * Used to delete an existing custom domain via the UI.
   *
   * @example 
   *
   * await customDomainPage.deleteCustomDomainViaUI();
   * @endexample
  */
  deleteCustomDomainViaUI: () => Promise<void>;
}
interface RoleDetails {
  roleName: string;
  permissions: string[];
}
interface VerifyAdminPanelCardProps {
  cardLocator: Locator;
  title: string;
  description: string;
}
declare class RolesPage {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  roleApis: RoleApis;
  t: TFunction;
  constructor(page: Page, neetoPlaywrightUtilities: CustomCommands);
  private getPermissionIds;
  private getRoleIdAndOrganizationId;
  /**
   *
   * Used to add a custom role via API request.
   *
   * roleName (required): The name of the role to add.
   *
   * targetPermissions (required): Array of permission names to assign.
   *
   * @example 
   *
   * await rolesPage.addCustomRoleViaRequest("Custom Role", ["Manage themes", "View roles"]);
   * @endexample
  */
  addCustomRoleViaRequest: (roleName: string, targetPermissions: string[]) => Promise<playwright_core.APIResponse | undefined>;
  /**
   *
   * Used to edit an existing role via API request.
   *
   * roleName (required): The name of the role to edit.
   *
   * targetPermissions (required): Array of permission names to update.
   *
   * @example 
   *
   * await rolesPage.editRoleViaRequest("Custom Role", ["Manage roles"]);
   * @endexample
  */
  editRoleViaRequest: (roleName: string, targetPermissions: string[]) => Promise<playwright_core.APIResponse | undefined>;
  /**
   *
   * Used to delete a role via API request.
   *
   * roleName (required): The name of the role to delete.
   *
   * @example 
   *
   * await rolesPage.deleteRoleViaRequest("Custom Role");
   * @endexample
  */
  deleteRoleViaRequest: (roleName: string) => Promise<playwright_core.APIResponse | undefined>;
  /**
   *
   * Used to add a role through the UI.
   *
   * roleName (required): The name of the role to add.
   *
   * permissions (required): Array of permission names to assign.
   *
   * @example 
   *
   * await rolesPage.addRoleViaUI({
   *   roleName: "Custom Role",
   *   permissions: ["Manage themes", "View roles"]
   * });
   * @endexample
  */
  addRoleViaUI: ({
    roleName,
    permissions
  }: RoleDetails) => Promise<void>;
  /**
   *
   * Used to edit an existing role through the UI.
   *
   * roleName (required): The name of the role to edit.
   *
   * permissions (required): Array of permission names to update.
   *
   * @example 
   *
   * await rolesPage.editRoleViaUI({
   *   roleName: "Custom Role",
   *   permissions: ["Manage roles"]
   * });
   * @endexample
  */
  editRoleViaUI: ({
    roleName,
    permissions
  }: RoleDetails) => Promise<void>;
  /**
   *
   * Used to select permissions.
   *
   * permissions (required): Array of permission names to select.
   *
   * @example 
   *
   * await rolesPage.selectAndSubmitPermissions(["Manage themes", "View roles"]);
   * @endexample
  */
  selectAndSubmitPermissions: (permissions: string[]) => Promise<void>;
  /**
   *
   * Used to verify the admin panel card details.
   *
   * cardLocator (required): The locator of the card to verify.
   *
   * title (required): The title of the card.
   *
   * description (required): The description of the card.
   *
   * @example 
   *
   * await rolesPage.verifyAdminPanelCard({
   *   description: "Roles card description",
   *   title: "Roles card title",
   *   cardLocator: page.getByTestId("roles-tab"),
   * });
   * @endexample
  */
  verifyAdminPanelCard: ({
    cardLocator,
    title,
    description
  }: VerifyAdminPanelCardProps) => Promise<[void, void, void]>;
  /**
   *
   * Used to delete a role through the UI.
   *
   * roleName (required): The name of the role to delete.
   *
   * @example 
   *
   * await rolesPage.deleteRoleViaUI("Custom Role");
   * @endexample
  */
  deleteRoleViaUI: (roleName: string) => Promise<void>;
  /**
   *
   * Used to verify role permissions visibility.
   *
   * allPermissions (required): Object containing all possible permissions.
   *
   * rolePermissions (required): Array of permissions assigned to the role.
   *
   * @example 
   *
   * await rolesPage.verifyPermissions({
   *   allPermissions: { adminPanel: "settings-nav-tab", members: "members-nav-tab" },
   *   rolePermissions: ["members-nav-tab"]
   * });
   * @endexample
  */
  verifyPermissions: ({
    allPermissions,
    rolePermissions
  }: {
    allPermissions: object;
    rolePermissions: string[];
  }) => Promise<void[]>;
  /**
   *
   * Used to verify role-specific link access.
   *
   * roleAccessableLinks (optional): Array of links the role can access.
   *
   * adminAccessableLinks (required): Array of links an admin can access.
   *
   * @example 
   *
   * await rolesPage.verifyRoleSpecificLinkAccess({
   *   roleAccessableLinks: ["/themes","/seo","roles"],
   *   adminAccessableLinks: ["/themes"]
   * });
   * @endexample
  */
  verifyRoleSpecificLinkAccess: ({
    roleAccessableLinks,
    adminAccessableLinks
  }: {
    roleAccessableLinks?: string[];
    adminAccessableLinks: string[];
  }) => Promise<void>;
}
declare class SidebarSection {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  t: TFunction;
  constructor(page: Page, neetoPlaywrightUtilities: CustomCommands);
  /**
   *
   * Used to click on the sub link in the sidebar. It takes the following parameters:
   *
   * label (required): The label of the sub link.
   *
   * @example 
   *
   *   await sideBarPage.clickOnSubLink("open menu item")
   * @endexample
  */
  clickOnSubLink: (label: string) => Promise<void>;
  /**
   *
   * Used to go back to the previous page. It takes the following parameters:
   *
   * label (required): The label of the go back button.
   *
   * @example 
   *
   *   await sideBarPage.sidebarGoBackButton("settings")
   * @endexample
  */
  clickOnGoBackButton: (label: string) => Promise<void>;
}
interface SearchAndSelectProps {
  selector: string;
  tagName: string;
  rowSelector: string;
}
interface MergeTagsViaUIProps {
  sourceTagName: string;
  destinationTagName: string;
  tagsBreadcrumbSelector: string;
}
declare class TagsPage {
  private page;
  private neetoPlaywrightUtilities;
  t: TFunction;
  tagsApi: TagsApi;
  constructor(page: Page, neetoPlaywrightUtilities: CustomCommands);
  /**
   *
   * Used to search and verify the tags by providing tag name as the search term. It takes the following parameters:
   *
   * tagName (required): The name of the tag to be searched.
   *
   * @example 
   *
   * await tagsPage.searchAndVerifyTags("tagName");
   * @endexample
  */
  searchAndVerifyTags: (tagName: string) => Promise<void>;
  /**
   *
   * Used to add a tag using the add button in the header. It takes the following parameters:
   *
   * tagName (required): The name of the tag to be added.
   *
   * addTagsLabel (required): The label of the add new tags pane header.
   *
   * tagsResponseUrl (required): the response URL of tags when the save button is clicked while adding new tags.
   *
   * @example 
   *
   * await tagsPage.addTagViaUI({
   *     tagName: "tagName",
   *     addTagsLabel: "Add new tag",
   *     tagsResponseUrl: API_ROUTES.tags.index,
   * });
   * @endexample
  */
  addTagViaUI: ({
    tagName,
    addTagsLabel,
    tagsResponseUrl
  }: {
    tagName: string;
    addTagsLabel: string;
    tagsResponseUrl?: string;
  }) => Promise<void>;
  /**
   *
   * Used to filter tags using the filter button in the header. It takes the following parameters:
   *
   * tagName (required): The name of the tag to be filtered.
   *
   * @example 
   *
   * await tagsPage.filterTagsViaUI({
   *     tagName: "tagName",
   * });
   * @endexample
  */
  filterTagsViaUI: (tagName: string) => Promise<void>;
  /**
   *
   * Used to edit a tag using the edit button in row dropdown. It takes the following parameters:
   *
   * tagName (required): The name of the tag to be edited.
   *
   * newTagName (required): The new name of the tag.
   *
   * @example 
   *
   * await tagsPage.editTagViaUI({
   *     tagName: "tagName",
   *     newTagName: "newTagName",
   * });
   * @endexample
  */
  editTagViaUI: ({
    tagName,
    newTagName
  }: {
    tagName: string;
    newTagName: string;
  }) => Promise<void>;
  /**
   *
   * Used to delete a tag using the delete button in row dropdown. It takes the following parameters:
   *
   * tagName (required): The name of the tag to be deleted.
   *
   * @example 
   *
   * await tagsPage.deleteTagViaUI({
   *     tagName: "tagName",
   * });
   * @endexample
  */
  deleteTagViaUI: (tagName: string) => Promise<void>;
  /**
   *
   * Used to add tags via API request. It takes the following parameters:
   *
   * name (required): The name of the tag to be added.
   *
   * description (optional): The description of the tag to be added. Default is "".
   *
   * tagsRequestUrl (required): The URL of the tags API endpoint.
   *
   * @example 
   *
   * await tagsPage.addTagsViaRequest({
   *     name: "tagName",
   *     description: "tagDescription",
   *     tagsRequestUrl: ROUTES.tags.index,
   * });
   * @endexample
  */
  addTagsViaRequest: ({
    name,
    description,
    tagsRequestUrl
  }: {
    name: string;
    description?: string;
    tagsRequestUrl: string;
  }) => Promise<playwright_core.APIResponse | undefined>;
  /**
   *
   * Used to navigate to merge tags page.
   *
   * @example 
   *
   * await tagsPage.navigateToMergeTagsPage();
   * @endexample
  */
  navigateToMergeTagsPage: () => Promise<void>;
  /**
   *
   * Used to search a tag and select that tag in the tags table. It takes the following parameters:
   *
   * selector (required): The selector used to search a tag.
   *
   * tagName (required): The name of the tag to be searched and selected.
   *
   * rowSelector (required): The selector of the row used to select a tag.
   *
   * @example 
   *
   * await tagsPage.searchAndSelect({
   *     selector: MERGE_TAGS_SELECTORS.sourceSearchTextField,
   *     tagName: "tagName",
   *     rowSelector: MERGE_TAGS_SELECTORS.sourceTagRow,
   * });
   * @endexample
  */
  searchAndSelect: ({
    selector,
    tagName,
    rowSelector
  }: SearchAndSelectProps) => Promise<void>;
  /**
   *
   * Used to merge tags and verify the merged tags in tags table. It takes the following parameters:
   *
   * sourceTagName (required): The name of the source tag to be merged.
   *
   * destinationTagName (required): The name of the destination tag to be merged.
   *
   * tagsBreadcrumbSelector (required): The selector of the tags breadcrumb used to redirect to the tags page.
   *
   * @example 
   *
   * tagsPage.mergeAndVerifyTagsViaUI({
   *     sourceTagName: "sourceTagName",
   *     destinationTagName: "destinationTagName",
   *     tagsBreadcrumbSelector: SETTINGS_SELECTORS.ticketTagsBreadcrumb,
   * })
   * @endexample
  */
  mergeAndVerifyTagsViaUI: ({
    sourceTagName,
    destinationTagName,
    tagsBreadcrumbSelector
  }: MergeTagsViaUIProps) => Promise<void>;
}
/**
 *
 * Constants related to different environments.
 *
 * development: Represents the development environment.
 *
 * staging: Represents the staging environment.
 *
 * review: Represents the review environment.
 *
 * @example 
 *
 * if (process.env.NODE_ENV === ENVIRONMENT.development) {
 *   // Perform actions specific to the development environment
 * }
 * 
 * // OR
 * 
 * if (process.env.NODE_ENV === ENVIRONMENT.staging) {
 *   // Perform actions specific to the staging environment
 * }
 * 
 * // OR
 * 
 * if (process.env.NODE_ENV === ENVIRONMENT.review) {
 *   // Perform actions specific to the review environment
 * }
 * @endexample
*/
declare const ENVIRONMENT: {
  development: string;
  staging: string;
  review: string;
};
/**
 *
 * Boolean value indicating whether the current environment is staging.
 *
 * @example 
 *
 * if(IS_STAGING_ENV){
 *   // Perform actions specific to the staging environment
 * }
 * @endexample
*/
declare const IS_STAGING_ENV: boolean;
/**
 *
 * Path to the JSON file for storing authentication data.
 *
*/
declare const STORAGE_STATE = "./e2e/auth/user.json";
/**
 *
 * Pattern for global translations file path.
 *
*/
declare const GLOBAL_TRANSLATIONS_PATTERN = "../node_modules/@bigbinary/**/translations/en.json";
/**
 *
 * Path to project-specific translations file.
 *
*/
declare const PROJECT_TRANSLATIONS_PATH = "../app/javascript/src/translations/en.json";
/**
 *
 * Default credentials for testing purposes.
 *
*/
declare const CREDENTIALS: {
  name: string;
  email: string;
  password: string;
};
/**
 *
 * Pattern for the subject of OTP emails.
 *
*/
declare const OTP_EMAIL_PATTERN = "is your login code";
/**
 *
 * Default Slack channel.
 *
*/
declare const SLACK_DEFAULT_CHANNEL = "general";
/**
 *
 * Function to generate Zapier test email address based on the product. It takes the following parameters:
 *
 * product: Product name.
 *
 * @example 
 *
 * const testEmail = ZAPIER_TEST_EMAIL("neetoChat");
 * 
 * console.log(testEmail) // `neeto-neetoChat-zapier-test@${process.env.FASTMAIL_DOMAIN_NAME}`
 * @endexample
*/
declare const ZAPIER_TEST_EMAIL: (product: string) => string;
declare const SINGULAR: {
  count: number;
};
declare const PLURAL: {
  count: number;
};
declare const COLOR: {
  transparent: string;
  softBlue: string;
};
declare const DATE_TEXTS: {
  now: string;
  nextYear: string;
};
/**
 *
 * The initial, empty state of browser storage, including empty cookies and origins.
 *
*/
declare const EMPTY_STORAGE_STATE: {
  storageState: {
    cookies: never[];
    origins: never[];
  };
};
declare const USER_AGENTS: {
  windows: string;
  mac: string;
  iPhone: string;
  iPad: string;
  android: string;
};
/**
 *
 * Description: Base URL for API endpoints.
 *
 * Value: "/api/v1"
 *
 * @example 
 *
 *   import { BASE_URL } from "@bigbinary/neeto-playwright-commons";
 * @endexample
*/
declare const BASE_URL = "/api/v1";
declare const NEETO_AUTH_BASE_URL: (subdomain?: string) => string;
/**
 *
 * Object containing various route URLs.
 *
 * @example 
 *
 *   import { ROUTES } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * neetoAuthSignup: URL for Neeto Auth signup page.
 *
 * neetoAuth: Base URL for Neeto Auth.
 *
 * loginLink: URL for login page.
 *
 * profile: URL for user profile page.
 *
 * admin: URL for admin page.
 *
 * myProfile: URL for personal profile page.
 *
 * authSettings: URL for authentication settings page.
 *
 * webhooks: URL for webhooks page.
 *
 * login: URL for login API endpoint.
 *
 * signup: URL for signup API endpoint.
 *
 * subdomainAvailability: URL for checking subdomain availability API endpoint.
 *
 * countries: URL for countries API endpoint.
 *
 * neetoApps: URL for Neeto Apps API endpoint.
 *
 * teamMembers: Object containing URLs related to team members.
 *
 * all: URL for retrieving all team members.
 *
 * bulkUpdate: URL for bulk updating team members.
 *
 * index: URL for team members index.
 *
 * show(id): Method to generate URL for showing a specific team member's details.
 *
*/
declare const ROUTES: {
  neetoAuthSignup: string;
  neetoAuth: string;
  loginLink: string;
  profile: string;
  admin: string;
  myProfile: string;
  authSettings: string;
  webhooks: string;
  login: string;
  signup: string;
  subdomainAvailability: string;
  countries: string;
  neetoApps: string;
  directUploads: string;
  teamMembers: {
    all: string;
    bulkUpdate: string;
    index: string;
    show: (id: string) => string;
  };
  attachment: string;
  dashboard: string;
  neetoThankYou: string;
};
/**
 *
 * Object containing API route URLs.
 *
 * @example 
 *
 * import { API_ROUTES } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * teamMembers: Object containing URLs related to team members (similar structure to ROUTES).
 *
 * integrations: Object containing URLs for integrations.
 *
 * zapier: Object containing URLs specific to Zapier integration.
 *
 * api_keys: URL for Zapier API keys.
 *
*/
declare const API_ROUTES: {
  teamMembers: {
    all: string;
    bulkUpdate: string;
    index: string;
    show: (id: string) => string;
    creationStatus: (id: string) => string;
  };
  integrations: {
    zapier: {
      api_keys: string;
    };
  };
};
/**
 *
 * Object containing URLs for third-party services.
 *
 * @example 
 *
 *  import { THIRD_PARTY_ROUTES } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * webhooks: Object containing URLs for webhook services.
 *
 * site: Base URL for webhook.site.
 *
 * slack: Object containing URLs for Slack.
 *
 * loginWithPassword(workspace): Method to generate URL for logging into Slack workspace using password.
 *
 * @example 
 *
 *   THIRD_PARTY_ROUTES.slack.loginWithPassword("example") // Outputs: "https://example.slack.com/sign_in_with_password"
 * @endexample
 * zapier: Object containing URLs for Zapier.
 *
 * login: URL for Zapier login.
 *
 * logOut: URL for Zapier logout.
 *
 * zapEditor(zapId): Method to generate URL for Zapier Zap editor.
 *
 * @example 
 *
 *   THIRD_PARTY_ROUTES.zapier.zapEditor("123") // Outputs: "https://zapier.com/editor/123"
 * @endexample
*/
declare const THIRD_PARTY_ROUTES: {
  webhooks: {
    site: string;
  };
  slack: {
    loginWithPassword: (workspace: string) => string;
  };
  zapier: {
    login: string;
    logOut: string;
    zapEditor: (zapId: string) => string;
  };
  google: {
    signin: string;
    password: string;
    totpChallenge: string;
    challengeSelection: string;
    myAccount: string;
    chooseAccount: string;
    consentScreen: string;
    warningScreen: string;
    additionalInfoScreen: string;
    consentSummary: string;
  };
};
declare const NEETO_ROUTES: {
  imageUploader: string;
};
declare const PROFILE_LINKS: {
  neetoStatus: string;
  neetoCommunity: string;
};
declare const networkConditions: Record<"Slow 3G" | "Fast 3G" | "No Throttling", Protocol.Network.emulateNetworkConditionsParameters>;
/**
 *
 * newConversation: Text for initiating a new conversation.
 *
 * welcomeChatBubble: Text for the welcome message displayed in the chat bubble.
 *
*/
declare const CHAT_WIDGET_TEXTS: {
  newConversation: string;
  welcomeChatBubble: string;
  preChatQuestions: string;
};
/**
 *
 * agent: Text representing an agent.
 *
*/
declare const MEMBER_TEXTS: {
  agent: string;
  admin: string;
  selectAll: string;
  hide: string;
  show: string;
};
/**
 *
 * connectHeader(integration): Method to generate text for connecting an integration account.
 *
 * connectedHeader(integration): Method to generate text indicating a successful connection to an integration.
 *
*/
declare const INTEGRATIONS_TEXTS: {
  connectHeader: (integration: string) => string;
  connectedHeader: (integration: string) => string;
};
/**
 *
 * signOut: Text for signing out.
 *
 * allow: Text for allowing.
 *
 * loadingThread: Text indicating thread loading.
 *
 * name: Text for name.
 *
 * deleteThisChannel: Text for deleting a channel.
 *
 * permanentlyDeleteTheChannel: Text for confirming permanent deletion of a channel.
 *
 * deleteChannel: Text for deleting a channel.
 *
*/
declare const SLACK_WEB_TEXTS: {
  signOut: string;
  allow: string;
  loadingThread: string;
  name: string;
  deleteThisChannel: string;
  permanentlyDeleteTheChannel: string;
  deleteChannel: string;
};
/**
 *
 * account: Text for account.
 *
 * email: Text for email.
 *
 * continue: Text for continue.
 *
 * statusLabel: Text for status label.
 *
 * editExistingDraft: Text for editing an existing draft.
 *
 * signInTo: Text for signing into Zapier.
 *
 * yesContinueTo: Text for confirming continuation to a specific destination.
 *
 * testTrigger: Text for testing a trigger.
 *
 * editStep: Text for editing a step.
 *
 * continueWithSelectedRecord: Text for continuing with a selected record.
 *
 * publish: Text for publishing.
 *
 * delete: Text for deleting.
 *
 * loading: Text indicating loading.
 *
 * subdomain: Text for subdomain.
 *
 * apiKey: Text for API key.
 *
 * publishingZapHeading: Text heading for preparing Zap to go live.
 *
 * connectionListMenu: Text for connection list item menu.
 *
 * usageRegExp: Text for usage reset information.
 *
 * trialEndsRegExp: Text for trial end date.
 *
 * testCurrentlyInQueue: Text indicating test currently in queue.
 *
 * welcomeText(zapierLoginEmail): Method to generate welcome text for Zapier login.
 *
 * connectStagingApp: Text for connecting to Staging application.
 *
 * zapierWorkflowTriggered: Text subject for the Outbound email.
 *
 * confirmPublishing: Text to confirm the publishing of the updated Zap.
 *
*/
declare const ZAPIER_WEB_TEXTS: {
  account: string;
  email: string;
  continue: string;
  statusLabel: string;
  password: string;
  editExistingDraft: string;
  signInTo: string;
  yesContinueTo: string;
  testTrigger: string;
  editStep: string;
  continueWithSelectedRecord: string;
  publish: string;
  delete: string;
  loading: string;
  subdomain: string;
  apiKey: string;
  publishingZapHeading: string;
  connectionListMenu: string;
  usageRegExp: string;
  trialEndsRegExp: string;
  testCurrentlyInQueue: string;
  welcomeText: (zapierLoginEmail: string) => string;
  connectStagingApp: (appName: string) => string;
  zapierWorkflowTriggered: string;
  confirmPublishing: string;
  startFreeWithEmail: string;
  appsByTitle: string;
  logIn: string;
  loginToYourAccount: string;
  deleteMessage: string;
};
/**
 *
 * zapierApiKeyGenerated: Message indicating successful generation of Zapier API key.
 *
*/
declare const TOASTR_MESSAGES: {
  zapierApiKeyGenerated: string;
};
/**
 *
 * Text indicating that Zapier's free task limit is exhausted and the test will be aborted.
 *
*/
declare const ZAPIER_LIMIT_EXHAUSTED_MESSAGE = "Zapier free task limit is exhausted. Test will be aborted";
declare const EMOJI_LABEL = "thumbs up";
declare const SELECT_COUNTRY = "Select country";
declare const GOOGLE_CALENDAR_DATE_FORMAT = "YYYY/M/D";
/**
 *
 * googleAccount: Text for google account.
 *
 * connectYourGoogleAccount: Text for connecting to your google account.
 *
 * signInWithGoogle: Text for signing in with google.
 *
 * signInHeading: Text heading for signing in.
 *
 * continue: Text for continue.
 *
 * selectAll: Text for selecting all permissions.
 *
 * appNotVerified: Text indicating app not verified.
 *
 * next: Text for next.
 *
 * showPassword: Text for showing password.
 *
 * emailOrPhone: Text indicating email or phone.
 *
 * enterYourPassword: Text for entering your password.
 *
 * twoStepVerification: Text for two-step verification.
 *
 * enterCode: "Text for entering code.
 *
 * allow: Text for allow.
 *
 * signOut: Text for signing out.
 *
 * wrongCode: "Text for wrong code.
 *
 * verificationCode: Text for verification code.
 *
 * confirm: Text for confirm.
 *
 * cancel: Text for cancel.
 *
 * deleteConnections: Text for deleting connections.
 *
 * noLongerConnected: Text indicating no longer connected.
 *
 * backToSafety: Text label for back to safety button.
 *
 * neetoAutomation: Text indicating neeto automation mail id.
 *
*/
declare const GOOGLE_LOGIN_TEXTS: {
  googleAccount: string;
  connectYourGoogleAccount: string;
  signInWithGoogle: string;
  signInHeading: (appName: string) => RegExp;
  continue: string;
  selectAll: string;
  appNotVerified: string;
  next: string;
  showPassword: string;
  emailOrPhone: string;
  enterYourPassword: string;
  twoStepVerification: string;
  enterCode: string;
  allow: string;
  signOut: string;
  wrongCode: string;
  verificationCode: string;
  confirm: string;
  cancel: string;
  deleteConnections: string;
  noLongerConnected: string;
  backToSafety: string;
  neetoAutomation: string;
};
declare const ENGAGE_TEXTS: {
  subscribe: string;
};
declare const COMMUNITY_TEXTS: {
  joinNow: string;
};
declare const STATUS_TEXTS: {
  application: (appName: NeetoProducts) => string;
};
declare const AUDIT_LOGS_TEXTS: {
  organizationRole: string;
};
/**
 *
 * skipCleanup: Text for skipping cleanup.
 *
 * skipSetup: Text for skipping setup.
 *
*/
declare const COMMON_TEXTS: {
  skipCleanup: string;
  skipSetup: string;
};
declare const ORGANIZATION_TEXTS: {
  subdomainAvailable: string;
};
declare const DESCRIPTION_EDITOR_TEXTS: {
  fontSize: string;
  paragraph: string;
  normalText: string;
  pasteLink: string;
  invalidURLError: string;
  pasteURL: string;
  delete: string;
  linkTag: string;
  link: string;
  cannedResponseHeader: string;
  paragraphOption: string;
  search: string;
  emoji: string;
};
declare const EXPANDED_FONT_SIZE: {
  h1: string;
  h2: string;
  h3: string;
  h4: string;
  h5: string;
};
declare const TEXT_MODIFIER_TAGS: {
  underline: string;
  strike: string;
  highlight: string;
};
declare const TEXT_MODIFIER_ROLES: {
  bold: string;
  italic: string;
  code: string;
  blockquote: string;
  codeBlock: string;
};
declare const LIST_MODIFIER_TAGS: {
  bulletList: string;
  orderedList: string;
};
/**
 *
 * Common selectors for UI elements.
 *
 * @example 
 *
 * import { COMMON_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * emailInputError: Selector for email input error.
 *
 * pane: Selector for pane wrapper.
 *
 * sideBar: Selector for side bar.
 *
 * copyButton: Selector for the copy button.
 *
 * resetButton: Selector for the reset button.
 *
 * spinner: Selector for spinners.
 *
 * uiSpinner: Selector for spinners.
 *
 * subheaderText: Selector to get the subheader text.
 *
 * alertTitle: Selector for alert titles.
 *
 * alertModalMessage: Selector for alert modal messages.
 *
 * alertModalSubmitButton: to get the submit button of the NeetoUI Alert component.
 *
 * checkbox: Selector for checkboxes.
 *
 * checkboxLabel: Selector for checkbox labels.
 *
 * dropdownContainer: Selector for dropdown containers.
 *
 * dropdownIcon: Selector for dropdown icons.
 *
 * heading: Selector for headings.
 *
 * paneBody: Selector for pane bodies.
 *
 * paneHeader: Selector for pane headers.
 *
 * profileSidebar: Selector for profile sidebars.
 *
 * selectOption(label: string): Method that generates a selector for select options based on the label.
 *
 * radioLabel(embedLabel: string): Method that generates a selector for radio labels based on the embedded label.
 *
 * toastMessage: To get the NeetoUI Toastr message.
 *
 * toastCloseButton: To get the NeetoUI Toastr close icon.
 *
 * windowAlert: Selector for window alerts.
 *
 * body: Selector for the body.
 *
 * toastIcon: To get the NeetoUI Toastr icon.
 *
 * toastContainer: To get the NeetoUI Toastr container.
 *
 * paneModalCrossIcon: Selector for pane modal cross icons.
 *
 * inputField: Selector to get NeetoUI input field.
 *
 * alertBox: Selector for alert box.
 *
 * tableContainer: Selector for table container.
 *
 * alertConfirmationText: Selector for alert confirmation text.
 *
 * alertCancelButton: Selector for alert cancel buttons.
 *
 * alertModalCrossIcon: Selector for alert modal cross icons.
 *
 * saveChangesButton: Selector for save changes buttons.
 *
 * cancelButton: Selector for cancel buttons.
 *
 * inputFieldError: Selector for input field errors.
 *
 * selectDropDownError: Selector for select dropdown errors.
 *
 * subTitleHeading: Selector for subtitle headings.
 *
 * noDataTitle: Selector for no data titles.
 *
 * noDataDescription: Selector for no data descriptions.
 *
 * noDataHelpText: Selector for no data help text.
 *
 * backdrop: Selector for backdrops.
 *
 * menuBarHeading: Selector for menu bar headings.
 *
 * dropdownWrapper: Selector for dropdown wrappers.
 *
 * toggleButton: Selector for toggle buttons.
 *
 * tooltip: Selector for tooltips.
 *
 * articlePageTitle: Selector for article page titles.
 *
 * tabItem: Selector for tab items.
 *
 * labelInputError: Selector for label input errors.
 *
 * urlInputError: Selector for URL input errors.
 *
 * noDataPrimaryButton: Selector for no data primary buttons.
 *
 * modalHeader: Selector for modal headers.
 *
 * nameInputError: Selector for name input errors.
 *
 * selectContainer: to get the select container.
 *
 * dropdownMenu: Selector for dropdown menus.
 *
 * sidebarToggle: Selector for sidebar toggles.
 *
 * subheader: Selector for subheaders.
 *
 * settingsLink: Selector for settings links.
 *
 * ticketFieldTextInput(label: string | number): Method that generates a selector for ticket field text inputs based on the label.
 *
 * appSwitcherButton: Selector for app switcher buttons.
 *
 * appSwitcherWrapper: Selector for app switcher wrappers.
 *
 * tableSpinner: Selector to get the spinner when the table is loading.
 *
 * pageLoader: Selector to get the spinner when the page element is loading.
 *
 * homeButton: Selector for home buttons.
 *
 * neetoUiSwitch: Selector for Neeto UI switches.
 *
 * floatingActionMenuButton: Selector for floating action menu buttons.
 *
 * columnsDropdownContainer: Selector for columns dropdown containers.
 *
 * columnsDropdownButton: Selector for columns dropdown buttons.
 *
 * breadcrumbHeader: Selector for breadcrumb headers.
 *
 * header: Selector to get the page header.
 *
 * sidebarSubLink(label: string): Method that generates a selector for sidebar sub-links based on the label.
 *
 * sidebarGoBackButton(label: string): Method that generates a selector for sidebar go-back buttons based on the label.
 *
 * selectSingleValue: Selector for select single values.
 *
 * actionSelectIndicator: Selector for action select indicator.
 *
 * takeActionDropdown: Selector for take action dropdown.
 *
 * columnsSearchInput: Selector for column search input.
 *
 * errorToastIcon: Selector for error toast icon.
 *
 * nuiRadioLabel: Selector for nui radio label.
 *
 * submitButton: Selector for submit button.
 *
 * tableRow: Selector for table row.
 *
 * navigationHeaderLeftBlock: Selector for navigation header left block.
 *
 * modalBody: Selector for modal body.
 *
 * modalFooter: Selector for modal footer.
 *
 * navigationHeader: Selector for navigation header,
 *
 * buttonSpinner: Selector for button spinner,
 *
 * customSelectValueContainer: Selector for custom value container,
 *
 * customDropDownMenu: Selector for custom dropdown menu,
 *
 * popoverTitle: Selector for the title of the help popover,
 *
 * appLink: Selector for the NeetoApp link,
 *
 * productSwitcherSearchInput: Selector for the product search input,
 *
 * helpPopoverButton: Selector for help popover button,
 *
 * helpPopoverDesc: Selector for help popover description,
 *
 * helpPopoverLinkButton: Selector for help popover link button,
 *
 * subheaderRight: Selector for right subheader,
 *
 * customInputLabel: Selector for custom input label,
 *
 * customInputField: Selector for custom input field,
 *
 * customSelectContainer: Selector for custom select container,
 *
 * customCheckboxLabel: Selector for custom checkbox label,
 *
 * errorImage: Selector for error image,
 *
 * customDropdownIcon: Selector for custom dropdown icon,
 *
 * customDropdownContainer: Selector for custom dropdown container,
 *
 * checkboxInput: Selector for checkbox input,
 *
 * radioInput: Selector for radio input,
 *
 * selectOptionError: Selector for select option error,
 *
 * pendingTagContainer: Selector for pending tag container.
 *
 * nextYearButton: Selector for next-year button.
 *
 * secretKeyInputField: Selector for the secret key input field.
 *
 * activeSwitch: Selector for the active/inactive toggle switch.
 *
 * labelInputField: Selector for a generic label input field.
 *
 * imageUploadModal: Selector for the image upload modal.
 *
 * neetoLogo: Selector for the sidebar logo.
 *
 * clearSelectIndicator: Selector for the clear option.
 *
 * menubarContainer: Selector for the menubar container.
 *
 * multiEmailInputContainer: Selector for the multi-email input field.
 *
 * linkInputError: Selector for displaying link input validation errors.
 *
 * continueButton: Selector for the continue button.
 *
 * clearAllButton: Selector for the clear all button.
 *
 * requiredSwitch: Selector for the required toggle switch.
 *
 * customSwitch: Selector for a custom-labeled switch.
 *
 * customMenuItem: Selector for a custom menu item.
 *
*/
declare const COMMON_SELECTORS: {
  emailInputError: string;
  pane: string;
  sideBar: string;
  copyButton: string;
  resetButton: string;
  spinner: string;
  uiSpinner: string;
  subheaderText: string;
  alertTitle: string;
  alertModalMessage: string;
  alertModalSubmitButton: string;
  checkbox: string;
  checkboxLabel: string;
  dropdownContainer: string;
  dropdownIcon: string;
  heading: string;
  paneBody: string;
  paneHeader: string;
  profileSidebar: string;
  selectOption: (label: string) => string;
  radioLabel: (embedLabel: string) => string;
  toastMessage: (type: string) => string;
  toastCloseButton: string;
  windowAlert: string;
  body: string;
  toastIcon: string;
  toastContainer: string;
  paneModalCrossIcon: string;
  inputField: string;
  alertBox: string;
  tableContainer: string;
  alertConfirmationText: string;
  alertCancelButton: string;
  alertModalCrossIcon: string;
  saveChangesButton: string;
  cancelButton: string;
  inputFieldError: string;
  selectDropDownError: string;
  subTitleHeading: string;
  noDataTitle: string;
  noDataDescription: string;
  noDataHelpText: string;
  backdrop: string;
  menuBarHeading: string;
  dropdownWrapper: string;
  toggleButton: string;
  tooltip: string;
  articlePageTitle: string;
  tabItem: string;
  labelInputError: string;
  urlInputError: string;
  noDataPrimaryButton: string;
  modalHeader: string;
  nameInputError: string;
  selectContainer: string;
  dropdownMenu: string;
  sidebarToggle: string;
  subheader: string;
  settingsLink: string;
  ticketFieldTextInput: (label: string) => string;
  appSwitcherButton: string;
  appSwitcherWrapper: string;
  appLink: (appName: NeetoProducts) => string;
  tableSpinner: string;
  pageLoader: string;
  homeButton: string;
  neetoUiSwitch: string;
  floatingActionMenuButton: string;
  columnsDropdownContainer: string;
  columnsDropdownButton: string;
  breadcrumbHeader: string;
  header: string;
  sidebarSubLink: (label: string) => string;
  sidebarGoBackButton: (label: string) => string;
  selectSingleValue: string;
  actionSelectIndicator: string;
  takeActionDropdown: string;
  columnsSearchInput: string;
  errorToastIcon: string;
  nuiRadioLabel: string;
  submitButton: string;
  tableRow: string;
  navigationHeaderLeftBlock: string;
  fileUploadBody: string;
  modalBody: string;
  modalForever: string;
  navigationHeader: string;
  buttonSpinner: string;
  pendingTagContainer: string;
  nextYearButton: string;
  popoverTitle: string;
  productSwitcherSearchInput: string;
  helpPopoverButton: string;
  helpPopoverDesc: string;
  helpPopoverLinkButton: string;
  copyToClipboardButton: string;
  subheaderRight: string;
  secretKeyInputField: string;
  activeSwitch: string;
  labelInputField: string;
  imageUploadModal: string;
  neetoLogo: string;
  clearSelectIndicator: string;
  menubarContainer: string;
  multiEmailInputContainer: string;
  linkInputError: string;
  continueButton: string;
  clearAllButton: string;
  requiredSwitch: string;
  customSwitch: (switchLabel: string) => string;
  customMenuItem: (label: string) => string;
  customInputLabel: (name?: string) => string;
  customInputField: (name?: string) => string;
  customSelectContainer: (name: string) => string;
  customSelectContainerWrapper: (label: string) => string;
  customSelectValueContainer: (label?: string) => string;
  customCheckboxLabel: (name: string) => string;
  errorImage: string;
  customDropdownIcon: (label?: string) => string;
  customDropdownContainer: (label?: string) => string;
  checkboxInput: (option?: string) => string;
  radioInput: (option?: string) => string;
  selectOptionError: (option: string) => string;
  customDropDownMenu: (label?: string) => string;
};
/**
 *
 * Selectors for thank you page components.
 *
 * @example 
 *
 * import { THANK_YOU_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * settingsLink: Selector for the settings link.
 *
 * showSocialShareIconsSwitch: Selector for the show social share icon switch.
 *
 * showLinkToSubmitAnotherResponseSwitch: Selector for the show link to submit another response switch.
 *
 * submitAnotherResponseLinkTextInputField: Selector for the submit another response link text input field.
 *
 * previewEditorContent: Selector for the preview editor content.
 *
 * redirectToExternalLinkRadioLabel: Selector for the redirect to external link radio label.
 *
 * saveChangesButton: Selector for the save changes button.
 *
 * cancelButton: Selector for the cancel button.
 *
 * thankYouPageImage: Selector for the thank you page image.
 *
 * thankYouPageContent: Selector for the thank you page content.
 *
 * thankYouPageResubmitLink: Selector for the thank you page resubmit link.
 *
 * linkInputField: Selector for the link input field.
 *
 * previewImage: Selector for image preview.
 *
 * thankYouMessageEditor: Selector for thank you message editor.
 *
*/
declare const THANK_YOU_SELECTORS: {
  settingsLink: string;
  showSocialShareIconsSwitch: string;
  showLinkToSubmitAnotherResponseSwitch: string;
  submitAnotherResponseLinkTextInputField: string;
  previewEditorContent: string;
  redirectToExternalLinkRadioLabel: () => string;
  thankYouConfigurationLabel: (label?: string) => string;
  saveChangesButton: string;
  cancelButton: string;
  thankYouPageImage: string;
  thankYouPageMessage: string;
  thankYouPageContent: string;
  thankYouPageResubmitLink: string;
  linkInputField: string;
  previewImage: string;
  thankYouMessageEditor: string;
};
/**
 *
 * Selectors for Neeto editor components.
 *
 * @example 
 *
 * import { NEETO_EDITOR_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * boldOption: Selector for the bold option.
 *
 * italicOption: Selector for the italic option.
 *
 * underlineOption: Selector for the underline option.
 *
 * strikeOption: Selector for the strike option.
 *
 * codeBlockOption: Selector for the code block option.
 *
 * highlightOption: Selector for the highlight option.
 *
 * linkInput: Selector for the link input.
 *
 * linkSubmitButton: Selector for the link submit button.
 *
 * commandList(index: number): Method that generates a selector for command list items based on the index.
 *
 * imageUploadUrlSubmitButton: Selector for the image upload URL submit button.
 *
 * imageUploadUrlInputTextField: Selector for the image upload URL input text field.
 *
 * uploadInput: Selector for the upload input.
 *
 * editorMenuBarWrapper: Selector for the editor menu bar wrapper.
 *
 * undoOption: Selector for the undo option.
 *
 * redoOption: Selector for the redo option.
 *
 * imageWrapper: Selector for the image wrapper.
 *
 * contentField: Selector for the content field.
 *
 * addLinkButton: Selector for the add link button.
 *
 * addLinkTextField: Selector for the add link text input field.
 *
 * addURLTextField: Selector for the add URL input field.
 *
 * submitLinkButton: Selector for the submit link button.
 *
 * errorText: Selector for the error text.
 *
 * content: Selector for the editor content.
 *
 * characterCount: Selector for the character count.
 *
 * tableOption: Selector for the table option in the editor menu.
 *
 * tableCreateButton: Selector for the button that creates a table in the editor.
 *
 * videoUploadOption: Selector for the video upload option in the editor.
 *
 * editorMenuWrapper: Selector for the wrapper of the fixed editor menu.
 *
 * editorMediaUploaderTab: Selector for the media upload tab.
 *
*/
declare const NEETO_EDITOR_SELECTORS: {
  fontSize: string;
  boldOption: string;
  italicOption: string;
  underlineOption: string;
  strikeOption: string;
  codeBlockOption: string;
  highlightOption: string;
  emojiOption: string;
  emojiDropdownIcon: string;
  linkInput: string;
  linkSubmitButton: string;
  commandList: (index: number) => string;
  imageUploadUrlSubmitButton: string;
  imageUploadUrlInputTextField: string;
  uploadInput: string;
  editorMenuBarWrapper: string;
  undoOption: string;
  redoOption: string;
  imageWrapper: string;
  contentField: string;
  addLinkButton: string;
  addLinkTextField: string;
  addURLTextField: string;
  submitLinkButton: string;
  fixedMenuArrow: string;
  cannedResponseOption: string;
  cannedResponseSelectContainer: string;
  fixedMenuWrapper: string;
  linkOption: string;
  addLinkUrlInput: string;
  addLinkDoneButton: string;
  unlinkButton: string;
  editorAttachmentsButton: string;
  attachmentPreviewDeleteButton: string;
  imageUploadOption: string;
  imageUploadLinkInput: string;
  imageUploadButton: string;
  imageUploadLinkSubmitButton: string;
  applyButton: string;
  videoEmbedOption: string;
  videoEmbedInput: string;
  videoEmbedSubmit: string;
  videoWrapper: string;
  paragraphOption: string;
  attachmentPreview: string;
  imageUploadLinkButton: string;
  errorText: string;
  content: string;
  imageUploadDeleteButton: string;
  dynamicVariablesButton: string;
  emojiContainer: string;
  characterCount: string;
  tableOption: string;
  tableCreateButton: string;
  videoUploadOption: string;
  editorMenuWrapper: string;
  editorMediaUploaderTab: string;
  dynamicVariableSelector: (variable: string) => string;
};
declare const NEETO_TEXT_MODIFIER_SELECTORS: {
  strike: string;
  underline: string;
  highlight: string;
};
declare const TEXT_MODIFIER_SELECTORS: {
  bold: string;
  italic: string;
  code: string;
  blockquote: string;
  codeBlock: string;
};
declare const LIST_MODIFIER_SELECTORS: {
  bulletList: string;
  orderedList: string;
};
declare const FONT_SIZE_SELECTORS: {
  h1: string;
  h2: string;
  h3: string;
  h4: string;
  h5: string;
};
/**
 *
 * Selectors for embed components.
 *
 * @example 
 *
 * import { EMBED_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * iframe(appName: string): Method that generates a selector for the iframe based on the app name.
 *
 * modal(appName: string): Method that generates a selector for the modal based on the app name.
 *
 * close(appName: string): Method that generates a selector for the close button based on the app name.
 *
 * loader(appName: string): Method that generates a selector for the loader based on the app name.
 *
 * inlineHeightInput: Selector for the inline height input field.
 *
 * inlineWidthInput: Selector for the inline width input field.
 *
 * inlineElementIdInput: Selector for the inline element ID input field.
 *
 * codeBlock: Selector for the code block.
 *
 * previewTab: Selector for the preview tab.
 *
 * htmlTab: Selector for the HTML tab.
 *
 * buttonTextInput: Selector for the button text input field.
 *
 * buttonPositionSelectContainer: Selector for the button position select container.
 *
 * buttonPositionSelectMenu: Selector for the button position select menu.
 *
 * buttonColorLabel: Selector for the button color label.
 *
 * buttonTextColorLabel: Selector for the button text color label.
 *
 * colorPickerTarget: Selector for the color picker target.
 *
 * colorpickerEditableInput: Selector for the color picker editable input.
 *
 * colorpickerEditableInputTextbox: Selector for the color picker editable input textbox.
 *
 * showIconCheckbox: Selector for the show icon checkbox.
 *
 * elementIdInput: Selector for the element ID input field.
 *
 * previewElementPopupButton: Selector for the preview element popup button.
 *
 * embedSelector: Selector for the embed card to select embed type.
 *
 * backToEmbedSelectionButton: Selector for the back button to select embed type.
 *
*/
declare const EMBED_SELECTORS: {
  iframe: (appName: string) => string;
  modal: (appName: string) => string;
  close: (appName: string) => string;
  loader: (appName: string) => string;
  inlineHeightInput: string;
  inlineWidthInput: string;
  inlineElementIdInput: string;
  codeBlock: string;
  previewTab: string;
  htmlTab: string;
  buttonTextInput: string;
  buttonPositionSelectContainer: string;
  buttonPositionSelectMenu: string;
  buttonColorLabel: string;
  buttonTextColorLabel: string;
  colorPickerTarget: string;
  colorpickerEditableInput: string;
  colorpickerEditableInputTextbox: string;
  showIconCheckbox: string;
  elementIdInput: string;
  previewElementPopupButton: string;
  embedSelector: (embedType: string) => string;
  backToEmbedSelectionButton: string;
};
/**
 *
 * Selectors for Neeto filters components.
 *
 * @example 
 *
 * import { NEETO_FILTERS_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * emailSelectContainer: Selector for the email select container wrapper.
 *
 * filterPaneHeading: Selector for the Neeto filters pane header.
 *
 * neetoFiltersEmailBlock: Selector for the Neeto filters email block.
 *
 * neetoFiltersRoleBlock: Selector for the Neeto filters role block.
 *
 * neetoFiltersBarClearButton: Selector for the Neeto filters bar clear button.
 *
 * neetoFiltersNameFilterField: Selector for the Neeto filters name filter field.
 *
 * neetoFilterNameBlock: Selector for the Neeto filter name block.
 *
 * roleSelectContainer: Selector for the role select container wrapper.
 *
 * filterButton: Selector for the Neeto filters toggle button.
 *
 * filtersClearButton: Selector for the Neeto filters clear button.
 *
 * filterDoneButton: Selector for the Neeto filters done button.
 *
 * filteredMembersCount: Selector for the filtered members count.
 *
 * allMenubarBlock: Selector for the all menubar block.
 *
 * filtersEmailFilter: Selector for the Neeto filters email filter.
 *
 * paneModalCrossIcon: Selector for the Neeto filters pane modal cross icon.
 *
 * searchTermBlock: Selector for the Neeto filters search term block.
 *
 * categoriesFilter: Selector for the Neeto filters categories filter.
 *
 * filtersTermBlock: Custom selector for filters term block.
 *
 * filtersSegmentName: Selector for the filter segment name input.
 *
 * activeSelectContainer: Selector for the container holding the active status filter.
 *
 * dateRange: Selector for a specific date range filter by name.
 *
 * segmentLabel: Selector for a specific segment block label.
 *
*/
declare const NEETO_FILTERS_SELECTORS: {
  emailSelectContainer: string;
  filterPaneHeading: string;
  neetoFiltersEmailBlock: string;
  neetoFiltersRoleBlock: string;
  neetoFiltersBarClearButton: string;
  neetoFiltersNameFilterField: string;
  neetoFilterNameBlock: string;
  roleSelectContainer: string;
  filterButton: string;
  filtersClearButton: string;
  filterDoneButton: string;
  filteredMembersCount: string;
  allMenubarBlock: string;
  filtersEmailFilter: string;
  paneModalCrossIcon: string;
  searchTermBlock: string;
  categoriesFilter: string;
  filtersSegmentName: string;
  activeSelectContainer: string;
  neetoFiltersFilter: (filterName: string) => string;
  filtersTermBlock: (filterType?: string) => string;
  dateRange: (filterName: string) => string;
  segmentLabel: (label: string) => string;
};
/**
 *
 * Selectors for Help Center components.
 *
 * @example 
 *
 * import { HELP_CENTER_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * helpButton: Selector for the help button.
 *
 * documentationButton: Selector for the documentation button.
 *
 * keyboardShortcutButton: Selector for the keyboard shortcut button.
 *
 * chatButton: Selector for the chat button.
 *
 * whatsNewButton: Selector for the "What's New" button.
 *
 * whatsNewWidgetInfo: Selector for the "What's New" widget info.
 *
 * whatsNewWidgetCloseButton: Selector for the "What's New" widget close button.
 *
 * keyboardShortcutPaneHeading: Selector for the keyboard shortcut pane heading.
 *
 * keyboardShortcutPaneCrossIcon: Selector for the keyboard shortcut pane cross icon.
 *
 * statusButton: Selector for the status button.
 *
 * communityButton: Selector for the community button.,
 *
*/
declare const HELP_CENTER_SELECTORS: {
  helpButton: string;
  documentationButton: string;
  keyboardShortcutButton: string;
  chatButton: string;
  whatsNewButton: string;
  whatsNewWidgetInfo: string;
  whatsNewWidgetCloseButton: string;
  keyboardShortcutPaneHeading: string;
  keyboardShortcutPaneCrossIcon: string;
  statusButton: string;
  communityButton: string;
};
declare const NEETO_IMAGE_UPLOADER_SELECTORS: {
  imageUploaderWrapper: string;
  browseText: string;
  fileInput: string;
  uploadedImage: string;
  uploadNewAsset: string;
  basicImageUploaderRemoveButton: string;
  removeButton: string;
  openImageLibraryButton: string;
  openAssetLibraryButton: string;
  imageEditorBackButton: string;
  aspectRatioWidthInput: string;
  aspectRatioHeightInput: string;
  cropSubmitButton: string;
  restrictionMessage: string;
  progressBar: string;
  myImagesTab: string;
  unsplashTab: string;
  nthLibraryImage: (index: number) => string;
  nthUnsplashImage: (index: number) => string;
  unsplashSearchInput: string;
  imageEditorUploadedImage: string;
  selectOriginalImageSwitch: string;
  lockAspectRatioSwitch: string;
  widthInputField: string;
  heightInputField: string;
};
/**
 *
 * Selectors for login components.
 *
 * @example 
 *
 * import { LOGIN_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * appleAuthenticationButton: Selector for the Apple authentication button.
 *
 * emailTextField: Selector to get the email field.
 *
 * googleAuthenticationButton: Selector for the Google authentication button.
 *
 * githubAuthenticationButton: Selector for the GitHub authentication button.
 *
 * loginViaEmailButton: Selector for the login via email button.
 *
 * passwordTextField: Selector for the password text field.
 *
 * rememberMeCheckBox: Selector for the remember me check box.
 *
 * submitButton: Selector for the submit button.
 *
 * twitterAuthenticationButton: Selector for the Twitter authentication button.
 *
*/
declare const LOGIN_SELECTORS: {
  appleAuthenticationButton: string;
  emailTextField: string;
  googleAuthenticationButton: string;
  githubAuthenticationButton: string;
  loginViaEmailButton: string;
  passwordTextField: string;
  rememberMeCheckBox: string;
  submitButton: string;
  twitterAuthenticationButton: string;
};
/**
 *
 * Selectors for member components.
 *
 * @example 
 *
 * import { MEMBER_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * membersTab: Selector for the members tab.
 *
 * newButton: Selector for the "New" button to add a new member.
 *
 * continueButton: Selector for the "Continue" button.
 *
 * submitButton: Selector for the "Submit" button.
 *
 * searchTextField: Selector for the search text field.
 *
 * deactivatedAgentsButton: Selector for the deactivated agents button.
 *
 * activatedMembersButton: Selector for the activated members button.
 *
 * columnCheckBox: Selector to get the NeetoUI checkbox.
 *
 * roleLabel(role: string): Method that generates a selector for role labels based on the role.
 *
 * dropDownIcon: Selector to get the NeetoUI Dropdown icon button.
 *
 * editButton: Selector for the edit button.
 *
 * menuBarHeading: Selector for the menu bar heading.
 *
 * removeMember: Selector for the remove member button.
 *
 * columnsButton: Selector for the columns button.
 *
 * columnsDropdownContainer: Selector for the columns dropdown container.
 *
 * emailDropdownItemLabel: Selector for the email dropdown item label.
 *
 * roleDropdownItemLabel: Selector for the role dropdown item label.
 *
 * inviteStatusDropdownItemLabel: Selector for the invite status dropdown item label.
 *
 * heading: Selector for the manage members pane header.
 *
 * activateButton: Selector for the activate members button.
 *
 * deactivateButton: Selector for the deactivate members button.
 *
 * rolesButton: Selector for the manage member roles button.
 *
 * statusTag: Selector for the member status tag.
 *
 * subscriptionPlanTag: Selector for subscription plan tag.
 *
 * memberNameCell: Selector for member name or email cell in members table.
 *
*/
declare const MEMBER_SELECTORS: {
  membersTab: string;
  newButton: string;
  continueButton: string;
  submitButton: string;
  searchTextField: string;
  deactivatedAgentsButton: string;
  activatedMembersButton: string;
  columnCheckBox: string;
  roleLabel: (role: string) => string;
  teamMembersTable: string;
  dropDownIcon: string;
  editButton: string;
  menuBarHeading: string;
  removeMember: string;
  columnsButton: string;
  columnsDropdownContainer: string;
  emailDropdownItemLabel: string;
  roleDropdownItemLabel: string;
  inviteStatusDropdownItemLabel: string;
  heading: string;
  activateButton: string;
  deactivateButton: string;
  rolesButton: string;
  statusTag: string;
  menubarSubLink: (sublink: string) => string;
  takeActionStateOption: (option?: string) => string;
  checkboxLabel: (label: string) => string;
  subscriptionPlanTag: string;
  memberNameCell: (nameOrEmail: string) => string;
};
/**
 *
 * Selectors for member form components.
 *
 * @example 
 *
 * import { MEMBER_FORM_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * emailTextField: Selector for the email text field in the member form.
 *
 * firstNameTextField: Selector for the first name text field in the member form.
 *
 * lastNameTextField: Selector for the last name text field in the member form.
 *
 * emailInput: Selector for the email input in the member form.
 *
 * emailErrorField: Selector for the email error field in the member form.
 *
 * cancelButton: Selector for the cancel button in the member form.
 *
*/
declare const MEMBER_FORM_SELECTORS: {
  emailTextField: string;
  firstNameTextField: string;
  lastNameTextField: string;
  emailInput: string;
  emailErrorField: string;
  cancelButton: string;
};
/**
 *
 * Selectors for profile section components.
 *
 * @example 
 *
 * import { PROFILE_SECTION_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * profileSectionButton: Selector for the profile section button.
 *
 * profilePopup: Selector for the profile popup.
 *
 * myProfileButton: Selector for the "My Profile" button.
 *
 * profileOrganizationSettingsButton: Selector for the profile organization settings button.
 *
 * logoutButton: Selector for the logout button.
 *
 * neetoAuthLink: Selector for the Neeto authentication link button.
 *
 * profileSidebarCancelButton: Selector for the profile sidebar cancel button.
 *
 * profileAvatar: Selector for the profile avatar.
 *
 * actionHeaderUserEmail: Selector for the user email.
 *
 * submitButton: Selector for the submit button.
 *
*/
declare const PROFILE_SECTION_SELECTORS: {
  profileSectionButton: string;
  profilePopup: string;
  myProfileButton: string;
  profileOrganizationSettingsButton: string;
  logoutButton: string;
  neetoAuthLink: string;
  profileSidebarCancelButton: string;
  profileAvatar: string;
  actionHeaderUserEmail: string;
  submitButton: string;
};
/**
 *
 * Selectors for roles components.
 *
 * @example 
 *
 * import {
 *  ROLES_SELECTORS
 * } from "@bigbinary/neeto-playwright-commons";
 * 
 * @endexample
 * newButton: Selector for the "New" button to add a new role.
 *
 * proceedButton: Selector for the "Proceed" button.
 *
 * cancelButton: Selector for the "Cancel" button.
 *
 * tableHeaderRoleName: Selector for the table header role name.
 *
 * nameTextField: Selector for the name text field when adding or updating a role.
 *
 * searchTextField: Selector for the search text field for roles.
 *
 * updateRolePaneHeading: Selector for the heading when updating a role.
 *
 * updateRoleCancelButton: Selector for the cancel button when updating a role.
 *
 * descriptionTextField: Selector for the description text field when adding or updating a role.
 *
 * permissionCategoryTitle: Selector for the title of the permission category.
 *
 * headerColumn: Selector for the header column of the roles table.
 *
 * dropDownIcon: Selector for the dropdown icon in the roles table header.
 *
 * tableHeaderRoleTitle: Selector for the title in the roles table header.
 *
 * permissionCheckbox: Selector for the permission checkbox.
 *
 * editRoleButton: Selector for the edit role button in the roles table.
 *
 * deleteRoleButton: Selector for the delete role button in the roles table.
 *
 * permissionCard: Selector for the permission card.
 *
 * searchPermissionsInput: Selector for the search input.
 *
 * permissionDescription: Selector for the permission description.
 *
 * rolesEditButton: Selector for the edit button.
 *
*/
declare const ROLES_SELECTORS: {
  newButton: string;
  proceedButton: string;
  cancelButton: string;
  tableHeaderRoleName: string;
  nameTextField: string;
  searchTextField: string;
  updateRolePaneHeading: string;
  updateRoleCancelButton: string;
  descriptionTextField: string;
  permissionCategoryTitle: string;
  headerColumn: string;
  dropDownIcon: string;
  tableHeaderRoleTitle: string;
  permissionCheckbox: string;
  editRoleButton: string;
  deleteRoleButton: string;
  permissionCard: string;
  searchPermissionsInput: string;
  permissionDescription: string;
  rolesEditButton: string;
};
/**
 *
 * @example 
 *
 * import { SIGNUP_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * Selectors for signup components.
 *
 * emailTextField: Selector for the email text field in the signup form.
 *
 * firstNameTextField: Selector for the first name text field in the signup form.
 *
 * lastNameTextField: Selector for the last name text field in the signup form.
 *
 * organizationNameTextField: Selector for the organization name text field in the signup form.
 *
 * organizationSubmitButton: Selector for the organization submit button in the signup form.
 *
 * otpTextBox: Selector for the OTP input text box in the signup form.
 *
 * profileSubmitButton: Selector for the profile submit button in the signup form.
 *
 * signupViaEmailButton: Selector for the signup via email button.
 *
 * submitButton: Selector for the submit button in the signup form.
 *
 * subdomainNameTextField: Selector for the subdomain name text field in the signup form.
 *
 * subdomainError: Selector for the subdomain input error message in the signup form.
 *
 * tryFreeButton: Selector for the "Try Free" button.
 *
 * unregisterdEmailError: Selector for the error message when using an unregistered email in the signup form.
 *
*/
declare const SIGNUP_SELECTORS: {
  emailTextField: string;
  firstNameTextField: string;
  lastNameTextField: string;
  organizationNameTextField: string;
  organizationSubmitButton: string;
  otpTextBox: string;
  profileSubmitButton: string;
  signupViaEmailButton: string;
  submitButton: string;
  subdomainNameTextField: string;
  subdomainError: string;
  tryFreeButton: string;
  unregisterdEmailError: string;
};
/**
 *
 * Selectors for tab components.
 *
 * @example 
 *
 * import { TAB_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * configureTab: Selector for the configure tab.
 *
 * buildTab: Selector for the build tab.
 *
 * themeTab: Selector for the theme tab.
 *
 * shareTab: Selector for the share tab.
 *
 * submissionsTab: Selector for the submissions tab.
 *
 * paymentsTab: Selector for the payments tab.
 *
 * settingsTab: Selector for the settings tab.
 *
*/
declare const TAB_SELECTORS: {
  configureTab: string;
  buildTab: string;
  themeTab: string;
  shareTab: string;
  submissionsTab: string;
  paymentsTab: string;
  settingsTab: string;
};
/**
 *
 * Selectors for tags components.
 *
 * @example 
 *
 * import { TAGS_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * newTagButton: Selector for the "New Tag" button.
 *
 * tagNameTextField: Selector for the tag name text field.
 *
 * editButton: Selector for the edit button for tags.
 *
 * deleteButton: Selector for the delete button for tags.
 *
 * cancelButton: Selector for the cancel button when managing tags.
 *
 * submitButton: Selector for the submit button when managing tags.
 *
 * searchTextField: Selector for the search text field for tags.
 *
 * descriptionTextArea: Selector for the description text area for tags.
 *
 * addTagButton: Selector for the button to add a new tag.
 *
 * tagSearchField: Selector for the tag search input field.
 *
 * deleteTagButton: Selector for the button to delete a tag.
 *
 * metaDataCard: Selector for the metadata card container.
 *
 * metaDataBlock: Selector for individual metadata blocks inside the card.
 *
 * tagContainer: Selector for the tag container.
 *
 * tagsCount: Selector for tags count text.
 *
*/
declare const TAGS_SELECTORS: {
  newTagButton: string;
  tagNameTextField: string;
  editButton: string;
  deleteButton: string;
  cancelButton: string;
  submitButton: string;
  searchTextField: string;
  descriptionTextArea: string;
  addTagButton: string;
  tagSearchField: string;
  deleteTagButton: string;
  metaDataCard: string;
  metaDataBlock: string;
  tagContainer: string;
  tagsCount: string;
};
/**
 *
 * Selectors for merging tags components.
 *
 * @example 
 *
 * import { MERGE_TAGS_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * mergeTagsButton: Selector for the "Merge Tags" button.
 *
 * mergeButton: Selector for the merge button.
 *
 * sourceSearchTextField: Selector for the search text field in the source tags section.
 *
 * sourceTagsList: Selector for the list of source tags.
 *
 * destinationTagsList: Selector for the list of destination tags.
 *
 * destinationSearchTextField: Selector for the search text field in the destination tags section.
 *
 * cancelButton: Selector for the cancel button when merging tags.
 *
 * proceedButton: Selector for the proceed button when merging tags.
 *
 * disabledTag: Selector for disabled tags.
 *
*/
declare const MERGE_TAGS_SELECTORS: {
  mergeTagsButton: string;
  mergeButton: string;
  sourceSearchTextField: string;
  sourceTagsList: string;
  destinationTagsList: string;
  destinationSearchTextField: string;
  cancelButton: string;
  proceedButton: string;
  disabledTag: string;
  sourceTagRow: string;
  destinationTagRow: string;
};
/**
 *
 * Selectors for the chat widget components.
 *
 * @example 
 *
 * import { CHAT_WIDGET_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * iframe: Selector for the chat widget iframe.
 *
 * spinner: Selector for the spinner in the chat widget.
 *
 * helpButton: Selector for the help button in the chat widget.
 *
 * preChatEmailInput: Selector for the email input in the pre-chat section of the chat widget.
 *
 * preChatSubmitButton: Selector for the submit button in the pre-chat section of the chat widget.
 *
 * chatBubble: Selector for the chat message bubble in the chat widget.
 *
 * closeChat: Selector for the close button in the chat widget.
 *
 * chatQuestionHeader: Selector for the chat question header.
 *
 * openChat: Selector for the chat widget open button.
 *
 * homeScreenSubtitle: Selector for the home screen subtitle.
 *
*/
declare const CHAT_WIDGET_SELECTORS: {
  iframe: string;
  spinner: string;
  helpButton: string;
  preChatEmailInput: string;
  preChatSubmitButton: string;
  chatBubble: string;
  closeChat: string;
  chatQuestionHeader: string;
  openChat: string;
  homeScreenSubtitle: string;
};
/**
 *
 * @example 
 *
 * import { CHANGELOG_WIDGET_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * Selectors for the changelog widget components.
 *
 * changelogWrapper: Selector for the wrapper of the changelog widget.
 *
 * closeButton: Selector for the close button in the changelog widget.
 *
 * publicUrlLink: Selector for the public URL link in the changelog widget.
 *
*/
declare const CHANGELOG_WIDGET_SELECTORS: {
  changelogWrapper: string;
  closeButton: string;
  publicUrlLink: string;
};
/**
 *
 * Selectors for the keyboard shortcuts pane components.
 *
 * @example 
 *
 * import { KEYBOARD_SHORTCUTS_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * keyboardShortcutsPane: Selector for the keyboard shortcuts pane.
 *
 * closePaneButton: Selector for the close button in the keyboard shortcuts pane.
 *
 * hotKeyItem: Selector for the hotkey item in the keyboard shortcuts pane.
 *
*/
declare const KEYBOARD_SHORTCUTS_SELECTORS: {
  keyboardShortcutsPane: string;
  closePaneButton: string;
  hotKeyItem: string;
};
/**
 *
 * Selectors for integration components.
 *
 * @example 
 *
 * import { INTEGRATION_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * integrationCard(integration: string): Method that generates a selector for the integration card based on the integration name. Accepts a string parameter representing the integration name.
 *
 * connectButton: Selector for the connect button.
 *
 * integrationStatusTag: Selector for the integration status tag.
 *
 * disconnectButton: Selector for the disconnect button.
 *
 * manageButton: Selector for the manage button.
 *
 * integrationConnectedTag: Selector for the connected tag.
 *
*/
declare const INTEGRATION_SELECTORS: {
  integrationCard: (integration: string) => string;
  connectButton: string;
  integrationStatusTag: string;
  disconnectButton: string;
  manageButton: string;
  integrationConnectedTag: string;
};
declare const GOOGLE_LOGIN_SELECTORS: {
  totpNext: string;
  form: string;
  totpChallengeSelector: string;
  signOutFrameLocator: string;
};
/**
 *
 * Selectors for Slack components.
 *
 * @example 
 *
 * import { SLACK_SELECTORS} from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * messageContainer: Selector for the message container.
 *
 * loginEmail: Selector for the login email input.
 *
 * loginPassword: Selector for the login password input.
 *
 * signInButton: Selector for the sign-in button.
 *
 * teamPicketButtonContent: Selector for the team picker button content.
 *
 * redirectOpenInBrowser: Selector for the redirect "open in browser" button.
 *
 * workspaceActionsButton: Selector for the workspace actions button.
 *
 * teamMenuTrigger: Selector for the team menu trigger.
 *
 * menuItemButton: Selector for the menu item button.
 *
 * threadsFlexpane: Selector for the threads flexpane.
 *
 * replyBar: Selector for the reply bar.
 *
 * markdownElement: Selector for the markdown element.
 *
 * virtualListItem: Selector for the virtual list item.
 *
 * channelItems: Selector for channel items.
 *
*/
declare const SLACK_SELECTORS: {
  messageContainer: string;
  loginEmail: string;
  loginPassword: string;
  signInButton: string;
  teamPicketButtonContent: string;
  redirectOpenInBrowser: string;
  workspaceActionsButton: string;
  teamMenuTrigger: string;
  menuItemButton: string;
  threadsFlexpane: string;
  replyBar: string;
  markdownElement: string;
  virtualListItem: string;
  channelItems: string;
};
/**
 *
 * Selectors for Slack components using 'data-qa' attributes.
 *
 * @example 
 *
 * import { SLACK_DATA_QA_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * sectionHeadingButton: Selector for the section heading button.
 *
 * channelSectionSubmenuCreate: Selector for the channel section submenu create button.
 *
 * channelSectionMenuCreateChannel: Selector for the channel section menu create channel button.
 *
 * skModalContent: Selector for the modal content.
 *
 * infiniteSpinner: Selector for the infinite spinner.
 *
 * channelNameOptionsList: Selector for the channel name options list.
 *
 * channelNameInput: Selector for the channel name input.
 *
 * createChannelNextButton: Selector for the create channel next button.
 *
 * inviteToWorkspaceSkipButton: Selector for the invite to workspace skip button.
 *
 * menuItems: Selector for the menu items.
 *
 * channelDetailsModal: Selector for the channel details modal.
 *
 * channelDetailsSettingsTab: Selector for the channel details settings tab.
 *
*/
declare const SLACK_DATA_QA_SELECTORS: {
  sectionHeadingButton: string;
  coachMarkCloseButton: string;
  messagePaneBannerCloseIcon: string;
  permissionBannerCloseIcon: string;
  channelSectionSubmenuCreate: string;
  channelSectionMenuCreateChannel: string;
  skModalContent: string;
  infiniteSpinner: string;
  channelNameOptionsList: string;
  channelNameInput: string;
  createChannelNextButton: string;
  inviteToWorkspaceSkipButton: string;
  menuItems: string;
  channelDetailsModal: string;
  channelDetailsSettingsTab: string;
};
/**
 *
 * Selectors for webhook components.
 *
 * @example 
 *
 * import { WEBHOOK_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * addNewWebhook: Selector for the "Add New Webhook" button.
 *
 * endpointInputField: Selector for the endpoint input field.
 *
 * deliveryResponseCode: Selector for the delivery response code.
 *
 * deliveryRequestPayload: Selector for the delivery request payload.
 *
 * addSecretKey: Selector for add secret key button.
 *
 * newWebhookHeader: Selector for new webhook pane header.
 *
 * endpointInputError: Selector for endpoint input error.
 *
 * eventsSelectError: Selector for event select error.
 *
 * regenerateSecret: Selector for regenerate secret key button.
 *
 * deleteSecret: Selector for delete secret key button.
 *
 * editWebhookButton: Selector for edit API key button.
 *
 * deleteWebhookButton: Selector for delete API key button.
 *
*/
declare const WEBHOOK_SELECTORS: {
  addNewWebhook: string;
  endpointInputField: string;
  deliveryResponseCode: string;
  deliveryRequestPayload: string;
  addSecretKey: string;
  newWebhookHeader: string;
  endpointInputError: string;
  eventsSelectError: string;
  regenerateSecret: string;
  deleteSecret: string;
  editWebhookButton: string;
  deleteWebhookButton: string;
};
/**
 *
 * Selectors for Zapier components.
 *
 * @example 
 *
 * import { ZAPIER_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * zapTriggerStep(zapId: string): Method that generates a selector for the Zap trigger step based on the Zap ID. Accepts a string parameter representing the Zap ID.
 *
 * zapAccountSubstep: Selector for the Zap account substep.
 *
 * zapOpenSubstepContainer: Selector for the container to open substeps.
 *
 * modal: Selector for modals.
 *
 * fmPrettytext: Selector for pretty text.
 *
 * spinner: Selector for spinners.
 *
 * skeletonBlock: Selector for skeleton blocks.
 *
 * accountsLoader: Selector for accounts loader.
 *
 * floatingBox: Selector for floating boxes.
 *
 * connection: Selector for connections.
 *
 * deleteConnectionModal: Selector for the delete connection modal.
 *
 * deleteConnectionDropdownButton: Selector for the dropdown button to delete a connection.
 *
 * usageAmounts: Selector for usage amounts.
 *
 * universalSidebar: Selector for the universal sidebar.
 *
 * sidebarFooter: Selector for the sidebar footer.
 *
 * contextualSideBar: Selector for the contextual sidebar.
 *
 * deleteApiButton: Selector for the delete button.
 *
 * zapierSubLink: Selector for the Zapier sub-link.
 *
*/
declare const ZAPIER_SELECTORS: {
  zapTriggerStep: (zapId: string) => string;
  zapAccountSubstep: string;
  zapOpenSubstepContainer: string;
  modal: string;
  fmPrettytext: string;
  spinner: string;
  skeletonBlock: string;
  accountsLoader: string;
  floatingBox: string;
  connection: string;
  deleteConnectionModal: string;
  deleteConnectionDropdownButton: string;
  usageAmounts: string;
  universalSidebar: string;
  sidebarFooter: string;
  contextualSideBar: string;
  iconContainer: string;
  deleteApiButton: string;
  zapierSubLink: string;
};
/**
 *
 * Selectors for table components.
 *
 * @example 
 *
 * import { TABLE_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * freezeUnfreezeButton: Selector for freeze/unfreeze column button.
 *
 * ascendingButton: Selector for ascending column button.
 *
 * descendingButton: Selector for descending column button.
 *
 * hideButton: Selector for hide column button.
 *
 * columnHeaderTitle: Selector for column header title.
 *
 * columnMenuButton: Selector for column menu button.
 *
*/
declare const TABLE_SELECTORS: {
  freezeUnfreezeButton: string;
  ascendingButton: string;
  descendingButton: string;
  hideButton: string;
  columnHeaderTitle: (columnName: string) => string;
  columnMenuButton: string;
};
/**
 *
 * Selectors for theme components.
 *
 * @example 
 *
 * import { THEMES_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * colorPickerDropdownContainer(colorHex: string): Selector for the color picker dropdown container.
 *
*/
declare const THEMES_SELECTORS: {
  colorPickerDropdownContainer: (colorHex: string) => string;
  baseThemeStyle: (styleType: string) => string;
  introPageThemeStyle: (styleType: string) => string;
};
/**
 *
 * Selectors for admin panel page components.
 *
 * @example 
 *
 * import { ADMIN_PANEL_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * settingsItemHeading: Selector for settings item heading.
 *
 * settingsItemDescription: Selector for settings item description.
 *
 * expiryDateInput: Selector for expiry date input.
 *
*/
declare const ADMIN_PANEL_SELECTORS: {
  settingsItemHeading: string;
  settingsItemDescription: string;
  expiryDateInput: string;
};
/**
 *
 * Selectors for custom domain page components.
 *
 * addCustomDomainButton: Selector for the add custom domain button.
 *
 * customDomainInputField: Selector for the custom domain input field.
 *
 * submitCustomDomainButton: Selector for the submit custom domain button.
 *
 * customDomainValidateButton: Selector for the custom domain validate button.
 *
 * moreDropdownButton: Selector for the more dropdown button.
 *
 * editCustomDomainButton: Selector for the edit custom domain button.
 *
 * deleteCustomDomainButton: Selector for the delete custom domain button.
 *
*/
declare const CUSTOM_DOMAIN_SELECTORS: {
  addCustomDomainButton: string;
  customDomainInputField: string;
  submitCustomDomainButton: string;
  customDomainValidateButton: string;
  editCustomDomainButton: string;
  deleteCustomDomainButton: string;
  dropdownButton: string;
};
/**
 *
 * Selectors for API keys page components.
 *
 * editApiKeyButton: Selector for the edit API key button.
 *
 * deleteApiKeyButton: Selector for the delete API key button.
 *
 * addApiKeyButton: Selector for the add API key button.
 *
 * apiKeysLabelField: Selector for the API key label input field.
 *
 * apiKeysExpiresAtField: Selector for the API key expiry input field.
 *
 * expiryDateInputError: Selector for the expiry date input error message.
 *
 * expiryDateInput: Selector for the expiry date input field.
 *
 * tokenField: Selector for the token input or display field.
 *
 * expiresAtField: Selector for the expiry date field.
 *
 * createdAtField: Selector for the API key creation date field.
 *
*/
declare const API_KEYS_SELECTORS: {
  editApiKeyButton: string;
  deleteApiKeyButton: string;
  addApiKeyButton: string;
  apiKeysLabelField: string;
  apiKeysExpiresAtField: string;
  expiryDateInputError: string;
  expiryDateInput: string;
  apiKeysField: string;
  tokenField: string;
  expiresAtField: string;
  createdAtField: string;
};
/**
 *
 * Selectors for date picker components.
 *
 * pickerInput: Selector for the picker input field.
 *
 * datePicker: Selector for the date picker component.
 *
 * timePicker: Selector for the time picker component.
 *
 * nextYearButton: Selector for the button to navigate to the next year.
 *
 * prevYearButton: Selector for the button to navigate to the previous year.
 *
*/
declare const DATE_PICKER_SELECTORS: {
  pickerInput: string;
  datePicker: string;
  timePicker: string;
  nextYearButton: string;
  prevYearButton: string;
};
/**
 *
 * Function to initialize credentials of the current user in the storageState.
 *
 * @example 
 *
 *   initializeCredentials("invoice");
 * @endexample
*/
declare const initializeCredentials: (product: string) => void;
interface KeyValue {
  key: string;
  value: string;
}
type JoinString = (string1: string, string2: string, string3?: string, separator?: string) => string;
interface UserContext {
  user: Record<string, string>;
  headers: Record<string, unknown>;
}
type ReadFileSyncIfExists = (path?: string) => UserContext & Record<string, object>;
type WriteDataToFile = (data: string) => boolean;
type UpdateCredentials = ({
  key,
  value
}: KeyValue) => boolean;
type ClearCredentials = () => void;
type Hyphenize = (input: number | string) => string;
type JoinHyphenCase = (args: string) => string;
/**
 *
 * Joins multiple strings with an optional separator. It takes the following parameters:
 *
 * string1: The first string to join.
 *
 * string2: The second string to join.
 *
 * string3 (optional): The third string to join.
 *
 * separator (optional): The separator to use between strings. Default is an empty string.
 *
 * @example 
 *
 *   const result = joinString("Open", "AI", "is", "-");
 *   console.log(result); // Output: Open-AI-is
 * @endexample
*/
declare const joinString: JoinString;
/**
 *
 * Reads the contents of a JSON file synchronously if it exists, otherwise returns an empty object. It takes the following parameters:
 *
 * path (optional): The path of the file to read. Default is STORAGE_STATE.
 *
 * @example 
 *
 *   readFileSyncIfExists()
 * @endexample
*/
declare const readFileSyncIfExists: ReadFileSyncIfExists;
/**
 *
 * Returns the current logged in user info.
 *
 * @example 
 *
 *   const user = getGlobalUserState()
 * @endexample
*/
declare const getGlobalUserState: () => Record<string, string>;
/**
 *
 * Writes data to STORAGE_STATE file.  It takes the following parameters:
 *
 * data: The data to write to the file.
 *
 * @example 
 *
 *   writeDataToFile("neeto")
 * @endexample
*/
declare const writeDataToFile: WriteDataToFile;
/**
 *
 * Updates credentials with a new key-value pair in the STORAGE_STATE json file. It takes the following parameters:
 *
 * key: The key of the credential to update.
 *
 * value: The new value to assign to the credential.
 *
 * @example 
 *
 *   updateCredentials({
 *     key:"name",
 *     value:'oliver'
 *   })
 * @endexample
*/
declare const updateCredentials: UpdateCredentials;
/**
 *
 * Used to remove or delete all the credentials
 *
 * @example 
 *
 *   removeCredentialFile()
 * @endexample
*/
declare const removeCredentialFile: ClearCredentials;
declare const clearCredentials: ClearCredentials;
/**
 * @deprecated Use hyphenate from neeto-cist instead.
 */
/**
 *
 * Used to hyphenize the strings. It takes the following parameters:
 *
 * input: The string that need to hyphenized.
 *
 * @example 
 *
 *   import {hyphenize} from  "@bigbinary/neeto-playwright-commons"
 *   const name = hyphenize("hello world")
 *   console.log(name) // hello-world
 * @endexample
*/
declare const hyphenize: Hyphenize;
/**
 *
 * Joins multiple strings into a hyphen-separated lowercase string. It takes the following parameters:
 *
 * ...args (string[]): The strings to join.
 *
 * @example 
 *
 *   const result1 = joinHyphenCase("Hello", "World");
 *   console.log(result1); // Output: hello-world
 * @endexample
*/
declare const joinHyphenCase: JoinHyphenCase;
/**
 *
 * Provides functions to skip tests based on the environment.
 *
 * forDevelopmentEnv: Skips the test if the environment is development.
 *
 * forReviewEnv: Skips the test if the environment is review.
 *
 * forAllExceptStagingEnv: Skips the test if the environment is not staging.
 *
 * forNonNightlyRun: Skips the test if it's not a nightly run in the staging environment.
 *
 * ifNotWithinAllowedNightlyHours: Skips the test if it's not within the allowed nightly run hours.
 *
 * reason: The reason for skipping the test.
 *
 * allowedNightlyRunHours (optional): An array of numbers representing the allowed hours for nightly runs. Default is [0, 6, 12, 18].
 *
 * @example 
 *
 *   // Example usage forDevelopmentEnv:
 *   skipTest.forDevelopmentEnv();
 * 
 *   // Example usage forReviewEnv:
 *   skipTest.forReviewEnv();
 * 
 *   // Example usage forAllExceptStagingEnv:
 *   skipTest.forAllExceptStagingEnv();
 * 
 *   // Example usage forNonNightlyRun:
 *   skipTest.forNonNightlyRun();
 * 
 *   // Example usage ifNotWithinAllowedNightlyHours:
 *   skipTest.ifNotWithinAllowedNightlyHours({
 *     reason: "outside allowed nightly run hours",
 *     allowedNightlyRunHours: [0, 6, 12, 18]
 *   })
 * @endexample
*/
declare const skipTest: {
  forDevelopmentEnv: () => void;
  forReviewEnv: () => void;
  forAllExceptStagingEnv: () => void;
  forNonNightlyRun: () => void;
  ifNotWithinAllowedNightlyHours: ({
    reason,
    allowedNightlyRunHours
  }: {
    reason: string;
    allowedNightlyRunHours?: number[];
  }) => void;
};
/**
 *
 * Checks whether setup and teardown should be skipped.
 *
 * @example 
 *
 *   const shouldSkip = shouldSkipSetupAndTeardown()
 * @endexample
*/
declare const shouldSkipSetupAndTeardown: () => boolean | "";
/**
 *
 * Trims and replaces multiple whitespace characters in a string with a single space. It takes the following parameters:
 *
 * text: The text that need to be squished.
 *
 * @example 
 *
 *   const textWithExtraSpaces = "   Hello    world   ";
 *   const squishedText = squish(textWithExtraSpaces);
 * 
 *   console.log(squishedText); // Output will be "Hello world"
 * @endexample
*/
declare const squish: (text: string) => string;
/**
 *
 * Converts a string to camel case. It takes the following parameters:
 *
 * text: The text that need to be converted to camel case.
 *
 * @example 
 *
 *   const inputString = "hello_world";
 *   const camelCaseString = toCamelCase(inputString);
 * 
 *   console.log(camelCaseString); // Output will be "helloWorld"
 * @endexample
*/
declare const toCamelCase: (string: string) => string;
/**
 *
 * Creates a function to locate elements by the data-qa attribute on a page.
 *
 * @example 
 *
 *   // Using getByDataQA to find an element with a single data-qa attribute
 *   getByDataQA(page, 'some_data_qa_value');
 * 
 *   // Using getByDataQA to find a nested element with two data-qa attributes
 *   const findElementByNestedDataQA = getByDataQA(page, ['parent_data_qa_value', 'child_data_qa_value']);
 * 
 *   // Now you can use the located elements as needed
 *   await findElementBySingleDataQA.click();
 *   await findElementByNestedDataQA.hover();
 * @endexample
*/
declare const getByDataQA: ts_toolbelt_out_Function_Curry.Curry<(page: Page, dataQa: string | [string, string]) => playwright_core.Locator>;
declare const getListCount: ({
  page,
  countSelector
}: {
  page: Page;
  countSelector: string;
}) => Promise<number>;
/**
 *
 * Retrieves the global user object from the window.globalProps in the browser context.
 *
 * page: Playwright Page object representing the current browser page.
 *
 * @example 
 *
 * const userProps = await getGlobalUserProps(page);
 * 
 * console.log(userProps);
 * 
 *   Output:
 *  {
 *    id: 'ead131c8-98d3-45b2-8941-bac950acd743',
 *    email: 'cpts9gnqty9+kb+0422223153855@bigbinary.com',
 *    currentSignInAt: '2025-04-22T17:02:07.897Z',
 *    firstName: 'André',
 *    lastName: "O'Reilly",
 *    timeZone: 'Asia/Kolkata',
 *    profileImageUrl: null,
 *    active: true,
 *    authenticationToken: 'eixNftMno2q1oJmAsoD1',
 *    dateFormat: 'MM/DD/YYYY',
 *    isOwner: true,
 *    isPro: false,
 *    subscriptionPlan: 'free'
 *  }
 * 
 * @endexample
*/
declare const getGlobalUserProps: (page: Page) => Promise<Record<string, string>>;
/**
 *
 * Fetches the current text content from the system clipboard in the browser context.
 *
 * page: The Playwright Page object representing the current browser page.
 *
 * @example 
 *
 * const clipboardText = await getClipboardContent(page);
 * @endexample
*/
declare const getClipboardContent: (page: Page) => Promise<string>;
interface LoginProps {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  loginPath?: string;
}
/**
 *
 * Used to login by using email and password. It takes the following parameters:
 *
 * loginPath (optional): The path to which the user should be redirected for login.
 *
 * page: A page object
 *
 * neetoPlaywrightUtilities: An object of type NeetoPlaywrightUtilities
 *
 * @example 
 *
 *   import { loginWithoutSSO } from "@bigbinary/neeto-playwright-commons"
 * 
 *   await loginWithoutSSO({
 *     page,
 *     neetoPlaywrightUtilities,
 *     loginPath:"/home"
 *   })
 * @endexample
*/
declare const loginWithoutSSO: ({
  page,
  neetoPlaywrightUtilities,
  loginPath
}: LoginProps) => Promise<void>;
/**
 *
 * Used to Login to App
 *
 * Only works in staging environment. It takes the following parameters:
 *
 * loginPath (optional): The path to which the user should be redirected for login. Default is /
 *
 * page: A page object
 *
 * neetoPlaywrightUtilities: An object of type NeetoPlaywrightUtilities
 *
 * @example 
 *
 *   import { login } from "@bigbinary/neeto-playwright-commons"
 * 
 *   login({
 *     page,
 *     neetoPlaywrightUtilities,
 *     loginPath:"/home"
 *   })
 * @endexample
*/
declare const login: ({
  page,
  neetoPlaywrightUtilities,
  loginPath
}: LoginProps) => Promise<false | void>;
/**
 *
 * Function to generate a random email to bypass OTP verification and log into
 *
 * neeto products.
 *
 * @example 
 *
 *   import { generateRandomBypassEmail } from "@bigbinary/neeto-playwright-commons";
 * 
 *   const bypassEmail = generateRandomBypassEmail();
 * @endexample
*/
declare const generateRandomBypassEmail: () => string;
/**
 *
 * Used to extract subdomain from the error message.
 *
 * @example 
 *
 *  extractSubdomainFromError("https://wwww.bb.neetoChat.com") // bb
 * @endexample
*/
declare const extractSubdomainFromError: (errorString: string) => string;
interface AssertColumnHeaderVisibilityProps {
  page: Page;
  columnName: string;
  shouldBeVisible: boolean;
}
interface ToggleColumnCheckboxAndVerifyVisibilityProps {
  page: Page;
  tableColumns: string[];
  shouldBeChecked: boolean;
}
interface VerifyTableColumnsExistenceProps {
  page: Page;
  columnNames: string[];
}
declare const tableUtils: {
  /**
   *
   * Used to check if columns exist in table or not. It takes the following parameters:
   *
   * page: A page object.
   *
   * columnNames: Array of column names to be checked.
   *
   * @example 
   *
   *  import { tableUtils } from  "@bigbinary/neeto-playwright-commons"
   * 
   *  await tableUtils.verifyTableColumnsExistence({
   *   page,
   *   columnNames,
   *  });
   * @endexample
  */
  verifyTableColumnsExistence: ({
    page,
    columnNames
  }: VerifyTableColumnsExistenceProps) => Promise<void>;
  /**
   *
   * Used to check if the provided column matches the given visibility option. It takes the following parameters:
   *
   * page:  A page object.
   *
   * columnName: Name of the column.
   *
   * shouldBeVisible: Status of the column checkbox.
   *
   * @example 
   *
   *  import { tableUtils } from "@bigbinary/neeto-playwright-commons"
   * 
   *  await tableUtils.assertColumnHeaderVisibility({
   *       page,
   *       columnName,
   *       shouldBeVisible :true,
   *   });
   * @endexample
  */
  assertColumnHeaderVisibility: ({
    page,
    columnName,
    shouldBeVisible
  }: AssertColumnHeaderVisibilityProps) => Promise<void>;
  /**
   *
   * Used to toggle columns from the subheader's show/hide columns button. The columns are then verified in the table. It takes the following parameters:
   *
   * page: A page object.
   *
   * tableColumns: Array of column names to be toggled.
   *
   * shouldBeChecked : Status of the column checkbox.
   *
   * @example 
   *
   *   import { tableUtils } from "@bigbinary/neeto-playwright-commons"
   * 
   *   await tableUtils.toggleColumnCheckboxAndVerifyVisibility({
   *     page,
   *     tableColumns,
   *     shouldBeChecked: false,
   *   });
   * @endexample
  */
  toggleColumnCheckboxAndVerifyVisibility: ({
    page,
    tableColumns,
    shouldBeChecked
  }: ToggleColumnCheckboxAndVerifyVisibilityProps) => Promise<void>;
  /**
   *
   * Used to verify the feature freeze column of table. The freezed column is then verified in the table. It takes the following parameters:
   *
   * page: A page object.
   *
   * t: An instance of TFunction.
   *
   * @example 
   *
   *   import { tableUtils } from "@bigbinary/neeto-playwright-commons"
   * 
   *   await tableUtils.verifyFreezeColumnAction(
   *     page,
   *     t
   *   );
   * @endexample
  */
  verifyFreezeColumnAction: (page: Page, t: TFunction) => Promise<void>;
};
interface BreadcrumbTitleAndRoute {
  title: string;
  route: string;
}
interface VerifyBreadcrumbProps {
  page: Page;
  titlesAndRoutes: BreadcrumbTitleAndRoute[];
}
declare const headerUtils: {
  /**
   *
   * Verifies the breadcrumbs in the header of a web page. It takes the following parameters:
   *
   * page: An instance of the Playwright Page class representing the web page where the breadcrumbs are located.
   *
   * titlesAndRoutes: An array of objects containing the titles and routes of the breadcrumbs to verify.
   *
   * @example 
   *
   *   import { Page } from "@playwright/test";
   *   import { headerUtils } from "@bigbinary/neeto-playwright-commons";
   * 
   *   const breadcrumbs = [
   *     { title: "Home", route: "/" },
   *     { title: "Category", route: "/category" },
   *     { title: "Subcategory", route: "/category/subcategory" }
   *   ];
   * 
   *   await headerUtils.verifyBreadcrumbs({
   *    page,
   *    titlesAndRoutes: breadcrumbs
   *   });
   * @endexample
  */
  verifyBreadcrumbs: ({
    page,
    titlesAndRoutes
  }: VerifyBreadcrumbProps) => Promise<void>;
};
/**
 *
 * Initializes TOTP authentication by creating a TOTP instance with the specified issuer and secret. It takes the following parameters:
 *
 * issuer: A string representing the issuer name for TOTP authentication.
 *
 * secret: A string or a Secret object representing the secret key for TOTP generation.
 *
 * Returns: A TOTP object initialized with the provided issuer, algorithm, digits, period, and secret.
 *
 * @example 
 *
 *   import { initializeTotp } from "@bigbinary/neeto-playwright-commons";
 * 
 *   // Initialize TOTP with issuer and secret
 *   const issuer = "MyApp";
 *   const secret = "my_secret_key";
 *   const totp = initializeTotp({ issuer, secret });
 * 
 *   // Generate TOTP token
 *   const token = totp.generate();
 *   console.log("TOTP Token:", token);
 * @endexample
*/
declare const initializeTotp: ({
  issuer,
  secret
}: {
  issuer: string;
  secret: string | Secret;
}) => TOTP;
type EmulateNetworkConditionsParameters = Protocol.Network.emulateNetworkConditionsParameters;
type NetworkThrottlingUsingCdpParams = {
  cdpSession: CDPSession;
  emulateNetworkConditionsParameters?: EmulateNetworkConditionsParameters;
};
/**
 *
 * Throttles network conditions using CDP. It takes the following parameters:
 *
 * cdpSession: A CDPSession instance for sending CDP commands.
 *
 * emulateNetworkConditionsParameters (optional): An object representing the network conditions to emulate. Default is "Fast 3G" conditions.
 *
 * Throttles CPU usage using CDP. It takes the following parameters:
 *
 * cdpSession: A CDPSession instance for sending CDP commands.
 *
 * rate (optional): A number representing the throttling rate as a slowdown factor. Default is 1.25.
 *
 * @example 
 *
 *   import { cpuThrottlingUsingCDP } from "@bigbinary/neeto-playwright-commons";
 * 
 *   cpuThrottlingUsingCDP({
 *     cdpSession
 *   })
 * @endexample
 * Executes code with throttled network and/or CPU resources. It takes the following parameters:
 *
 * code: A function representing the code to execute.
 *
 * kind (optional): A string specifying the type of throttling to apply. Can be "both" (default), "network", or "cpu".
 *
 * networkCondition (optional): An object representing the network conditions to emulate.
 *
 * cpuThrottlingRate (optional): A number representing the CPU throttling rate as a slowdown factor.
 *
 * cdpSession: A CDPSession instance for sending CDP commands.
 *
 * @example 
 *
 *   import { networkConditions } from "@constants/networkConditions";
 *   import { executeWithThrottledResources } from "@bigbinary/neeto-playwright-commons";
 * 
 *   const emulateNetworkConditionsParameters = networkConditions["Fast 3G"];
 *   const cpuThrottlingRate = 2;
 * 
 *   await executeWithThrottledResources({
 *     code: async () => {
 *       // Your code to emulate network and CPU throttling
 *     },
 *     kind: "both",
 *     networkCondition: emulateNetworkConditionsParameters,
 *     cpuThrottlingRate,
 *     cdpSession, // Provide the CDPSession instance
 *   });
 * @endexample
*/
declare const networkThrottlingUsingCDP: ({
  cdpSession,
  emulateNetworkConditionsParameters
}: NetworkThrottlingUsingCdpParams) => Promise<Protocol.Network.emulateNetworkConditionsReturnValue>;
type CpuThrottlingUsingCdpParams = {
  cdpSession: CDPSession;
  rate?: number;
};
declare const cpuThrottlingUsingCDP: ({
  cdpSession,
  rate
}: CpuThrottlingUsingCdpParams) => Promise<Protocol.Emulation.setCPUThrottlingRateReturnValue>;
interface ExecuteWithThrottledResourcesParams {
  kind?: "both" | "network" | "cpu";
  code: () => Promise<void>;
  networkCondition?: EmulateNetworkConditionsParameters;
  cpuThrottlingRate?: number;
  cdpSession: CDPSession;
}
declare const executeWithThrottledResources: ({
  code: emulatedCode,
  kind,
  networkCondition,
  cpuThrottlingRate,
  cdpSession
}: ExecuteWithThrottledResourcesParams) => Promise<void>;
/**
 *
 * Function to generate a basic HTML content with the given body.
 *
 * @example 
 *
 *    basicHTMLContent(`
 *        <h1>Hello world</h1>
 *    `)
 * 
 * @endexample
*/
declare const basicHTMLContent: (content: string) => string;
/**
 *
 * This function converts a hexadecimal color code to its RGB equivalent.
 *
 * hex: A string representing the hexadecimal color code to be converted to RGB.
 *
 * @example 
 *
 *    import { hexToRGB } from "@bigbinary/neeto-playwright-commons";
 * 
 *    // Convert hexadecimal color code to RGB
 *    const rgbColor = hexToRGB("#ff0000");
 * 
 *    console.log(rgbColor); // Output: 'rgb(255, 0, 0)'
 * 
 *    // Convert another hexadecimal color code to RGB
 *    const anotherRGBColor = hexToRGB("#00ff00");
 * 
 *    console.log(anotherRGBColor); // Output: 'rgb(0, 255, 0)'
 * @endexample
*/
declare const hexToRGB: (hex: string) => string;
declare const filterUtils: {
  /**
   *
   * Opens the filter pane on page.
   *
   * page: An instance of the Playwright Page class representing the web page where the filter pane should be opened.
   *
   * @example 
   *
   *   import { Page } from "@playwright/test";
   *   import { filterUtils } from "@bigbinary/neeto-playwright-commons";
   * 
   *   await filterUtils.openFilterPane(page);
   * @endexample
  */
  openFilterPane: (page: Page) => Promise<void>;
  /**
   *
   * Clear the filters applied on a page using the clear button
   *
   * page: An instance of the Playwright Page class representing the web page from where filters need to be cleared.
   *
   * @example 
   *
   *   import { Page } from "@playwright/test";
   *   import { filterUtils } from "@bigbinary/neeto-playwright-commons";
   * 
   *   await filterUtils.clearFiltersFromActionBlock(page);
   * @endexample
  */
  clearFiltersFromActionBlock: (page: Page) => Promise<void>;
};
/**
 *
 * Function to get the image path and name from the image in a given path.
 *
 * @example 
 *
 *   import { getImagePathAndName } from "@bigbinary/neeto-playwright-commons";
 * 
 *   const { imagePath, imageName } = getImagePathAndName("../assets/images/image.png");
 * @endexample
*/
declare const getImagePathAndName: (localImagePath: string) => {
  imagePath: string;
  imageName: string;
};
declare const currencyUtils: {
  getAmountWithSymbol: (amount: number, options: Record<string, unknown>) => string;
  currencyFormat: {
    withAmount: (amount: number, options?: {
      minimumFractionDigits: number;
    }) => string;
    withSymbol: (amount: number, currency: string, options: Record<string, unknown>) => string;
    withCode: (amount: number, currency: string, options?: {
      minimumFractionDigits: number;
    }) => string;
    withSymbolAndCode: (amount: number, currency: string, options: Record<string, unknown>) => string;
  };
};
/**
 *
 * Automatically tracks GitHub issues to fail tests when bugs are fixed
 *
 * issueLinks: An array of dependent issue links that need to be closed before
 *
 * continuing with the test
 *
 * @example 
 *
 * import { isGithubIssueOpen } from "@neetoplaywright";
 * 
 * test("should fail because of a bug in the product", async () => {
 *   test.fail(
 *     await isGithubIssueOpen([
 *       "github.com/bigbinary/neeto-app-web/1234",
 *       "github.com/bigbinary/neeto-app-web/1235",
 *     ]),
 *     "This test will fail until these bugs are fixed."
 *   );
 * });
 * 
 * // OR
 * 
 * test("should fail because of a bug in the product", async () => {
 *   test.fixme(
 *     await isGithubIssueOpen([
 *       "github.com/bigbinary/neeto-app-web/1234",
 *       "github.com/bigbinary/neeto-app-web/1235",
 *     ]),
 *     "This test should be fixed until these bugs are fixed."
 *   );
 * });
 * @endexample
*/
declare const isGithubIssueOpen: (issueLinks: string[]) => Promise<boolean>;
/**
 *
 * Simulates typing with a delay.
 *
 * @example 
 *
 * import { simulateTypingWithDelay } from "@bigbinary/neeto-playwright-commons";
 * 
 * await simulateTypingWithDelay({
 *   field: page.getByTestId("email-field"),
 *   value: "oliver@example.com",
 *   delay: 600,
 * });
 * @endexample
*/
declare const simulateTypingWithDelay: ({
  field,
  value,
  delay
}: {
  field: Locator;
  value: string;
  delay?: number;
}) => Promise<void>;
/**
 *
 * Simulates a click with a delay.
 *
 * @example 
 *
 * import { simulateClickWithDelay } from "@bigbinary/neeto-playwright-commons";
 * 
 * await simulateClickWithDelay({
 *   element: page.getByTestId("submit-button"),
 *   page: page,
 * });
 * @endexample
*/
declare const simulateClickWithDelay: ({
  element,
  page
}: {
  element: Locator;
  page: Page;
}) => Promise<void>;
interface GenerateRandomFileProps {
  sizeInKB: number;
  fileType: FileType;
  fileName?: string;
}
/**
 *
 * Used to serialize a File object into a format that can be passed into the browser context using Playwright’s evaluateHandle.
 *
 * This is required because DOM File instances can't be transferred directly between Node and browser contexts.
 *
 * file: A File object generated in the Node/test context.
 *
 * Returns a plain object containing:
 *
 * name: File name.
 *
 * type: MIME type.
 *
 * lastModified: Last modified timestamp.
 *
 * buffer: Byte array representing file contents (as a regular array).
 *
 * @example 
 *
 * import { serializeFileForBrowser } from "@utils/fileUtils";
 * 
 * const serializedFile = await serializeFileForBrowser(file);
 * @endexample
*/
declare const serializeFileForBrowser: (file: File) => Promise<{
  name: string;
  type: string;
  lastModified: number;
  buffer: number[];
}>;
/**
 *
 * Used to generate a random File object of a specific size and type.
 *
 * sizeInKB: Size of the file in KB.
 *
 * fileType: Type/extension of the file (e.g., 'png', 'pdf', 'jpg').
 *
 * fileName (optional): Custom name for the generated file. Defaults to sample.{fileType}.
 *
 * Returns an object containing:
 *
 * file: The generated File object.
 *
 * fileName: The file name as a string.
 *
 * @example 
 *
 * import { generateRandomFile } from "@utils/fileUtils";
 * 
 * const { file, fileName } = generateRandomFile({
 *   sizeInKB: 1024,
 *   fileType: "png",
 * });
 * @endexample
*/
declare const generateRandomFile: ({
  sizeInKB,
  fileType,
  fileName
}: GenerateRandomFileProps) => {
  file: File;
  fileName: string;
};
interface PlaydashOverrides {
  projectKey: string;
}
interface Overrides {
  globalOverrides?: Record<string, unknown>;
  useOverrides?: Record<string, unknown>;
  useCustomProjects?: boolean;
  projectOverrides?: Record<string, unknown>[];
  playdashStagingOverrides?: PlaydashOverrides & Record<string, unknown>;
  playdashProductionOverrides?: PlaydashOverrides & Record<string, unknown>;
  playdashLighthouseOverrides?: PlaydashOverrides & Record<string, unknown>;
}
/**
 *
 * This function returns the default playwright configuration object. It can be
 *
 * used to extend the default playwright configuration object in the host project.
 *
 * @example 
 *
 * import { definePlaywrightConfig } from "@bigbinary/neeto-playwright-commons";
 * 
 * export default definePlaywrightConfig({
 *   playdashProductionOverrides: { projectKey: "********************" },
 * });
 * @endexample
*/
declare const definePlaywrightConfig: (overrides: Overrides) => _playwright_test.PlaywrightTestConfig<{}, {}>;
export { ADMIN_PANEL_SELECTORS, API_KEYS_SELECTORS, API_ROUTES, AUDIT_LOGS_TEXTS, AdminPanelPage, ApiKeysPage, AuditLogsPage, BASE_URL, type BaseThemeStyle, type BaseThemeStyleType, CHANGELOG_WIDGET_SELECTORS, CHAT_WIDGET_SELECTORS, CHAT_WIDGET_TEXTS, COLOR, COMMON_SELECTORS, COMMON_TEXTS, COMMUNITY_TEXTS, CREDENTIALS, CUSTOM_DOMAIN_SELECTORS, CustomCommands, CustomDomainPage as CustomDomainsPage, type CustomFixture, DATE_PICKER_SELECTORS, DATE_TEXTS, DESCRIPTION_EDITOR_TEXTS, EMBED_SELECTORS, EMOJI_LABEL, EMPTY_STORAGE_STATE, ENGAGE_TEXTS, ENVIRONMENT, EXPANDED_FONT_SIZE, EditorPage, EmbedBase, FONT_SIZE_SELECTORS, GLOBAL_TRANSLATIONS_PATTERN, GOOGLE_CALENDAR_DATE_FORMAT, GOOGLE_LOGIN_SELECTORS, GOOGLE_LOGIN_TEXTS, GooglePage, HELP_CENTER_SELECTORS, HelpAndProfilePage, INTEGRATIONS_TEXTS, INTEGRATION_SELECTORS, IS_STAGING_ENV, ImageUploader, IntegrationBase, type IntroPageThemeStyle, type IntroPageThemeStyleType, KEYBOARD_SHORTCUTS_SELECTORS, LIST_MODIFIER_SELECTORS, LIST_MODIFIER_TAGS, LOGIN_SELECTORS, MEMBER_FORM_SELECTORS, MEMBER_SELECTORS, MEMBER_TEXTS, MERGE_TAGS_SELECTORS, MailerUtils, Member, MemberApis, NEETO_AUTH_BASE_URL, NEETO_EDITOR_SELECTORS, NEETO_FILTERS_SELECTORS, NEETO_IMAGE_UPLOADER_SELECTORS, NEETO_ROUTES, NEETO_TEXT_MODIFIER_SELECTORS, ORGANIZATION_TEXTS, OTP_EMAIL_PATTERN, OrganizationPage, PLURAL, PROFILE_LINKS, PROFILE_SECTION_SELECTORS, PROJECT_TRANSLATIONS_PATH, ROLES_SELECTORS, ROUTES, RolesPage, SELECT_COUNTRY, SIGNUP_SELECTORS, SINGULAR, SLACK_DATA_QA_SELECTORS, SLACK_DEFAULT_CHANNEL, SLACK_SELECTORS, SLACK_WEB_TEXTS, STATUS_TEXTS, STORAGE_STATE, SidebarSection, SlackPage, TABLE_SELECTORS, TAB_SELECTORS, TAGS_SELECTORS, TEXT_MODIFIER_ROLES, TEXT_MODIFIER_SELECTORS, TEXT_MODIFIER_TAGS, THANK_YOU_SELECTORS, THEMES_SELECTORS, THIRD_PARTY_ROUTES, TOASTR_MESSAGES, TagsPage, TeamMembers, ThankYouPage, type ThemeCategory, USER_AGENTS, WEBHOOK_SELECTORS, WebhooksPage, ZAPIER_LIMIT_EXHAUSTED_MESSAGE, ZAPIER_SELECTORS, ZAPIER_TEST_EMAIL, ZAPIER_WEB_TEXTS, ZapierPage, basicHTMLContent, clearCredentials, commands, cpuThrottlingUsingCDP, currencyUtils, decodeQRCodeFromFile, definePlaywrightConfig, executeWithThrottledResources, extractSubdomainFromError, filterUtils, generateRandomBypassEmail, generateRandomFile, generateStagingData, getByDataQA, getClipboardContent, getGlobalUserProps, getGlobalUserState, getImagePathAndName, getListCount, headerUtils, hexToRGB, hexToRGBA, hyphenize, i18nFixture, initializeCredentials, initializeTotp, isGithubIssueOpen, joinHyphenCase, joinString, login, loginWithoutSSO, networkConditions, networkThrottlingUsingCDP, readFileSyncIfExists, removeCredentialFile, serializeFileForBrowser, shouldSkipSetupAndTeardown, simulateClickWithDelay, simulateTypingWithDelay, skipTest, squish, _default as stealthTest, tableUtils, toCamelCase, updateCredentials, writeDataToFile };